package com.alonginfo.common.utils;

import org.springframework.web.multipart.MultipartFile;

import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.util.HashMap;
import java.util.Map;

public class FileTypeDetector {
    // 定义文件类型映射
    private static final Map<String, String> FILE_TYPE_MAP = new HashMap<>();

    static {
        // 初始化文件类型映射
        FILE_TYPE_MAP.put("89504E47", "png"); // PNG
        FILE_TYPE_MAP.put("47494638", "gif"); // GIF
        FILE_TYPE_MAP.put("25504446", "pdf"); // PDF
        FILE_TYPE_MAP.put("504b0304", "docx"); // docx
        FILE_TYPE_MAP.put("d0cf11e0", "doc"); // doc
        FILE_TYPE_MAP.put("504B0304", "xlsx"); // xlsx
        FILE_TYPE_MAP.put("D0CF11E0", "xls"); // xls
        FILE_TYPE_MAP.put("00000018", "mp4"); // mp4
        FILE_TYPE_MAP.put("6D6F6F76", "mov"); // mov
        // ... 其他文件类型的魔数
    }

    public static String getFileType(MultipartFile file) throws IOException {
        byte[] fileBytes = new byte[8];
        try (InputStream inputStream = file.getInputStream()) {
            int bytesRead = inputStream.read(fileBytes, 0, fileBytes.length);
            if (bytesRead < fileBytes.length) {
                throw new IOException("无法读取足够的字节来检测文件类型");
            }
        }

        String magicNumber = bytesToHex(fileBytes, 0, fileBytes.length).toUpperCase();

        for (Map.Entry<String, String> entry : FILE_TYPE_MAP.entrySet()) {
            if (magicNumber.startsWith(entry.getKey())) {
                return entry.getValue();
            }
        }

        return "未知文件类型";
    }

    private static String bytesToHex(byte[] bytes, int offset, int length) {
        StringBuilder sb = new StringBuilder();
        for (int i = offset; i < offset + length; i++) {
            sb.append(String.format("%02X", bytes[i]));
        }
        return sb.toString();
    }
}
