package com.alonginfo.project.business.controller;

import com.alonginfo.framework.datasource.DynamicDataSourceContextHolder;
import com.alonginfo.framework.web.controller.BaseController;
import com.alonginfo.framework.web.domain.AjaxResult;
import com.alonginfo.framework.web.page.TableDataInfo;
import com.alonginfo.project.business.domain.MxDataGroup;
import com.alonginfo.project.business.domain.MxDataSet;
import com.alonginfo.project.business.service.IMxDataSetService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

/**
 * @author Li先生
 *  数据集管理
 */
@Api("数据集管理")
@RestController
@RequestMapping("/businiss/mxdataset")
public class MxDataSetController extends BaseController {

    @Autowired
    IMxDataSetService mxDataSetService;

    // 数据集分组相关 ======================================


    /**
     * 获取数据集分组列表+数据集列表
     */
    @ApiOperation("获取数据集分组+数据集列表")
    @GetMapping("/mxDataGroupAndDataSetList")
    public AjaxResult mxDataGrouplist() {
        return AjaxResult.success(mxDataSetService.selectMxDataGroupList());
    }

    /**
     * 添加数据集分组
     * @param mxDataGroup
     */
    @ApiOperation("添加数据集分组")
    @PostMapping("/addMxDataGroup")
    public AjaxResult addMxDataGroup(@RequestBody MxDataGroup mxDataGroup){
        return toAjax(mxDataSetService.addMxDataGroup(mxDataGroup)) ;
    }

    /**
     * 删除数据集分组
     * @param dGroupId
     */
    @ApiOperation("删除数据集分组")
    @DeleteMapping("/deleteMxDataGroup/{dGroupId}")
    public AjaxResult deleteMxDataGroup(@PathVariable("dGroupId") String dGroupId){
        return toAjax(mxDataSetService.deleteMxDataGroup(dGroupId)) ;
    }

    /**
     * 修改数据集分组
     * @param mxDataGroup
     */
    @ApiOperation("修改数据集分组")
    @PutMapping("/editMxDataGroup")
    public AjaxResult editMxDataGroup(@RequestBody MxDataGroup mxDataGroup){
        return toAjax(mxDataSetService.editMxDataGroup(mxDataGroup)) ;
    }

    // 数据集相关 =====================================

    /**
     * 根据数据集id 获取数据集实例
     */
    @ApiOperation("根据数据集id,获取数据集实例")
    @GetMapping("/getMxDataSet/{dsId}")
    public AjaxResult getMxDataSet(@PathVariable("dsId") String dsId) {
        return AjaxResult.success(mxDataSetService.getMxDataSet(dsId));
    }

    /**
     * 根据数据集 （数据源id+sql） 展示查询结果
     * @param mxDataSet
     * @return
     */
    @ApiOperation("执行sql展示结果")
    @PostMapping("/showResult")
    public TableDataInfo showResult(@RequestBody MxDataSet mxDataSet  ){
        // change数据源
        DynamicDataSourceContextHolder.setDataSourceType(mxDataSet.getDatabaseId());
        startPage();
        List<Map<String, Object>> list = mxDataSetService.executeSql(mxDataSet);
        DynamicDataSourceContextHolder.clearDataSourceType();
        return getDataTable(list);

    }

    /**
     * 添加数据集
     * @param mxDataSet
     */
    @ApiOperation("添加数据集")
    @PostMapping("/addMxDataSet")
    public AjaxResult addMxDataSet(@RequestBody MxDataSet mxDataSet){
        // change数据源
        DynamicDataSourceContextHolder.setDataSourceType(mxDataSet.getDatabaseId());
        return toAjax(mxDataSetService.addMxDataSet(mxDataSet)) ;
    }

    /**
     * 删除数据集
     * @param dsId
     */
    @ApiOperation("删除数据集")
    @DeleteMapping("/deleteMxDataSet/{dsId}")
    public AjaxResult deleteMxDataSet(@PathVariable("dsId") String dsId){
        return toAjax(mxDataSetService.deleteMxDataSet(dsId)) ;
    }

    /**
     * 修改数据集
     * @param mxDataSet
     */
    @ApiOperation("修改数据集")
    @PutMapping("/editMxDataSet")
    public AjaxResult editMxDataSet(@RequestBody MxDataSet mxDataSet){

        return toAjax(mxDataSetService.addMxDataSet(mxDataSet)) ;
    }


}
