package com.alonginfo.project.business.controller;

import com.alibaba.druid.filter.config.ConfigTools;
import com.alonginfo.common.utils.sign.Base64;
import com.alonginfo.framework.datasource.DynamicDataSourceContextHolder;
import com.alonginfo.framework.web.controller.BaseController;
import com.alonginfo.framework.web.domain.AjaxResult;
import com.alonginfo.framework.web.page.TableDataInfo;
import com.alonginfo.project.business.domain.MxDataSet;
import com.alonginfo.project.business.domain.MxDatabase;
import com.alonginfo.project.business.service.IMxDatabaseService;
import com.alonginfo.utils.DBUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.net.URLDecoder;
import java.nio.charset.StandardCharsets;
import java.util.List;
import java.util.Map;

/**
 * @author Li先生
 * 数据源管理
 */
@Api("数据源管理")
@RestController
@RequestMapping("/businiss/mxdatabase")
public class MxDatabaseController extends BaseController {

    @Autowired
    IMxDatabaseService mxDatabaseService;

    /**
     * 获取数据源列表
     */
    @ApiOperation("获取数据源列表-分页")
    @GetMapping("/list")
    public TableDataInfo list(@RequestBody(required = false)  MxDatabase mxDatabase) {
        startPage();
        List<MxDatabase> mxDatabases = mxDatabaseService.selectMxDatabaseList(mxDatabase);
        return getDataTable(mxDatabases );
    }

    /**
     * 获取数据源列表-全部不分页
     */
    @ApiOperation("获取数据源列表-全部")
    @GetMapping("/listall")
    public AjaxResult listall() {
        List<MxDatabase> mxDatabases = mxDatabaseService.selectMxDatabaseList(null);
        return AjaxResult.success(mxDatabases);
    }



    /**
     * 根据id获取对象
     */
    @ApiOperation("根据id获取对象")
    @GetMapping("/{id}")
    public AjaxResult getMxDatabase(@PathVariable String id ) {
        return AjaxResult.success(mxDatabaseService.getMxDatabase(id));
    }

    /**
     *  新增数据
     */
    @ApiOperation("新增数据")
    @PostMapping("/add")
    public AjaxResult insertMxDatabase(@RequestBody MxDatabase mxDatabase) {
        String password = URLDecoder.decode(new String(Base64.decode(mxDatabase.getPassword()), StandardCharsets.UTF_8));
        mxDatabase.setPassword(password);
        AjaxResult test = DBUtil.TestMxDatabase(mxDatabase);
        if (Integer.parseInt(test.get("code").toString()) != 200 ) {
            return test;
        } else {
            return toAjax(mxDatabaseService.insertMxDatabase(mxDatabase));
        }
    }

    /**
     *  删除数据
     */
    @ApiOperation("删除数据")
    @DeleteMapping("/{id}")
    public AjaxResult deleteMxDatabase(@PathVariable String id) {
        return toAjax(mxDatabaseService.deleteMxDatabase(id));
    }

    /**
     *  修改数据
     */
    @ApiOperation("修改数据")
    @PutMapping("/edit")
    public AjaxResult editMxDatabase(@RequestBody MxDatabase mxDatabase) {
        String password = URLDecoder.decode(new String(Base64.decode(mxDatabase.getPassword()), StandardCharsets.UTF_8));
        mxDatabase.setPassword(password);
        AjaxResult test = DBUtil.TestMxDatabase(mxDatabase);
        if (Integer.parseInt(test.get("code").toString()) != 200 ) {
            return test;
        } else {
            return toAjax(mxDatabaseService.editMxDatabase(mxDatabase));
        }
    }

    /**
     *  加密
     */
    @ApiOperation("加密")
    @PostMapping("/encrypt")
    public AjaxResult encrypt(@RequestBody MxDatabase mxDatabase) {
        try {
            return AjaxResult.success(ConfigTools.encrypt(mxDatabase.getPassword() == null ? "" : mxDatabase.getPassword()));
        } catch (Exception e) {
            e.printStackTrace();
        }
        return AjaxResult.error("加密错误！");
    }

}
