package com.alonginfo.project.business.controller;

import com.alonginfo.framework.web.controller.BaseController;
import com.alonginfo.framework.web.domain.AjaxResult;
import com.alonginfo.project.business.domain.MxGroupSetting;
import com.alonginfo.project.business.service.IMxGroupSettingService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 配置Controller
 * @author LM
 * @date 2020-03-10
 */
@Api("配置操作")
@Controller
@RequestMapping("/business/mxgroupsetting")
public class MxGroupSettingController extends BaseController
{

    @Autowired
    private IMxGroupSettingService mxGroupSettingService;


    /**
     * 查询配置列表
     */
    @ApiOperation("查询配置列表")
    @GetMapping("/list")
    @ResponseBody
    public AjaxResult list(MxGroupSetting mxGroupSetting)
    {
        List<MxGroupSetting> list = mxGroupSettingService.selectMxGroupSettingList(mxGroupSetting);
        return AjaxResult.success(list);
    }



    /**
     * 新增保存配置
     */
    @ApiOperation("新增保存配置")
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(@RequestBody MxGroupSetting mxGroupSetting)
    {
        return toAjax(mxGroupSettingService.insertMxGroupSetting(mxGroupSetting));
    }

    /**
     * 修改配置
     * @param mxGroupSetting
     * @return
     */
    @ApiOperation("修改配置")
    @PutMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(@RequestBody MxGroupSetting mxGroupSetting)
    {
        return toAjax(mxGroupSettingService.updateMxGroupSetting(mxGroupSetting));
    }

    /**
     * 删除配置
     */
    @ApiOperation("删除配置")
    @DeleteMapping( "/remove/{settingId}")
    @ResponseBody
    public AjaxResult remove(@PathVariable("settingId") String settingId)
    {
        return toAjax(mxGroupSettingService.deleteMxGroupSettingById(settingId));
    }

    /**
     * 根据id  查询配置
     */
    @ApiOperation("根据id  查询配置")
    @GetMapping( "/get/{settingId}")
    @ResponseBody
    public AjaxResult get(@PathVariable("settingId") String settingId)
    {
        return AjaxResult.success(mxGroupSettingService.selectMxGroupSettingById(settingId));
    }
}
