package com.alonginfo.project.business.controller;

import com.alonginfo.framework.web.controller.BaseController;
import com.alonginfo.framework.web.domain.AjaxResult;
import com.alonginfo.project.business.domain.MxPageGroup;
import com.alonginfo.project.business.service.IMxPageGroupService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 分组信息Controller
 * 
 * @author LM
 * @date 2020-03-10
 */
@Api("分组信息")
@Controller
@RequestMapping("/business/mxpagegroup")
public class MxPageGroupController extends BaseController
{

    @Autowired
    private IMxPageGroupService mxPageGroupService;


    /**
     * 查询分组信息列表
     */
    @ApiOperation("查询分组列表")
    @GetMapping("/list")
    @ResponseBody
    public AjaxResult list(MxPageGroup mxPageGroup)
    {
        List<MxPageGroup> list = mxPageGroupService.selectMxPageGroupList(mxPageGroup);
        return AjaxResult.success(list);
    }

    /**
     * 新增保存分组信息
     */
    @ApiOperation("新增分组信息")
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(@RequestBody MxPageGroup mxPageGroup)
    {
        return toAjax(mxPageGroupService.insertMxPageGroup(mxPageGroup));
    }


    /**
     * 修改保存分组信息
     */
    @ApiOperation("修改分组信息")
    @PutMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(@RequestBody  MxPageGroup mxPageGroup)
    {
        return toAjax(mxPageGroupService.updateMxPageGroup(mxPageGroup));
    }

    /**
     * 删除分组信息
     */
    @ApiOperation("删除分组信息")
    @DeleteMapping( "/remove/{groupId}")
    @ResponseBody
    public AjaxResult remove(@PathVariable("groupId") String groupId)
    {
        return toAjax(mxPageGroupService.deleteMxPageGroupById(groupId));
    }

    /**
     * 根据id 获取分组信息
     */
    @ApiOperation("根据id获取分组信息")
    @GetMapping( "/get/{groupId}")
    @ResponseBody
    public AjaxResult get(@PathVariable("groupId") String groupId)
    {
        return AjaxResult.success(mxPageGroupService.selectMxPageGroupById(groupId));
    }

    /**
     * 删除分组中的主题
     */
    @ApiOperation("删除分组中的主题")
    @DeleteMapping( "/removePageInGroup/{groupId}/{themeId}")
    @ResponseBody
    public AjaxResult removePageInGroup(@PathVariable("groupId") String groupId,@PathVariable("themeId") String themeId)
    {
        return toAjax(mxPageGroupService.removePageInGroup(groupId,themeId));
    }

    /**
     * 添加主题到分组
     */
    @ApiOperation("添加主题到分组")
    @PostMapping("/addPageToGroup")
    @ResponseBody
    public AjaxResult addPageToGroup(@RequestBody  MxPageGroup mxPageGroup)
    {
        return toAjax(mxPageGroupService.addPageToGroup(mxPageGroup));
    }


    /**
     * 获取工程列表
     */
    @ApiOperation("获取工程列表 ")
    @GetMapping( "/getProjectList")
    @ResponseBody
    public AjaxResult getProjectList()
    {
        return AjaxResult.success(mxPageGroupService.getProjectList());
    }

    /**
     * 根据工程id 获取主题列表
     */
    @ApiOperation("根据工程id 获取主题列表")
    @GetMapping( "/getPagesList/{proId}")
    @ResponseBody
    public AjaxResult getPagesList(@PathVariable("proId") String proId)
    {
        return AjaxResult.success(mxPageGroupService.getPagesList(proId));
    }


    /**
     * 修改分组主题排序
     */
    @ApiOperation("修改分组主题排序")
    @PostMapping("/editOrderNum")
    @ResponseBody
    public AjaxResult editOrderNum(@RequestBody  MxPageGroup mxPageGroup)
    {
        return toAjax(mxPageGroupService.editOrderNum(mxPageGroup));
    }

}
