package com.alonginfo.project.business.controller;

import com.alonginfo.framework.security.service.TokenService;
import com.alonginfo.framework.web.controller.BaseController;
import com.alonginfo.framework.web.domain.AjaxResult;
import com.alonginfo.framework.web.page.TableDataInfo;
import com.alonginfo.project.business.service.IMxQuartzService;
import com.alonginfo.quartz.domain.SysJob;
import com.alonginfo.quartz.utils.CronUtils;
import org.quartz.SchedulerException;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @Description  定时任务界面  Controller层
 * @Author Haoxs
 * @Date 2021-04-26 16:16
 */
@RestController
@RequestMapping("/quartz")
public class MxQuartzController extends BaseController {

    @Autowired
    private IMxQuartzService iMxQuartzService;

    @Autowired
    private TokenService tokenService;

    /**
     * 获取所有定时任务列表
     * @return
     */
    @GetMapping("/getAllQuartzList")
    public TableDataInfo getQuartzList(SysJob job) {
        startPage();
        return getDataTable(iMxQuartzService.getQuartzList(job));
    }

    /**
     * 修改定时任务状态
     * @param job
     * @return
     */
    @PostMapping("/changeStatus")
    public AjaxResult changeStatus(@RequestBody SysJob job) {
        try {
            SysJob newJob = iMxQuartzService.selectJobById(job.getJobId());
            newJob.setStatus(job.getStatus());
            newJob.setUpdateBy("admin");
            iMxQuartzService.changeStatus(newJob);
            return AjaxResult.success("定时任务:"+ job.getJobName() + ", 已成功" + ("0".equals(job.getStatus()) ? "运行!" : "停止!"));
        } catch (SchedulerException e) {
            e.printStackTrace();
            return AjaxResult.error("定时任务状态修改失败!");
        }
    }

    /**
     * 新增定时任务
     * @param job
     * @return
     */
    @PostMapping("/add")
    public AjaxResult addQuartz(@RequestBody SysJob job) {
        try {
            if (!CronUtils.isValid(job.getCronExpression())) {
                return AjaxResult.error("cron表达式不正确!");
            }
            iMxQuartzService.insertJob(job);
            return AjaxResult.success("新增定时任务:" + job.getJobName() + "成功!");
        } catch (Exception e) {
            e.printStackTrace();
            return AjaxResult.error("新增定时任务失败!");
        }
    }

    /**
     * 立即执行定时任务
     * @param job
     * @return
     */
    @PostMapping("/run")
    public AjaxResult runQuartz(@RequestBody SysJob job) {
        try {
            iMxQuartzService.runJob(job);
            return AjaxResult.success("定时任务:" + job.getJobName() + ", 开始执行!");
        }catch (Exception e) {
            e.printStackTrace();
            return AjaxResult.error("定时任务立即执行失败!");
        }
    }

    /**
     * 立即执行所有定时任务
     * @param jobList
     * @return
     */
    @PostMapping("/runAll")
    public AjaxResult runAllQuartz(@RequestBody List<SysJob> jobList) {
        try {
            iMxQuartzService.runAllJob(jobList);
            return AjaxResult.success("启动成功! 所有定时任务将被执行一遍!");
        }catch (Exception e) {
            e.printStackTrace();
            return AjaxResult.error("立即执行所有定时任务失败!");
        }
    }
}
