package com.alonginfo.project.business.controller;


import com.alonginfo.common.utils.StringUtils;
import com.alonginfo.framework.web.domain.AjaxResult;
import com.alonginfo.project.system.service.ISysConfigService;
import com.alonginfo.websocket.server.WebSocketServer;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.HashMap;
import java.util.Map;

/**
 * @Description websocket控制层，负责接受前端的指令然后向全部会话推送
 * @Author Yalon
 * @Date 2020-03-06 10:05
 * @Version mxdata_v
 */
@RestController
@RequestMapping("/business/websocket")
@Slf4j
public class WebSocketController {

    /**
     * 注入socket服务
     */
    @Autowired
    private WebSocketServer webSocketServer;

    @Autowired
    private ISysConfigService sysConfigService;

    /**
     * 推送消息
     * @param jsonMsg
     */
    @GetMapping("/testPush")
    public void list(String jsonMsg) {
        log.info("收到前端推送请求，推送内容为{}", jsonMsg);
        log.info("----开始推送----");
        webSocketServer.sendMessageToAll(jsonMsg);
        log.info("----推送结束----");
    }

    /**
     * 推送消息
     * @param groupId 推送给的主题分组ID，没有则推送全部
     * @param jsonMsg 要推送的消息 可以是JSON 例如 {"cmd":"goto","pageNum":1}
     */
    @PostMapping("/pushMsg")
    public AjaxResult pushMsg(String groupId, String jsonMsg, String themeId) {
        if (StringUtils.isEmpty(groupId)) {
            //为空 推送全部
            webSocketServer.sendMessageToAll(jsonMsg);
        } else {
            //不为空 则 推送给themeId
            webSocketServer.sendMessageToAssignUser(groupId, jsonMsg);
        }
        //解说词
        Map<String, String> introduce = new HashMap<>();
        if (StringUtils.isEmpty(themeId)) {
            return AjaxResult.success(introduce);
        }
        //查询解说词
        String introduceByThemeId = sysConfigService.getIntroduceByThemeId(themeId);
        introduce.put("introduce", introduceByThemeId);
        return AjaxResult.success(introduce);
    }

    /**
     * 请求所有在线主题
     */
    @PostMapping("/getOnlineThemeGroups")
    public AjaxResult getOnlineThemeGroups() {
        return AjaxResult.success(webSocketServer.getOnlineThemeGroups());
    }

    /**
     * 获取websocket地址
     * @return
     */
    @PostMapping("/getWebsocketAddress")
    public AjaxResult getWebsocketAddress() {
        return AjaxResult.success(sysConfigService.selectConfigByKey("websocket.address"));
    }
}
