package com.alonginfo.project.business.mapper;

import com.alonginfo.project.business.domain.MxTableColumn;
import com.alonginfo.project.business.domain.MxTableInfo;
import com.alonginfo.project.system.domain.SysDictData;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;
import java.util.Map;

/**
 * @Description 业务数据管理mapper
 * @Author Yalon
 * @Date 2020-03-16 9:07
 * @Version mxdata_v
 */
@Mapper
public interface MxBusinessDataMapper {

    /**
     * 根据业务表开头关键字集合 查询所有的表名字和备注 TABLE_NAME,TABLE_COMENT
     * @param businessKeys 业务表开头关键字集合
     * @return
     */
    List<MxTableInfo> getTableInfos(List<SysDictData> businessKeys);

    /**
     * 根据表名称获取表的字段信息
     * @param tableName 表名称
     * @return
     */
    List<MxTableColumn> getColumnByTableName(@Param("tableName") String tableName);

    /**
     * 根据表名查找数据
     * @param tableName
     * @return
     */
    List<Map<String, Object>> getTableDataByTableName(@Param("tableName") String tableName);

    /**
     * 根据表名 表主键 主键值删除表数据
     * @param params
     *          tableName 表名 tableKey主键名 keyValue 主键值
     * @return
     */
    Integer removeDataByKey(@Param("params") Map<String, Object> params);

    /**
     * 根据表名 主键名 主键值  数据MAP 更新数据
     * @param params
     * tableName 表名 tableKey主键名 keyValue 主键值 dataMap数据映射
     * @return
     */
    Integer updateDataByKey(@Param("params") Map<String, Object> params);

    /**
     * 根据表名 数据MAP 插入数据
     * @param params
     * tableName 表名  dataMap数据映射
     * @return
     */
    Integer insertData(@Param("params") Map<String, Object> params);

    /**
     * 根据表名获取表注释名称
     * @param tableName
     * @return
     */
    String getTableCNName(String tableName);

    /**
     * 根据表名删除表数据
     * @param tableName
     */
    void delDataByTableName(@Param("tableName") String tableName);
}
