package com.alonginfo.project.business.mapper;

import com.alonginfo.project.business.domain.MxDataGroup;
import com.alonginfo.project.business.domain.MxDataSet;
import com.alonginfo.project.business.domain.MxDataSetKey;
import com.alonginfo.project.business.domain.MxPageGroup;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;
import java.util.Map;

/**
 * @author LM
 * @create 2020-03-05 9:25
 * 数据集管理
 */
@Mapper
public interface MxDataSetMapper {

    /**
     * 获取业务分类列表
     * @return
     */
    List<MxDataGroup> selectMxDataGroupList();

    /**
     * 添加数据集分组
     * @param mxDataGroup
     */
    int addMxDataGroup(MxDataGroup mxDataGroup);

    /**
     * 根据业务id获取数据集
     * @param dGroupId
     * @return
     */
    List<MxDataSet> getDataSetListByDGroupId(String dGroupId);

    /**
     * 添加数据集
     * @param mxDataSet
     * @return
     */
    int addDataSet(MxDataSet mxDataSet);

    /**
     * 根据sql 查询数据（动态sql）
     * @param dataSql
     * @return
     */
    List<Map<String,Object>> executeSql(Map<String, Object> params);

    /**
     * 保存数据集key
     * @param mxDataSetKey
     */
    void addMxDtaSetKey(MxDataSetKey mxDataSetKey);

    /**
     * 根据数据集id 删除相关的key信息
     * @param dsId
     */
    void deleteMxDataSetKeyByDsId(String dsId);

    /**
     * 根据id 删除数据集
     * @param dsId
     * @return
     */
    int deleteMxDataSetById(String dsId);

    /**
     * 删除数据集分组
     * @param dGroupId
     * @return
     */
    int deleteMxDataGroup(String dGroupId);

    /**
     * 修改数据集分组
     * @param mxDataGroup
     * @return
     */
    int editMxDataGroup(MxDataGroup mxDataGroup);

    /**
     * 根据数据集id 获取实例
     * @param dsId
     * @return
     */
    MxDataSet getMxDataSet(String dsId);

    // 获取所有的mx_data_set_key
    List<MxDataSetKey> listMxDataSetKey();
    // 根据page_path 查找主题id+配置信息
    List<MxPageGroup> listPagesByGroupPagePath(String pagePath);
    // 根据数据集分组id 查找数据集及数据集对应的字段列名
    List<MxDataSet> mxDataqueryDataSetBydGroupId(String dGroupId);

    /**
     * 根据查询名称获取数据集
     * @param ajaxId
     * @return
     */
    List<MxDataSet> getDataSetListByAjaxId(@Param("ajaxId") String ajaxId);
}
