package com.alonginfo.project.business.service;

import com.alonginfo.project.business.domain.MxTableColumn;
import com.alonginfo.project.business.domain.MxTableInfo;

import java.util.List;
import java.util.Map;

/**
 * @Description 业务数据管理 业务层接口
 * @Author Yalon
 * @Date 2020-03-16 10:14
 * @Version mxdata_v
 */
public interface IMxBusinessDataService {

    /**
     * 根据业务表开头关键字集合 查询所有的表名字和备注
     * @return 集合 tableName tableComment
     */
    List<MxTableInfo> getTableInfos();

    /**
     * 根据表名称获取表的字段信息
     * @param tableName 表名称
     * @return
     */
    List<MxTableColumn> getColumnByTableName(String tableName);

    /**
     * 根据表名称获取表数据
     * @param tableName 表名称
     * @return
     */
    List<Map<String, Object>> getTableDataByTableName(String tableName);

    /**
     * 根据表名 主键名 主键值  删除数据
     * @param params
     * tableName 表名 tableKey主键名 keyValue 主键值
     * @return
     */
    Integer removeDataByKey(Map<String, Object> params);

    /**
     * 根据表名 主键名 主键值  数据MAP 更新数据
     * @param params
     * tableName 表名 tableKey主键名 keyValue 主键值 dataMap数据映射
     * @return
     */
    Integer updateDataByKey(Map<String, Object> params);

    /**
     * 根据表名 数据MAP 新增数据
     * @param params
     * tableName 表名  dataMap数据映射
     * @return
     */
    Integer insertData(Map<String, Object> params);

    /**
     * 根据表名获取表注释名
     * @param tableName
     * @return
     */
    String getTableCNName(String tableName);

    /**
     * 根据表名删除表数据
     * @param tableName
     */
    void delData(String tableName);
}
