package com.alonginfo.project.business.service;

import com.alonginfo.project.business.domain.MxPageGroup;
import com.alonginfo.project.engine.domain.MxPages;
import com.alonginfo.project.engine.domain.MxProject;

import java.util.List;

/**
 * 分组信息Service接口
 * 
 * @author LM
 * @date 2020-03-10
 */
public interface IMxPageGroupService 
{
    /**
     * 查询分组信息
     * 
     * @param groupId 分组信息ID
     * @return 分组信息
     */
    public MxPageGroup selectMxPageGroupById(String groupId);

    /**
     * 查询分组信息列表
     * 
     * @param mxPageGroup 分组信息
     * @return 分组信息集合
     */
    public List<MxPageGroup> selectMxPageGroupList(MxPageGroup mxPageGroup);

    /**
     * 新增分组信息
     * 
     * @param mxPageGroup 分组信息
     * @return 结果
     */
    public int insertMxPageGroup(MxPageGroup mxPageGroup);

    /**
     * 修改分组信息
     * 
     * @param mxPageGroup 分组信息
     * @return 结果
     */
    public int updateMxPageGroup(MxPageGroup mxPageGroup);



    /**
     * 删除分组信息信息
     * 
     * @param groupId 分组信息ID
     * @return 结果
     */
    public int deleteMxPageGroupById(String groupId);

    /**
     * 删除分组中的主题
     * @param groupId
     * @param themeId
     * @return
     */
    int removePageInGroup(String groupId, String themeId);

    /**
     * 添加主题到分组
     * @param mxPageGroup
     * @return
     */
    int addPageToGroup(MxPageGroup mxPageGroup);

    /**
     * 获取工程列表
     * @return
     */
    List<MxProject> getProjectList();

    /**
     * 根据工程id 获取主题列表
     * @param proId
     * @return
     */
    List<MxPages> getPagesList(String proId);

    /**
     * 修改分组主题排序
     * @param mxPageGroup
     * @return
     */
    int editOrderNum(MxPageGroup mxPageGroup);
}
