package com.alonginfo.project.business.service;

import com.alonginfo.common.exception.job.TaskException;
import com.alonginfo.quartz.domain.SysJob;
import org.quartz.SchedulerException;

import java.util.List;
import java.util.Map;

/**
 * @Description  定时任务 业务层接口
 * @Author Haoxs
 * @Date 2021-04-26 16:19
 */
public interface IMxQuartzService {

    /**
     * 获取全部定时任务列表
     * @param job SysJob对象
     * @return
     */
    List<Map<String, Object>> getQuartzList(SysJob job);

    /**
     * 通过id查询定时任务
     * @param jobId
     * @return
     */
    SysJob selectJobById(Long jobId);

    /**
     * 修改调度任务状态
     * @param job
     * @return
     */
    int changeStatus(SysJob job) throws SchedulerException;

    /**
     * 恢复任务
     * @param job
     * @return
     */
    int resumeJob(SysJob job) throws SchedulerException;

    /**
     * 暂停任务
     * @param job
     * @return
     */
    int pause(SysJob job) throws SchedulerException;

    /**
     * 新增定时任务
     * @param job
     * @return
     */
    int insertJob(SysJob job) throws TaskException, SchedulerException;

    /**
     * 立即运行定时任务
     * @param job
     */
    void runJob(SysJob job) throws SchedulerException;

    /**
     * 立即运行所有定时任务
     * @param jobList
     */
    void runAllJob(List<SysJob> jobList) throws SchedulerException;
}
