package com.alonginfo.project.business.service.impl;

import com.alibaba.fastjson.JSON;
import com.alonginfo.common.utils.StringUtils;
import com.alonginfo.project.business.domain.MxTableColumn;
import com.alonginfo.project.business.domain.MxTableInfo;
import com.alonginfo.project.business.mapper.MxBusinessDataMapper;
import com.alonginfo.project.business.service.IMxBusinessDataService;
import com.alonginfo.project.system.domain.SysDictData;
import com.alonginfo.project.system.mapper.SysDictDataMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * @Description 业务数据管理接口实现
 * @Author Yalon
 * @Date 2020-03-16 10:19
 * @Version mxdata_v
 */
@Service
public class MxBusinessDataServiceImpl implements IMxBusinessDataService {

    /**
     * 系统数据字典参数mapper
     */
    @Autowired
    private SysDictDataMapper sysDictDataMapper;

    /**
     * 业务数据管理mapper
     */
    @Autowired
    private MxBusinessDataMapper mxBusinessDataMapper;

    /**
     * 根据业务表开头关键字集合 查询所有的表名字和备注
     *
     * @return 集合 tableName tableComment
     */
    @Override
    public List<MxTableInfo> getTableInfos() {
        //业务表开头关键字的 dictType
        String dictType = "yw";
        List<SysDictData> sysDictData = sysDictDataMapper.selectDictDataByType(dictType);
        return StringUtils.isEmpty(sysDictData) ? new ArrayList<>() : mxBusinessDataMapper.getTableInfos(sysDictData);
    }

    /**
     * 根据表名称获取表的字段信息
     *
     * @param tableName 表名称
     * @return
     */
    @Override
    public List<MxTableColumn> getColumnByTableName(String tableName) {
        List<MxTableColumn> columnByTableName = mxBusinessDataMapper.getColumnByTableName(tableName);
        List<MxTableColumn> filterList = columnByTableName.stream().filter(item ->  !"tdate".equals(item.getColumnName())
                && !"update_time".equals(item.getColumnName())).collect(Collectors.toList());
        return filterList;
    }

    /**
     * 根据表名称获取表数据
     *
     * @param tableName 表名称
     * @return
     */
    @Override
    public List<Map<String, Object>> getTableDataByTableName(String tableName) {
        List<MxTableInfo> tableInfoList = getTableInfos();
        long count = tableInfoList.stream().filter(mxTableInfo -> tableName.equals(mxTableInfo.getTableName())).count();
        if (count>0){
            return mxBusinessDataMapper.getTableDataByTableName(tableName);
        }
        return new ArrayList<Map<String,Object>>();
    }

    /**
     * 根据表名 主键名 主键值  数据MAP 更新数据
     *
     * @param params tableName 表名 tableKey主键名 keyValue 主键值 dataMap数据映射
     * @return
     */
    @Override
    public Integer removeDataByKey(Map<String, Object> params) {
        List<MxTableInfo> tableInfoList = getTableInfos();
        long count = tableInfoList.stream().filter(mxTableInfo -> params.get("tableName").equals(mxTableInfo.getTableName())).count();
        if (count>0){
            return mxBusinessDataMapper.removeDataByKey(params);
        }
        return 0;
    }

    /**
     * 根据表名 主键名 主键值  数据MAP 更新数据
     *
     * @param params tableName 表名 tableKey主键名 keyValue 主键值 dataMap数据映射
     * @return
     */
    @Override
    public Integer updateDataByKey(Map<String, Object> params) {
        List<MxTableInfo> tableInfoList = getTableInfos();
        long count = tableInfoList.stream().filter(mxTableInfo -> params.get("tableName").equals(mxTableInfo.getTableName())).count();
        if (count>0){
            return mxBusinessDataMapper.updateDataByKey(params);
        }
        return 0;

    }

    /**
     * 根据表名 数据MAP 新增数据
     *
     * @param params tableName 表名 dataMap数据映射
     * @return
     */
    @Override
    public Integer insertData(Map<String, Object> params) {
        List<MxTableInfo> tableInfoList = getTableInfos();
        long count = tableInfoList.stream().filter(mxTableInfo -> params.get("tableName").equals(mxTableInfo.getTableName())).count();
        if (count>0){
            return mxBusinessDataMapper.insertData(params);
        }
        return 0;
    }

    /**
     * 根据表名获取表注释名称
     * @param tableName
     * @return
     */
    @Override
    public String getTableCNName(String tableName) {

        return mxBusinessDataMapper.getTableCNName(tableName);
    }

    /**
     * 根据表名删除表数据
     * @param tableName
     */
    @Override
    public void delData(String tableName) {
        List<MxTableInfo> tableInfoList = getTableInfos();
        long count = tableInfoList.stream().filter(mxTableInfo -> tableName.equals(mxTableInfo.getTableName())).count();
        if (count>0){
            mxBusinessDataMapper.delDataByTableName(tableName);
        }
    }
}
