package com.alonginfo.project.business.service.impl;

import com.alibaba.druid.filter.config.ConfigTools;
import com.alonginfo.common.utils.IdUtils;
import com.alonginfo.project.business.domain.MxDatabase;
import com.alonginfo.project.business.mapper.MxDatabaseMapper;
import com.alonginfo.project.business.service.IMxDatabaseService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * @author Li先生
 * 数据源 业务类
 */
@Service
public class MxDatabaseServiceImpl implements IMxDatabaseService {

    @Autowired
    MxDatabaseMapper mapper;

    /**
     * 获取数据源列表
     */
    @Override
    public List<MxDatabase> selectMxDatabaseList(MxDatabase mxDatabase) {
        return mapper.selectMxDatabaseList(mxDatabase);
    }

    /**
     * 插入信息
     * @param mxDatabase
     * @return
     */
    @Override
    public int insertMxDatabase(MxDatabase mxDatabase) {
        mxDatabase.setId(IdUtils.randomUUID());
        // 密码加密
        try {
            mxDatabase.setPassword(ConfigTools.encrypt(mxDatabase.getPassword()));
        } catch (Exception e) {
            e.printStackTrace();
        }
        return mapper.insertMxDatabase(mxDatabase);
    }

    /**
     * 删除数据
     * @param id
     * @return
     */
    @Override
    public int deleteMxDatabase(String id) {
        return mapper.deleteMxDatabase(id);
    }

    /**
     * 修改数据
     * @param mxDatabase
     * @return
     */
    @Override
    public int editMxDatabase(MxDatabase mxDatabase) {
        try {
            mxDatabase.setPassword(ConfigTools.encrypt(mxDatabase.getPassword()));
        } catch (Exception e) {
            //e.printStackTrace();
        }
        return mapper.editMxDatabase(mxDatabase);
    }

    /**
     * 根据id获取对象
     * @param id
     * @return
     */
    @Override
    public MxDatabase getMxDatabase(String id) {
        MxDatabase mxDatabase =  mapper.getMxDatabase(id);
        // 密码解密
        try {
            mxDatabase.setPassword(ConfigTools.decrypt(mxDatabase.getPassword()));
        } catch (Exception e) {
            e.printStackTrace();
        }
        return mxDatabase;
    }

}
