package com.alonginfo.project.business.service.impl;

import com.alonginfo.common.utils.IdUtils;
import com.alonginfo.project.business.domain.MxGroupSetting;
import com.alonginfo.project.business.mapper.MxGroupSettingMapper;
import com.alonginfo.project.business.service.IMxGroupSettingService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 配置Service业务层处理
 * 
 * @author LM
 * @date 2020-03-10
 */
@Service
public class MxGroupSettingServiceImpl implements IMxGroupSettingService 
{
    @Autowired
    private MxGroupSettingMapper mxGroupSettingMapper;

    /**
     * 查询配置
     * 
     * @param settingId 配置ID
     * @return 配置主
     */
    @Override
    public MxGroupSetting selectMxGroupSettingById(String settingId)
    {
        return mxGroupSettingMapper.selectMxGroupSettingById(settingId);
    }

    /**
     * 查询配置列表
     * 
     * @param mxGroupSetting 配置
     * @return 配置
     */
    @Override
    public List<MxGroupSetting> selectMxGroupSettingList(MxGroupSetting mxGroupSetting)
    {
        return mxGroupSettingMapper.selectMxGroupSettingList(mxGroupSetting);
    }

    /**
     * 新增配置
     * 
     * @param mxGroupSetting 配置
     * @return 结果
     */
    @Override
    public int insertMxGroupSetting(MxGroupSetting mxGroupSetting)
    {
        mxGroupSetting.setSettingId(IdUtils.fastUUID());
        return mxGroupSettingMapper.insertMxGroupSetting(mxGroupSetting);
    }

    /**
     * 修改配置
     * 
     * @param mxGroupSetting 配置
     * @return 结果
     */
    @Override
    public int updateMxGroupSetting(MxGroupSetting mxGroupSetting)
    {
        return mxGroupSettingMapper.updateMxGroupSetting(mxGroupSetting);
    }


    /**
     * 删除配置信息
     * 
     * @param settingId 配置ID
     * @return 结果
     */
    @Override
    public int deleteMxGroupSettingById(String settingId)
    {
        return mxGroupSettingMapper.deleteMxGroupSettingById(settingId);
    }
}
