package com.alonginfo.project.business.service.impl;

import com.alonginfo.project.business.mapper.MxIntroduceMapper;
import com.alonginfo.project.business.service.IMxIntroduceService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * @Description 解说词管理 业务层实现
 * @Author Yalon
 * @Date 2020-11-18 17:31
 * @Version mxdata_v
 */
@Service
public class MxIntroduceServiceImpl implements IMxIntroduceService {

    @Autowired
    private MxIntroduceMapper introduceMapper;


    /**
     * 获取所有的工程及工程下的主题
     *
     * @return
     */
    @Override
    public List<Map<String, Object>> getProjectPage() {
        return introduceMapper.selectProject().stream().peek(map -> map.put("pages", introduceMapper.selectPageByProject((String) map.get("proId")))).collect(Collectors.toList());
    }

    /**
     * 根据主题ID 获取解说词
     *
     * @param pageId 主题ID
     * @return
     */
    @Override
    public Map<String, Object> getIntroduceByPage(String pageId) {
        return introduceMapper.selectIntroduceByPage(pageId);
    }

    /**
     * 保存解说词
     *
     * @param pageId    主题ID
     * @param introduce 解说词
     */
    @Override
    public void saveIntroduce(String pageId, String introduce) {
        introduceMapper.updateIntroduce(pageId, introduce);
    }
}
