package com.alonginfo.project.business.service.impl;

import com.alonginfo.common.utils.DateUtils;
import com.alonginfo.common.utils.IdUtils;
import com.alonginfo.project.business.domain.MxPageGroup;
import com.alonginfo.project.business.mapper.MxPageGroupMapper;
import com.alonginfo.project.business.service.IMxPageGroupService;
import com.alonginfo.project.engine.domain.MxPages;
import com.alonginfo.project.engine.domain.MxProject;
import com.alonginfo.project.engine.domain.ThemeManager;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 分组信息Service业务层处理
 * 
 * @author LM
 * @date 2020-03-10
 */
@Service
public class MxPageGroupServiceImpl implements IMxPageGroupService 
{
    @Autowired
    private MxPageGroupMapper mxPageGroupMapper;

    /**
     * 查询分组信息
     * 
     * @param groupId 分组信息ID
     * @return 分组信息
     */
    @Override
    public MxPageGroup selectMxPageGroupById(String groupId)
    {
        return mxPageGroupMapper.selectMxPageGroupById(groupId);
    }

    /**
     * 查询分组信息列表
     * 
     * @param mxPageGroup 分组信息
     * @return 分组信息
     */
    @Override
    public List<MxPageGroup> selectMxPageGroupList(MxPageGroup mxPageGroup)
    {
        return mxPageGroupMapper.selectMxPageGroupList(mxPageGroup);
    }

    /**
     * 新增分组信息
     * 
     * @param mxPageGroup 分组信息
     * @return 结果
     */
    @Override
    public int insertMxPageGroup(MxPageGroup mxPageGroup)
    {   // 设置id
        mxPageGroup.setGroupId(IdUtils.fastUUID());
        // 设置访问path
        mxPageGroup.setPagePath("/"+DateUtils.dateTimeNow());
        return mxPageGroupMapper.insertMxPageGroup(mxPageGroup);
    }

    /**
     * 修改分组信息
     * 
     * @param mxPageGroup 分组信息
     * @return 结果
     */
    @Override
    public int updateMxPageGroup(MxPageGroup mxPageGroup)
    {
        return mxPageGroupMapper.updateMxPageGroup(mxPageGroup);
    }



    /**
     * 删除分组信息信息
     * 
     * @param groupId 分组信息ID
     * @return 结果
     */
    @Override
    public int deleteMxPageGroupById(String groupId)
    {
        // 先删除分组&主题中间表信息
        mxPageGroupMapper.deleteMxPageMidGroupByGroupId(groupId);
        return mxPageGroupMapper.deleteMxPageGroupById(groupId);
    }

    /**
     * 删除分组中的主题
     * @param groupId
     * @param themeId
     * @return
     */
    @Override
    public int removePageInGroup(String groupId, String themeId) {
        return mxPageGroupMapper.removePageInGroup(groupId,themeId);
    }

    /**
     * 添加主题到分组
     * @param mxPageGroup
     * @return
     */
    @Override
    public int addPageToGroup(MxPageGroup mxPageGroup) {
        // 获取分组id
        String groupId = mxPageGroup.getGroupId();
        // 获取分组中主题排序最大值
        int maxOrderNum = getMaxOrderNum(groupId);
        // 获取所有主题
        List<ThemeManager> themeManagers = mxPageGroup.getThemeManagers();
        for (int i = 0; i < themeManagers.size(); i++) {
            themeManagers.get(i).setOrderNum(++maxOrderNum);
        }
        return mxPageGroupMapper.addPageToGroup(mxPageGroup);
    }

    /**
     * 根据分组id 获取最大排序只（如果没有新增分组 返回0）
     * @param groupId
     * @return
     */
    private int getMaxOrderNum(String groupId) {
        return mxPageGroupMapper.getMaxOrderNum(groupId);
    }

    /**
     * 获取工程列表
     * @return
     */
    @Override
    public List<MxProject> getProjectList() {
        return mxPageGroupMapper.getProjectList();
    }
    /**
     * 根据工程id 获取主题列表
     * @param proId
     * @return
     */
    @Override
    public List<MxPages> getPagesList(String proId) {
        return mxPageGroupMapper.getPagesList(proId);
    }

    /**
     * 修改分组主题排序
     * @param mxPageGroup
     * @return
     */
    @Override
    public int editOrderNum(MxPageGroup mxPageGroup) {
        // 获取分组groupId
        String groupId = mxPageGroup.getGroupId();
        // 获取
        List<ThemeManager> themeManagers = mxPageGroup.getThemeManagers();
        // 排序
        for (int j = 0; j <themeManagers.size() ; j++) {
             mxPageGroupMapper.editOrderNum(groupId,themeManagers.get(j).getThemeId(),j+1);
        }
        return 1;
    }
}
