package com.alonginfo.project.business.service.impl;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.alonginfo.framework.datasource.DynamicDataSource;
import com.alonginfo.framework.datasource.DynamicDataSourceContextHolder;
import com.alonginfo.framework.redis.RedisCache;
import com.alonginfo.framework.web.domain.AjaxResult;
import com.alonginfo.project.business.domain.*;
import com.alonginfo.project.business.mapper.MxDataSetMapper;
import com.alonginfo.project.business.mapper.MxPageGroupMapper;
import com.alonginfo.project.business.service.IMxShowDataSetService;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.*;

/**
 * @author Li先生
 */
@Service
@Slf4j
public class MxShowDataSetImpl implements IMxShowDataSetService {

    @Autowired
    RedisCache redisCache;
    @Autowired
    MxDataSetMapper dataSetMapper;

    @Autowired
    MxPageGroupMapper pageGroupMapper;

    // 获取数据
    @Override
    public AjaxResult getData(MxDataInfo mxDataInfo) {
        // 数据格式类型
        Integer type = mxDataInfo.getType();
        // type==1  name:[]  value:[]
        if (type == 1) {
            JSONArray result =  initDataType1(mxDataInfo);
            return AjaxResult.success(result);
        }
        // type==2  label:[]  value:[]
        if (type == 2) {
            JSONArray result =  initDataType2(mxDataInfo);
            return AjaxResult.success(result);
        }

        // type==3  value:[]
        if (type == 3) {
            JSONArray result =  initDataType3(mxDataInfo);
            return AjaxResult.success(result);
        }

        return AjaxResult.error("type错误");
    }

    // 查询数据集所有分组列表
    @Override
    public List<MxDataGroup> mxDataqueryGroup() {
        return  dataSetMapper.selectMxDataGroupList();
    }

    // 根据page_path 查找主题id+配置信息
    @Override
    public List<MxPageGroup> listPagesByGroupPagePath(String pagePath) {
        return  pageGroupMapper.listPagesByGroupPagePath(pagePath);
    }
    // 根据数据集分组id 查找数据集及数据集对应的字段列名
    @Override
    public List<MxDataSet> mxDataqueryDataSetBydGroupId(String dGroupId) {
        return  dataSetMapper.mxDataqueryDataSetBydGroupId(dGroupId);
    }

    //根据数据集查询名称和参数查询数据集
    @Override
    public AjaxResult getDataByAjaxId(MxDataSet mxDataSetQuery) {
        List<MxDataSet> sets = dataSetMapper.getDataSetListByAjaxId(mxDataSetQuery.getAjaxId());
        if (sets.size() != 1) {
            return AjaxResult.error("根据此查询别名查出的数据集不是一条！");
        }
        MxDataSet mxDataSet = sets.get(0);
        mxDataSet.setParam(mxDataSetQuery.getParam());
        // 切换数据源
        DynamicDataSourceContextHolder.setDataSourceType(mxDataSet.getDatabaseId());
        Map<String, Object> params = new HashMap<>();
        try {
            params = JSONObject.parseObject(Optional.ofNullable(mxDataSet.getParam()).orElse("{}"), Map.class);
        } catch (Exception e) {
            log.info("数据集参数格式有误！");
        }
        params.put("dataSql", mxDataSet.getDataSql());
        // 执行sql
        return AjaxResult.success(dataSetMapper.executeSql(params));
    }

    // 加载数据 type==1
    private JSONArray initDataType1(MxDataInfo mxDataInfo){
        // 返回值
        JSONArray result = new JSONArray();
        // name value
        List<String> nameKeyNameList = transforKeyIds(mxDataInfo.getName());
        List<String> valueKeyNametList = transforKeyIds(mxDataInfo.getValue());
        // 获取mxDataSet
        MxDataSet mxDataSet = dataSetMapper.getMxDataSet(mxDataInfo.getDsId());

        // 切换数据源
        DynamicDataSourceContextHolder.setDataSourceType(mxDataSet.getDatabaseId());

        Map<String, Object> params = new HashMap<>();
        try {
            params = JSONObject.parseObject(Optional.ofNullable(mxDataSet.getParam()).orElse("{}"), Map.class);
        } catch (Exception e) {
            log.info("数据集参数格式有误！");
        }
        params.put("dataSql", mxDataSet.getDataSql());
        // 执行sql
        List<Map<String, Object>> mapData= dataSetMapper.executeSql(params);
        // 遍历 组合数据
        mapData.stream().forEach(map->{
            JSONObject entity = new JSONObject();
            transforkeyNameToData(nameKeyNameList,"name",map,entity);
            transforkeyNameToDataArr(valueKeyNametList,"value",map,entity);
            result.add(entity);
        });
        DynamicDataSourceContextHolder.clearDataSourceType();
        return  result;
    }
    // 加载数据 type==2
    private JSONArray initDataType2(MxDataInfo mxDataInfo){
        // 返回值
        JSONArray result  = new JSONArray();
        // name value
        List<String> labelKeyNameList = transforKeyIds(mxDataInfo.getLabel());
        List<String> valueKeyNametList = transforKeyIds(mxDataInfo.getValue());
        // 获取mxDataSet
        MxDataSet mxDataSet = dataSetMapper.getMxDataSet(mxDataInfo.getDsId());
        // 获取sql
        String sql =  mxDataSet.getDataSql();
        // 切换数据源
        DynamicDataSourceContextHolder.setDataSourceType(mxDataSet.getDatabaseId());

        Map<String, Object> params = new HashMap<>();
        try {
            params = JSONObject.parseObject(Optional.ofNullable(mxDataSet.getParam()).orElse("{}"), Map.class);
        } catch (Exception e) {
            log.info("数据集参数格式有误！");
        }
        params.put("dataSql", mxDataSet.getDataSql());
        // 执行sql
        List<Map<String, Object>> mapData= dataSetMapper.executeSql(params);
        // 遍历 组合数据
        mapData.stream().forEach(map->{
            JSONObject entity = new JSONObject();
            transforkeyNameToData(labelKeyNameList,"label",map,entity);
            transforkeyNameToDataArr(valueKeyNametList,"value",map,entity);
            result.add(entity);
        });
        DynamicDataSourceContextHolder.clearDataSourceType();
        return  result;
    }
    // value : 1212.22
    private JSONArray initDataType3(MxDataInfo mxDataInfo){
        // 返回值
        JSONArray result  = new JSONArray();
        // 获取key_name
        List<String> valueKeyNametList = transforKeyIds(mxDataInfo.getValue());
        // 获取mxDataSet
        MxDataSet mxDataSet = dataSetMapper.getMxDataSet(mxDataInfo.getDsId());
        // 获取sql
        String sql =  mxDataSet.getDataSql();
        // 切换数据源
        DynamicDataSourceContextHolder.setDataSourceType(mxDataSet.getDatabaseId());

        Map<String, Object> params = new HashMap<>();
        try {
            params = JSONObject.parseObject(Optional.ofNullable(mxDataSet.getParam()).orElse("{}"), Map.class);
        } catch (Exception e) {
            log.info("数据集参数格式有误！");
        }
        params.put("dataSql", mxDataSet.getDataSql());
        // 执行sql
        List<Map<String, Object>> mapData= dataSetMapper.executeSql(params);
        // 遍历 组合数据
        mapData.stream().forEach(map->{
            JSONObject entity = new JSONObject();
            transforkeyNameToData(valueKeyNametList,"value",map,entity);
            result.add(entity);
        });
        DynamicDataSourceContextHolder.clearDataSourceType();
        return  result;
    }
    // key_id  --> key_name
    private List<String> transforKeyIds(List<String> keyIdList) {
        List<String> keyNameList = new ArrayList<>();
        keyIdList.stream().forEach(keyId->{
            // 根据name的key 获取 value  1000->年份
            String keyName = getValue(keyId);
            keyNameList.add(keyName);
        });
        return keyNameList;
    }
    // 列名+数据集 --》指定格式数据  --》 一个的情况下 变为字符串
    private  void transforkeyNameToData(List<String> colNames,String labelName,Map<String,Object> data,JSONObject entity ){
        JSONObject jsonObject = new JSONObject();
        if (colNames.size() == 1) {
            entity.put(labelName,data.get(colNames.get(0)));
        } else {
            JSONArray nameArr = new JSONArray();
            colNames.stream().forEach(name->{
                nameArr.add(data.get(name));
            });
            entity.put(labelName,nameArr);
        }
    }

    // 列名+数据集 --》指定格式数据  --》 一个的情况下 变为数组
    private  void transforkeyNameToDataArr(List<String> colNames,String labelName,Map<String,Object> data,JSONObject entity ){
        JSONObject jsonObject = new JSONObject();
            JSONArray nameArr = new JSONArray();
            colNames.stream().forEach(name->{
                nameArr.add(data.get(name));
            });
            entity.put(labelName,nameArr);
    }

    // 根据key id 获取列名称
    private String getValue(String name){
       String value = redisCache.getCacheMapValue("mx_data_set_key",name);
       // 如果redis没有中 去数据库查询
       if (value == null) {
            Map<String,String> map = new HashMap<>();
            List<MxDataSetKey> list =dataSetMapper.listMxDataSetKey();
            list.stream().forEach(mxDataSetKey -> {
                map.put(mxDataSetKey.getKeyId(),mxDataSetKey.getKeyName());
            });
            // 放到缓存中
            redisCache.setCacheMap("mx_data_set_key",map);
            value = map.get(name);
       }
       return value;
    }
}
