package com.alonginfo.project.business.service.impl;

import com.alonginfo.project.business.mapper.YwMonthTransactionMapper;
import com.alonginfo.project.business.service.YwMonthTransactionService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @Description 月度直接交易service实现
 * @Author Haoxs
 * @Date 2021-10-21 18:32
 */
@Service
public class YwMonthTransactionServiceImpl implements YwMonthTransactionService {

    @Autowired
    private YwMonthTransactionMapper ywMonthTransactionMapper;

    /**
     * 获取月度直接交易列表
     * @return
     */
    @Override
    public List<Map<String, String>> getTransactionList() {
        return ywMonthTransactionMapper.getTransactionList();
    }

    /**
     * 获取月度交易明细
     * @param transactionName
     * @return
     */
    @Override
    public Map<String, Object> getTransactionDetailed(String transactionName) {
        if (transactionName == null || "".equals(transactionName)) {
            return new HashMap<>();
        }
        //获取交易月份
        String month = transactionName.split("年")[1].substring(0, 1);
        //判断当月是否包含月内交易
        String monthFlag = transactionName.contains("月内") ? "月内" : "";
        //判断是燃煤交易还是燃气交易
        Integer transactionType = transactionName.contains("燃煤") ? 300 : 500;
        //交易公告
        Map<String, Object> transactionNotice = ywMonthTransactionMapper.getTransactionNotice(transactionName);
        //购方数据
        Map<String, Object> buyData = ywMonthTransactionMapper.getBuyerData(month, monthFlag, transactionType);
        List<Map<String, Object>> buyDet = ywMonthTransactionMapper.getBuyerDet(month, monthFlag, transactionType);
        //售方数据
        Map<String, Object> sellData = ywMonthTransactionMapper.getSellerData(month, monthFlag, transactionType);
        List<Map<String, Object>> sellDet = ywMonthTransactionMapper.getSellerDet(month, monthFlag, transactionType);

        //结果封装
        buyData.put("buyDet", buyDet);
        sellData.put("sellDet", sellDet);
        Map<String, Object> resultMap = new HashMap<>();
        resultMap.put("transactionNotice", transactionNotice);
        resultMap.put("buyData", buyData);
        resultMap.put("sellData", sellData);
        return resultMap;
    }
}
