package com.alonginfo.project.common;

import com.alonginfo.common.utils.FileTypeDetector;
import com.alonginfo.common.utils.StringUtils;
import com.alonginfo.project.tool.FileUtil;
import com.alonginfo.utils.FileUploadUtils;
import com.alonginfo.common.utils.file.FileUtils;
import com.alonginfo.framework.config.MxConfig;
import com.alonginfo.framework.config.ServerConfig;
import com.alonginfo.framework.web.domain.AjaxResult;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;

/**
 * 通用请求处理
 */
@RestController
public class CommonController {
    private static final Logger log = LoggerFactory.getLogger(CommonController.class);

    @Autowired
    private ServerConfig serverConfig;

    static String[] validExtensions = {"xlsx","xls","docx","doc","txt","mp4","mov","jpg","gif","png"};

    /**
     * 通用下载请求
     * 
     * @param fileName 文件名称
     * @param delete 是否删除
     */
//    @GetMapping("common/download")
//    public void fileDownload(String fileName, Boolean delete, HttpServletResponse response, HttpServletRequest request) {
//        try {
//            if (!FileUtils.isValidFilename(fileName)) {
//                throw new Exception(StringUtils.format("文件名称({})非法，不允许下载。 ", fileName));
//            }
//            //文件名称 例如甘肃电力交易中心
//            String fileNamePrefix = fileName.substring(fileName.indexOf("_") + 1).split("\\.")[0];
//            //后缀 .xlsx
//            String fileNameSuffix = "." + fileName.substring(fileName.indexOf("_") + 1).split("\\.")[1];
//            String realFileName =  fileNamePrefix + System.currentTimeMillis() + fileNameSuffix;
//            String filePath = MxConfig.getDownloadPath() + fileName;
//
//            response.setCharacterEncoding("utf-8");
//            response.setContentType("multipart/form-data");
////            response.setHeader("Content-Disposition",
////                    "attachment;fileName=" + FileUtils.setFileDownloadHeader(request, realFileName));
//            FileUtils.writeBytes(filePath, response.getOutputStream());
//            if (delete) {
//                FileUtils.deleteFile(filePath);
//            }
//        } catch (Exception e) {
//            log.error("下载文件失败", e);
//        }
//    }

    /**
     * 通用上传请求
     */
    @PostMapping("/common/upload")
    public AjaxResult uploadFile(MultipartFile file) throws Exception {
        try {
            // 上传文件路径
            String filePath = MxConfig.getUploadPath();
            String fileName2 = file.getOriginalFilename();
            String extension = "";
            boolean validExtension = false;
            boolean validExtension2 = false;
            if (fileName2 != null && fileName2.contains(".")) {
                extension = fileName2.substring(fileName2.lastIndexOf("."));
                String fileType = FileTypeDetector.getFileType(file);
                validExtension = FileUtil.isValidExtension(extension, validExtensions);
                validExtension2 = FileUtil.isValidExtension(fileType, validExtensions);
            }
            AjaxResult ajax = AjaxResult.success();
            if(validExtension && validExtension2){
                String fileName = FileUploadUtils.upload(filePath, file);
                String url = serverConfig.getUrl() + fileName;
                ajax.put("fileName", fileName);
                ajax.put("url", url);
            }
            // 上传并返回新文件名称
            return ajax;
        } catch (Exception e) {
            e.printStackTrace();
            return AjaxResult.error("上传失败");
        }
    }

    /**
     * 通用上传请求
     */
    @PostMapping("/common/uploadMedia")
    public AjaxResult uploadMedia(MultipartFile file) throws Exception {
        try {
            // 上传文件路径
            String filePath = MxConfig.getUploadPath();
            String fileName2 = file.getOriginalFilename();
            String extension = "";
            boolean validExtension = false;
            if (fileName2 != null && fileName2.contains(".")) {
                extension = fileName2.substring(fileName2.lastIndexOf("."));
                validExtension = FileUtil.isValidExtension(extension, validExtensions);
            }
            AjaxResult ajax = AjaxResult.success();
            // 上传并返回新文件名称
            if(validExtension){
                String fileName = FileUploadUtils.uploadMedia(filePath, file);
                String url = serverConfig.getUrl() + fileName;
                ajax.put("fileName", fileName);
                ajax.put("url", url);
            }
            return ajax;
        } catch (Exception e) {
            e.printStackTrace();
            return AjaxResult.error("操作失败");
        }
    }
}
