package com.alonginfo.project.engine.controller;

import com.alonginfo.common.constant.DatavConstans;
import com.alonginfo.common.utils.IdUtils;
import com.alonginfo.common.utils.StringUtils;
import com.alonginfo.framework.aspectj.lang.annotation.Log;
import com.alonginfo.framework.aspectj.lang.enums.BusinessType;
import com.alonginfo.framework.web.controller.BaseController;
import com.alonginfo.framework.web.domain.AjaxResult;
import com.alonginfo.project.engine.domain.MxPages;
import com.alonginfo.project.engine.service.IMxPagesService;
import com.alonginfo.utils.SecurityUtils;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Api(value="主题页面，信息操作处理")
@RestController
@RequestMapping("/engine/mxPages")
public class MxPagesController extends BaseController {

    @Autowired
    private IMxPagesService mxPageService;

    /**
     * 获取主题页面
     * @param mxPages
     * @return
     */
    @ApiOperation("获取所有主题页面")
    @GetMapping("/getPages")
    public AjaxResult getPages (MxPages mxPages) {
        List<MxPages> listPages = mxPageService.getPagesForId(mxPages);
        return AjaxResult.success(listPages);
    }


    /**
     * 新增主题页
     * @param mxPages
     * @return
     */
    @ApiOperation("新增主题页")
    @PostMapping("/addPages")
    public AjaxResult addPages(@Validated @RequestBody MxPages mxPages){
        if (DatavConstans.NOT_UNIQUE.equals(mxPageService.checkPageNameUnique(mxPages))){
            return AjaxResult.error("新增页面'" + mxPages.getPageName() + "'失败，名称已存在");
        }
        mxPages.setPageId(IdUtils.simpleUUID());
        mxPages.setCreateBy(SecurityUtils.getUsername());
        return toAjax(mxPageService.insertPages(mxPages));
    }

    /**
     * 更新工程信息
     * @param mxPages
     * @return
     */
    @ApiOperation("修改工程页面信息")
    @PutMapping("/updatePages")
    public AjaxResult updatePages(@Validated @RequestBody MxPages mxPages){
        if (DatavConstans.NOT_UNIQUE.equals(mxPageService.checkPageNameUnique(mxPages))){
            return AjaxResult.error("更新页面'" + mxPages.getPageName() + "'失败，名称已存在");
        }
        return toAjax(mxPageService.updatePages(mxPages));
    }

    /**
     * 主题发布
     * @param mxPages
     * @return
     */
    @ApiOperation("主题发布接口")
    @PutMapping("/releasePage")
    public AjaxResult releasePage(@Validated @RequestBody MxPages mxPages){
        return toAjax(mxPageService.releasePage(mxPages));
    }

    /**
     * 删除主题
     * @param pageId
     * @return
     */
    @Log(title = "删除主题", businessType = BusinessType.DELETE)
    @DeleteMapping("/mxDeletePage/{pageId}")
    public AjaxResult remove(@PathVariable String pageId){
        return toAjax(mxPageService.mxDeletePage(pageId));
    }


}
