package com.alonginfo.project.engine.controller;

import com.alonginfo.common.constant.DatavConstans;
import com.alonginfo.common.utils.IdUtils;
import com.alonginfo.framework.aspectj.lang.annotation.Log;
import com.alonginfo.framework.aspectj.lang.enums.BusinessType;
import com.alonginfo.framework.web.controller.BaseController;
import com.alonginfo.framework.web.domain.AjaxResult;
import com.alonginfo.framework.web.page.TableDataInfo;
import com.alonginfo.project.engine.domain.MxProject;
import com.alonginfo.project.engine.service.IMxProjectService;
import com.alonginfo.utils.SecurityUtils;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 工程管理 控制成
 * @author shidj
 */

@Api(value="工程管理，信息操作处理")
@RestController
@RequestMapping("/engine/mxProject")
public class MxProjectController extends BaseController {

    @Autowired
    private IMxProjectService mxProjectService;

    /**
     * 工程管理列表
     * @param mxProject
     * @return
     */
    @ApiOperation("获取工程管理列表")
    @PreAuthorize("@ss.hasPermi('engine:mxProject:list')")
    @GetMapping("/list")
    public TableDataInfo list(MxProject mxProject) {
        startPage();
        String userName = SecurityUtils.getUsername();
        mxProject.setCreateBy(userName);
        mxProject.setUserId(SecurityUtils.getUserId());
        List<MxProject> list = mxProjectService.selectProject(mxProject);
        return getDataTable(list);
    }

    /**
     * 新增工程
     * @param mxProject
     * @return
     */
    @ApiOperation("新增工程")
    @PreAuthorize("@ss.hasPermi('engine:mxProject:add')")
    @Log(title = "工程管理", businessType = BusinessType.INSERT)
    @PostMapping("/addProject")
    public AjaxResult addProject(@Validated @RequestBody MxProject mxProject){
        if (DatavConstans.NOT_UNIQUE.equals(mxProjectService.checkProjectNameUnique(mxProject))){
            return AjaxResult.error("新增工程'" + mxProject.getProName() + "'失败，工程名称已存在");
        }
        mxProject.setProId(IdUtils.simpleUUID());
        // 新增时默认状态为开启
        mxProject.setProState("0");
        mxProject.setCreateBy(SecurityUtils.getUsername());
        return toAjax(mxProjectService.insertMxProject(mxProject));
    }

    /**
     * 获取信息
     * @param proId
     * @return
     */
    @GetMapping(value = "/getmxProjectKey/{proId}")
    public AjaxResult getInfo(@PathVariable String proId) {
        return AjaxResult.success(mxProjectService.getInfo(proId));
    }

    /**
     * 工程信息修改
     * @param mxProject
     * @return
     */
    @ApiOperation("修改工程信息")
    @PreAuthorize("@ss.hasPermi('engine:mxProject:edit')")
    @Log(title = "工程管理", businessType = BusinessType.UPDATE)
    @PutMapping("/updateMxProject")
    public AjaxResult updateMxProject(@Validated @RequestBody MxProject mxProject){
        if (DatavConstans.NOT_UNIQUE.equals(mxProjectService.checkProjectNameUnique(mxProject))){
            return AjaxResult.error("修改工程'" + mxProject.getProName() + "'失败，工程名称已存在");
        }
        mxProject.setUpdateBy(SecurityUtils.getUsername());
        return toAjax(mxProjectService.updateMxProject(mxProject));
    }

    /**
     * 删除工程
     * @param proIds
     * @return
     */
    @PreAuthorize("@ss.hasPermi('engine:themeMamager:remove')")
    @Log(title = "删除工程", businessType = BusinessType.DELETE)
    @DeleteMapping("/delMxPorject/{proIds}")
    public AjaxResult remove(@PathVariable String[] proIds){
        return toAjax(mxProjectService.delMxPorject(proIds));
    }

    /**
     * 改变工程状态
     * @param mxProject
     * @return
     */
    @ApiOperation("改变工程状态")
    @GetMapping("/changeProState")
    public AjaxResult changeProState(MxProject mxProject) {
        return toAjax(mxProjectService.changeProState(mxProject));
    }
}
