package com.alonginfo.project.engine.controller;

import com.alonginfo.common.constant.DatavConstans;
import com.alonginfo.common.utils.IdUtils;
import com.alonginfo.framework.aspectj.lang.annotation.Log;
import com.alonginfo.framework.aspectj.lang.enums.BusinessType;
import com.alonginfo.framework.web.controller.BaseController;
import com.alonginfo.framework.web.domain.AjaxResult;
import com.alonginfo.framework.web.page.TableDataInfo;
import com.alonginfo.project.engine.domain.ThemeManager;
import com.alonginfo.project.engine.service.IThemeManagerService;
import com.alonginfo.utils.SecurityUtils;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 主推管理Controller
 * @author shidj
 */

@Api(value="主题管理，信息操作处理")
@RestController
@RequestMapping("/engine/themeManager")
public class ThemeManagerController extends BaseController {

    @Autowired
    private IThemeManagerService themeManagerService;

    @ApiOperation("获取图表主题管理列表")
    @PreAuthorize("@ss.hasPermi('engine:themeMamager:list')")
    @GetMapping("/list")
    public TableDataInfo list(ThemeManager themeManager) {
        startPage();
        Long userId = SecurityUtils.getUserId();
        themeManager.setUserId(userId);
        List<ThemeManager> list = themeManagerService.selectThemeManagerList(themeManager);
        return getDataTable(list);
    }

    /**
     * 获取当前用户创建的所有主题
     * @param themeManager
     * @return
     */
    @ApiOperation("获取当前用户创建的所有主题")
    @GetMapping("/allList")
    public AjaxResult allList(ThemeManager themeManager) {
        Long userId = SecurityUtils.getUserId();
        themeManager.setUserId(userId);
        List<ThemeManager> list = themeManagerService.selectThemeManagerList(themeManager);
        return AjaxResult.success(list);
    }


    /**
     * 新增图表主题
     * @param themeManager
     * @return
     */
    @ApiOperation("新增图表主题")
    @PreAuthorize("@ss.hasPermi('engine:themeMamager:add')")
    @Log(title = "图表主题管理", businessType = BusinessType.INSERT)
    @PostMapping("/addTheme")
    public AjaxResult addTheme(@Validated @RequestBody ThemeManager themeManager) {
        if (DatavConstans.NOT_UNIQUE.equals(themeManagerService.checkThemeNameUnique(themeManager))){
            return AjaxResult.error("新增图表主题'" + themeManager.getThemeName() + "'失败，主题名称已存在");
        }
        themeManager.setThemeId(IdUtils.simpleUUID());
        themeManager.setUserId(SecurityUtils.getUserId());
        return toAjax(themeManagerService.insertThemeManager(themeManager));
    }

    /**
     * 根据图表主题id获取信息
     * @param themeId
     * @return
     */
    @GetMapping(value = "/chartThememKey/{themeId}")
    public AjaxResult getInfo(@PathVariable String themeId) {
        return AjaxResult.success(themeManagerService.getInfoChartThemeId(themeId));
    }

    /**
     * 修改图表主题
     * @param themeManager
     * @return
     */
    @ApiOperation("修改图表主题")
    @PreAuthorize("@ss.hasPermi('engine:themeMamager:edit')")
    @Log(title = "图表主题管理", businessType = BusinessType.UPDATE)
    @PutMapping("/updateChartTheme")
    public AjaxResult updateChartTheme(@Validated @RequestBody ThemeManager themeManager) {
        if (DatavConstans.NOT_UNIQUE.equals(themeManagerService.checkThemeNameUnique(themeManager))){
            return AjaxResult.error("修改图表主题'" + themeManager.getThemeName() + "'失败，主题名称已存在");
        }
        return toAjax(themeManagerService.updateThemeManager(themeManager));
    }

    /**
     * 删除图表主题
     * @param themeIds
     * @return
     */
    @PreAuthorize("@ss.hasPermi('engine:themeMamager:remove')")
    @Log(title = "图表主题管理", businessType = BusinessType.DELETE)
    @DeleteMapping("/delChartTheme/{themeIds}")
    public AjaxResult remove(@PathVariable String[] themeIds){
        return toAjax(themeManagerService.delChartTheme(themeIds));
    }

}

