package com.alonginfo.project.engine.service.impl;

import com.alonginfo.common.constant.DatavConstans;
import com.alonginfo.common.utils.StringUtils;
import com.alonginfo.project.engine.domain.MxPages;
import com.alonginfo.project.engine.domain.MxProject;
import com.alonginfo.project.engine.mapper.MxPagesMapper;
import com.alonginfo.project.engine.mapper.MxProjectMapper;
import com.alonginfo.project.engine.service.IMxProjectService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 工程管理 实现层
 */
@Service
public class MxProjectServiceImpl implements IMxProjectService {

    @Autowired
    private MxProjectMapper mxProjectMapper;

    @Autowired
    private MxPagesMapper pagesMapper;

    /**
     * 工程列表
     * @param mxProject
     * @return
     */
    @Override
    public List<MxProject> selectProject(MxProject mxProject) {
        List<MxProject> proList = mxProjectMapper.selectProject(mxProject);
        proList.stream().forEach( mxPro -> {
            MxPages mx = new MxPages();
            mx.setProId(mxPro.getProId());
            mxPro.setPageInfo(pagesMapper.getPages(mx));
        });
        return proList;
    }

    /**
     * 检测工程名是否唯一
     * @param mxProject
     * @return
     */
    @Override
    public String checkProjectNameUnique(MxProject mxProject) {
        String proId = StringUtils.isNull(mxProject.getProId()) ? "-1" : mxProject.getProId();
        MxProject mx = mxProjectMapper.selectProjectForName(mxProject);
        if (StringUtils.isNotNull(mx) && !proId.equals(mx.getProId())){
            return DatavConstans.NOT_UNIQUE;
        }
        return DatavConstans.UNIQUE;
    }

    /**
     * 插入工程
     * @param mxProject
     * @return
     */
    @Override
    public int insertMxProject(MxProject mxProject) {
        return mxProjectMapper.insertPro(mxProject);
    }

    /**
     * 获取项目信息
     * @param proId
     * @return
     */
    @Override
    public MxProject getInfo(String proId) {
        MxProject mx = new MxProject();
        mx.setProId(proId);
        return mxProjectMapper.getInfo(mx);
    }

    /**
     * 修改工程信息
     * @param mxProject
     * @return
     */
    @Override
    public int updateMxProject(MxProject mxProject) {
        return mxProjectMapper.updateMxProject(mxProject);
    }

    /**
     * 删除工程信息
     * @param proIds
     * @return
     */
    @Override
    public int delMxPorject(String[] proIds) {
        // 1：删除页面信息
        int row = pagesMapper.deletePagesForProId(proIds);
        // 2: 删除工程信息
        if (row > 0) {
            return mxProjectMapper.deleteProjects(proIds);
        }
        return 0;
    }

    /**
     * 改变工程状态
     * @param mxProject
     * @return
     */
    @Override
    public int changeProState(MxProject mxProject) {
        return mxProjectMapper.changeProState(mxProject);
    }
}
