package com.alonginfo.project.engine.service.impl;

import com.alonginfo.common.constant.DatavConstans;
import com.alonginfo.common.utils.StringUtils;
import com.alonginfo.project.engine.domain.ThemeManager;
import com.alonginfo.project.engine.mapper.ThemeManagerMapper;
import com.alonginfo.project.engine.service.IThemeManagerService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 主题管理 服务层实现
 * @author shidj
 */
@Service
public class ThemeManagerServiceImpl implements IThemeManagerService {

    @Autowired
    private ThemeManagerMapper themeManagerMapper;

    /**
     * 查询主题管理列表
     * @param themeManager
     * @return
     */
    @Override
    public List<ThemeManager> selectThemeManagerList(ThemeManager themeManager) {
        return themeManagerMapper.selectThemeManagerList(themeManager);
    }

    /**
     * 检测图表主题是否唯一
     * @param themeManager
     * @return
     */
    @Override
    public String checkThemeNameUnique(ThemeManager themeManager) {
        String themeId = StringUtils.isNull(themeManager.getThemeId()) ? "-1" : themeManager.getThemeId();
        ThemeManager theme = themeManagerMapper.selectThemeManagerForName(themeManager);
        if (StringUtils.isNotNull(theme) && !themeId.equals(theme.getThemeId())){
            return DatavConstans.NOT_UNIQUE;
        }
        return DatavConstans.UNIQUE;
    }

    /**
     * 新增图表主题
     * @param themeManager
     * @return
     */
    @Override
    public int insertThemeManager(ThemeManager themeManager) {
        return themeManagerMapper.insertThemeManager(themeManager);
    }

    /**
     * 根据id获取信息
     * @param themeId
     * @return
     */
    @Override
    public ThemeManager getInfoChartThemeId(String themeId) {
        ThemeManager th = new ThemeManager();
        th.setThemeId(themeId);
        ThemeManager reth = themeManagerMapper.getInfoChartThemeId(th);
        return reth;
    }

    /**
     * 修改图表主题
     * @param themeManager
     * @return
     */
    @Override
    public int updateThemeManager(ThemeManager themeManager) {
        return themeManagerMapper.updateThemeManager(themeManager);
    }

    /**
     * 删除图表主题
     * @param themeIds
     * @return
     */
    @Override
    public int delChartTheme(String[] themeIds) {
        return themeManagerMapper.delChartTheme(themeIds);
    }
}
