package com.alonginfo.project.gansu.controller.carbon;

import com.alonginfo.framework.web.domain.AjaxResult;
import com.alonginfo.project.gansu.domain.common.EchartsCommonDTO;
import com.alonginfo.project.gansu.domain.CarbonMapTopContentDTO;
import com.alonginfo.project.gansu.domain.ClearInstallTrendDTO;
import com.alonginfo.project.gansu.domain.IndustryEmissionDTO;
import com.alonginfo.project.gansu.service.carbon.ICarbonMonitorService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * @author: HaoXs
 * @Date: 2023/6/19 10:04
 * @Description:  双碳检测
 */
@Api(value = "双碳监测", tags = {"双碳监测"})
@RestController
@RequestMapping("/carbonMonitor")
@Slf4j
public class CarbonMonitorController {

    @Autowired
    private ICarbonMonitorService iCarbonMonitorService;

    /**
     * 发电企业碳排放情况
     * @return
     */
    @ApiOperation(value = "(导入数据)发电企业碳排放情况", response = EchartsCommonDTO.class)
    @PostMapping("/getEnterpriseEmission")
    public AjaxResult getEnterpriseEmission() {
        try {
            return AjaxResult.success(iCarbonMonitorService.getEnterpriseEmission());
        }catch (Exception e) {
            log.error("error: 获取双碳监测-发电企业碳排放情况失败!", e);
            return AjaxResult.error("获取双碳监测-发电企业碳排放情况失败!");
        }
    }

    /**
     * 各行业电力用户碳排放情况
     * @return
     */
    @ApiOperation(value = "(导入数据)各行业电力用户碳排放情况", response = IndustryEmissionDTO.class)
    @PostMapping("/getIndustryEmission")
    public AjaxResult getIndustryEmission() {
        try {
            return AjaxResult.success(iCarbonMonitorService.getIndustryEmission());
        }catch (Exception e) {
            log.error("error: 获取双碳监测-各行业电力用户碳排放情况数据失败!", e);
            return AjaxResult.error("获取双碳监测-各行业电力用户碳排放情况数据失败!");
        }
    }

    /**
     * 清洁能源装机趋势
     * @return
     */
    @ApiOperation(value = "(导入数据)清洁能源装机趋势", response = ClearInstallTrendDTO.class)
    @PostMapping("/getClearInstallTrend")
    public AjaxResult getClearInstallTrend() {
        try {
            return AjaxResult.success(iCarbonMonitorService.getClearInstallTrend());
        }catch (Exception e) {
            log.error("error: 获取双碳监测-清洁能源装机趋势数据失败!", e);
            return AjaxResult.error("获取双碳监测-清洁能源装机趋势数据失败!");
        }
    }

    /**
     * 清洁能源减排成果
     * @return
     */
    @ApiOperation(value = "(导入数据)清洁能源减排成果")
    @PostMapping("/getClearReduceGain")
    public AjaxResult getClearReduceGain() {
        try {
            return AjaxResult.success(iCarbonMonitorService.getClearReduceGain());
        }catch (Exception e) {
            log.error("error: 获取双碳监测-清洁能源减排成果数据失败!", e);
            return AjaxResult.error("获取双碳监测-清洁能源减排成果数据失败!");
        }
    }

    /**
     * 地图上方概览
     * @return
     */
    @ApiOperation(value = "(导入数据)地图上方概览", response = CarbonMapTopContentDTO.class)
    @PostMapping("/getCarbonMapTopContent")
    public AjaxResult getMapTopContent() {
        try {
            return AjaxResult.success(iCarbonMonitorService.getCarbonMapTopContent());
        }catch (Exception e) {
            log.error("error: 获取双碳监测-地图上方概览数据失败!", e);
            return AjaxResult.error("获取双碳监测-地图上方概览数据失败");
        }
    }
}
