package com.alonginfo.project.gansu.controller.clearenergy;

import com.alonginfo.framework.web.domain.AjaxResult;
import com.alonginfo.project.gansu.domain.common.EchartsCommonDTO;
import com.alonginfo.project.gansu.domain.ClearAbsorptionAnalysisDTO;
import com.alonginfo.project.gansu.domain.ClearRationDTO;
import com.alonginfo.project.gansu.domain.MapTopContentDTO;
import com.alonginfo.project.gansu.service.clearenergy.IClearEnergyAbsorptionService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * @author: HaoXs
 * @Date: 2023/6/16 15:33
 * @Description:  清洁能源消纳
 */
@Api(value = "清洁能源消纳", tags = {"清洁能源消纳"})
@RestController
@RequestMapping("/clearEnergyAbsorption")
@Slf4j
public class ClearEnergyAbsorptionController {

    @Autowired
    private IClearEnergyAbsorptionService iClearEnergyAbsorptionService;

    /**
     * 当年清洁能源消纳趋势
     * @return
     */
    @ApiOperation(value = "(导入数据)当年清洁能源消纳趋势", response = EchartsCommonDTO.class)
    @PostMapping("/getAbsorptionTrendCurrentYear")
    public AjaxResult getAbsorptionTrendCurrentYear() {
        try {
            return AjaxResult.success(iClearEnergyAbsorptionService.getAbsorptionTrendCurrentYear());
        }catch (Exception e) {
            log.error("error: 获取当年清洁能源消纳趋势数据失败!", e);
            return AjaxResult.error("获取当年清洁能源消纳趋势数据失败");
        }
    }

    /**
     * 历年清洁能源占比情况
     * @return
     */
    @ApiOperation(value = "(导入数据)历年清洁能源消纳情况", response = ClearRationDTO.class)
    @PostMapping("/getClearRatioByCalendarYear")
    public AjaxResult getClearRatioByCalendarYear() {
        try {
            return AjaxResult.success(iClearEnergyAbsorptionService.getClearRatioByCalendarYear());
        }catch (Exception e){
            log.error("error: 获取历年清洁能源消纳情况数据失败!", e);
            return AjaxResult.error("获取历年清洁能源消纳情况数据失败!");
        }
    }

    /**
     * 清洁能源消纳分析
     * @return
     */
    @ApiOperation(value = "(导入数据)清洁能源消纳分析", response = ClearAbsorptionAnalysisDTO.class)
    @PostMapping("/getClearAbsorptionAnalysis")
    public AjaxResult getClearAbsorptionAnalysis() {
        try {
            return AjaxResult.success(iClearEnergyAbsorptionService.getClearAbsorptionAnalysis());
        }catch (Exception e) {
            log.error("error: 获取清洁能源消纳分析数据失败!", e);
            return AjaxResult.error("获取清洁能源消纳分析数据失败!");
        }
    }

    /**
     * 清洁能源消纳趋势
     * @return
     */
    @ApiOperation(value = "(导入数据)清洁能源消纳趋势", response = EchartsCommonDTO.class)
    @PostMapping("/getClearAbsorptionTrend")
    public AjaxResult getClearAbsorptionTrend() {
        try {
            return AjaxResult.success(iClearEnergyAbsorptionService.getClearAbsorptionTrend());
        }catch (Exception e) {
            log.error("error: 获取清洁能源消纳趋势数据失败!", e);
            return AjaxResult.error("获取清洁能源消纳趋势数据失败!");
        }
    }

    /**
     * 地图上方概览
     * @return
     */
    @ApiOperation(value = "(导入数据)地图上方概览", response = MapTopContentDTO.class)
    @PostMapping("/getMapTopContent")
    public AjaxResult getMapTopContent() {
        try {
            return AjaxResult.success(iClearEnergyAbsorptionService.getMapTopContent());
        }catch (Exception e) {
            log.error("error: 获取地图上方概览数据失败!", e);
            return AjaxResult.error("获取地图上方概览数据失败!");
        }
    }
}
