package com.alonginfo.project.gansu.controller.forward;

import com.alonginfo.framework.web.domain.AjaxResult;
import com.alonginfo.project.gansu.service.forward.IDeliveryService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;
import javax.validation.constraints.NotNull;

/**
 * @author: HaoXs
 * @Date: 2023/7/7 17:32
 * @Description:  远程接口服务: http://25.215.196.215:/px-trade-show
 */
@Api(tags = "接口转接-delivery")
@RestController
@RequestMapping("/delivery")
@Slf4j
@Validated
public class DeliveryController {

    @Autowired
    private IDeliveryService iDeliveryService;

    @ApiOperation(value = "市场概况-当年各月各类型发电情况")
    @PostMapping("/trackingPower")
    public AjaxResult trackingPower() {
        try {
            return AjaxResult.success(iDeliveryService.trackingPower());
        }catch (Exception e) {
            log.error("error: 接口/delivery/trackingPower调用失败!");
            return AjaxResult.error("获取市场概况-当年各月各类型发电情况数据失败!");
        }
    }

    @ApiOperation(value = "外送实际执行情况-当年外送电量成分")
    @PostMapping("/getShortSendAllData")
    public AjaxResult getShortSendAllData() {
        try {
            return AjaxResult.success(iDeliveryService.getShortSendAllData());
        }catch (Exception e) {
            log.error("error: 接口/delivery/getShortSendAllData调用失败!");
            return AjaxResult.error("获取外送实际执行情况-当年外送电量成分数据失败!");
        }
    }

    @ApiOperation(value = "外送通道")
    @PostMapping("/getSendByAllChannel")
    public AjaxResult getSendByAllChannel() {
        try {
            return AjaxResult.success(iDeliveryService.getSendByAllChannel());
        }catch (Exception e) {
            log.error("error: 接口/delivery/getSendByAllChannel调用失败!");
            return AjaxResult.error("获取外送通道数据失败!");
        }
    }

    @ApiOperation("装机情况总览")
    @PostMapping("/selectMachineLoadList")
    public AjaxResult selectMachineLoadList() {
        try {
            return AjaxResult.success(iDeliveryService.selectMachineLoadList());
        }catch (Exception e) {
            log.error("error: 接口/delivery/selectMachineLoadList调用失败!");
            return AjaxResult.error("获取装机情况总览数据失败!");
        }
    }

    @ApiOperation("企业装机容量排名")
    @PostMapping("/selectGroupCap")
    public AjaxResult selectGroupCap() {
        try {
            return AjaxResult.success(iDeliveryService.selectGroupCap());
        }catch (Exception e) {
            log.error("error: 接口/delivery/selectGroupCap调用失败!");
            return AjaxResult.error("获取企业装机容量排名数据失败!");
        }
    }

    @ApiOperation("合同交易情况")
    @PostMapping("/selectContractInfo")
    public AjaxResult selectContractInfo() {
        try {
            return AjaxResult.success(iDeliveryService.selectContractInfo());
        }catch (Exception e) {
            log.error("error: 接口/delivery/selectContractInfo调用失败!");
            return AjaxResult.error("获取合同交易情况数据失败");
        }
    }

    @ApiOperation("各品类交易结算情况")
    @PostMapping("/selectEmossContractList")
    public AjaxResult selectEmossContractList() {
        try {
            return AjaxResult.success(iDeliveryService.selectEmossContractList());
        }catch (Exception e) {
            log.error("error: 接口/delivery/selectEmossContractList调用失败!");
            return AjaxResult.error("获取各品类交易结算情况数据失败!");
        }
    }

    @ApiOperation("当年各类型交易结算电量趋势")
    @PostMapping("/selectEmossContractListByMonth")
    public AjaxResult selectEmossContractListByMonth() {
        try {
            return AjaxResult.success(iDeliveryService.selectEmossContractListByMonth());
        }catch (Exception e) {
            log.error("error: 接口/delivery/selectEmossContractListByMonth调用失败!");
            return AjaxResult.error("获取当年各类型交易结算电量趋势数据失败!");
        }
    }

    @ApiOperation("当年发电侧结算情况")
    @PostMapping("/selectPowerContractListByMonth")
    public AjaxResult selectPowerContractListByMonth() {
        try {
            return AjaxResult.success(iDeliveryService.selectPowerContractListByMonth());
        }catch (Exception e) {
            log.error("error: 接口/delivery/selectPowerContractListByMonth调用失败!");
            return AjaxResult.error("获取当年发电侧结算情况数据失败!");
        }
    }

    @ApiOperation("当年各类型交易情况")
    @PostMapping("/selectInnerTradeByType")
    public AjaxResult selectInnerTradeByType() {
        try {
            return AjaxResult.success(iDeliveryService.selectInnerTradeByType());
        }catch (Exception e) {
            log.error("error: 接口/delivery/selectInnerTradeByType!");
            return AjaxResult.error("获取当年各类型交易情况数据失败!");
        }
    }

    @ApiOperation("电力用户直接交易量价情况")
    @PostMapping("/selectDirTradeInfo")
    public AjaxResult selectDirTradeInfo() {
        try {
            return AjaxResult.success(iDeliveryService.selectDirTradeInfo());
        }catch (Exception e) {
            log.error("error: 接口/delivery/selectDirTradeInfo!");
            return AjaxResult.error("获取电力用户直接交易量价情况数据失败!");
        }
    }



    @ApiOperation("结算地市供电情况")
    @PostMapping("/newQueryProviceProviderEle")
    public AjaxResult newQueryProviceProviderEle() {
        try {
            return AjaxResult.success(iDeliveryService.newQueryProviceProviderEle());
        }catch (Exception e) {
            log.error("error: 接口/delivery/newQueryProviceProviderEle调用失败!");
            return AjaxResult.error("获取结算地市供电情况数据失败!");
        }
    }

    @ApiOperation("装机机组数量")
    @PostMapping("/selectGeneratorCount")
    public AjaxResult selectGeneratorCount() {
        try {
            return AjaxResult.success(iDeliveryService.selectGeneratorCount());
        }catch (Exception e) {
            log.error("error: 接口/delivery/selectGeneratorCount调用失败!");
            return AjaxResult.error("获取装机机组数量数据失败!");
        }
    }

    /**
     * 目前正在用
     * @return
     */
    @ApiOperation("市场概览-当年市场主体参与市场情况")
    @PostMapping("/selectParticipantByMonth")
    public AjaxResult selectParticipantByMonth() {
        try {
            return AjaxResult.success(iDeliveryService.selectParticipantByMonth());
        }catch (Exception e) {
            log.error("error: 接口/delivery/selectParticipantByMonth调用失败!");
            return AjaxResult.error("获取当年个月市场主体参与交易情况数据失败!");
        }
    }

    /**
     * 已舍弃-目前没被调用
     * @param year
     * @return
     */
    @ApiOperation("市场概览-当年市场主体参与市场情况")
    @ApiImplicitParam(name = "year", value = "年份(4位)", dataType = "String", paramType = "query", required = true)
    @PostMapping("/selectTradeCountByMonth")
    public AjaxResult selectTradeCountByMonth(@Valid @NotNull String year) {
        try {
            return AjaxResult.success(iDeliveryService.selectTradeCountByMonth(year));
        }catch (Exception e) {
            log.error("error: 接口/delivery/selectTradeCountByMonth调用失败!");
            return AjaxResult.error("获取/delivery/selectTradeCountByMonth数据失败!");
        }
    }

    @ApiOperation("省间")
    @PostMapping("/selectGreenPower")
    public AjaxResult selectGreenPower() {
        try {
            return AjaxResult.success(iDeliveryService.selectGreenPower());
        }catch (Exception e) {
            log.error("error: 接口/delivery/selectGreenPower!");
            return AjaxResult.error("获取/delivery/selectGreenPower数据失败!");
        }
    }

    @ApiOperation("省内")
    @PostMapping("/selectInnerGreenPower")
    public AjaxResult selectInnerGreenPower() {
        try {
            return AjaxResult.success(iDeliveryService.selectInnerGreenPower());
        }catch (Exception e) {
            log.error("error: 接口/delivery/selectInnerGreenPower!");
            return AjaxResult.error("获取/delivery/selectInnerGreenPower数据失败!");
        }
    }

    @ApiOperation("各月市场主体注册")
    @PostMapping("/selectParticipantReg")
    public AjaxResult selectParticipantReg() {
        try {
            return AjaxResult.success(iDeliveryService.selectParticipantReg());
        }catch (Exception e) {
            log.error("error: 接口/delivery/selectParticipantReg调用失败!");
            return AjaxResult.error("获取各月市场主体注册数据失败!");
        }
    }

    @ApiOperation("各月市场主体参与交易")
    @PostMapping("/selectParticipantTrade")
    public AjaxResult selectParticipantTrade() {
        try {
            return AjaxResult.success(iDeliveryService.selectParticipantTrade());
        }catch (Exception e) {
            log.error("error: 接口: /delivery/selectParticipantTrade调用失败!");
            return AjaxResult.error("获取各月市场主体参与交易数据失败!");
        }
    }

    @ApiOperation("累计参与交易")
    @PostMapping("/selectParticipantTradeByYear")
    public AjaxResult selectParticipantTradeByYear() {
        try {
            return AjaxResult.success(iDeliveryService.selectParticipantTradeByYear());
        }catch (Exception e) {
            log.error("error: 接口: /delivery/selectParticipantTradeByYear调用失败!");
            return AjaxResult.error("获取累计参与交易数据失败!");
        }
    }

    @ApiOperation("省内交易情况-当年各类型交易情况/直接交易电量")
    @PostMapping("/selectYearDirEnergy")
    public AjaxResult selectYearDirEnergy() {
        try {
            return AjaxResult.success(iDeliveryService.selectYearDirEnergy());
        }catch (Exception e) {
            log.error("error: 接口: /delivery/selectYearDirEnergy调用失败!");
            return AjaxResult.error("获取省内交易情况-当年各类型交易情况/直接交易电量数据失败!");
        }
    }
}
