package com.alonginfo.project.gansu.controller.forward;

import com.alonginfo.framework.web.domain.AjaxResult;
import com.alonginfo.project.gansu.service.forward.IGreenConsumer;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * @author: HaoXs
 * @Date: 2023/7/7 17:02
 * @Description:  远程接口服务: http://25.215.196.215:/px-trade-show
 */
@Api(tags = "接口转接-GreenConsumer")
@RestController
@RequestMapping("/greenConsumer")
@Slf4j
public class GreenConsumerController {

    @Autowired
    private IGreenConsumer iGreenConsumer;

    /**
     * 历年外送电规模
     * @return
     */
    @ApiOperation(value = "历年外送电规模")
    @PostMapping("/getYearHitorySend")
    public AjaxResult getYearHitorySend() {
        try {
            return AjaxResult.success(iGreenConsumer.getYearHitorySend());
        }catch (Exception e) {
            log.error("error: 接口:/greenConsumer/getYearHitorySend调用失败!");
            return AjaxResult.error("获取历年外送电规模数据失败!");
        }
    }

    /**
     * 装机总量/新能源变化趋势
     * @return
     */
    @ApiOperation(value = "装机总量/新能源变化趋势")
    @PostMapping("/getMachineHistory")
    public AjaxResult getMachineHistory() {
        try {
            return AjaxResult.success(iGreenConsumer.getMachineHistory());
        }catch (Exception e) {
            log.error("error: 接口: /greenConsumer/getMachineHistory调用失败!");
            return AjaxResult.error("获取装机总量/新能源变化趋势数据失败!");
        }
    }

    /**
     * 新能源装机结构
     * @return
     */
    @ApiOperation(value = "新能源装机结构")
    @PostMapping("/getGreenProportion")
    public AjaxResult getGreenProportion() {
        try {
            return AjaxResult.success(iGreenConsumer.getGreenProportion());
        }catch (Exception e) {
            log.error("error: 接口: /greenConsumer/getGreenProportion调用失败!");
            return AjaxResult.error("获取新能源装机结构数据失败!");
        }
    }

    /**
     * 新能源发电趋势
     * @return
     */
    @ApiOperation(value = "新能源发电趋势")
    @PostMapping("/getHistoryGreenPower")
    public AjaxResult getHistoryGreenPower() {
        try {
            return AjaxResult.success(iGreenConsumer.getHistoryGreenPower());
        }catch (Exception e) {
            log.error("error: 接口: /greenConsumer/getHistoryGreenPower调用失败!");
            return AjaxResult.error("获取新能源发电趋势数据失败!");
        }
    }

    /**
     * 新能源参与交易情况
     * @return
     */
    @ApiOperation(value = "新能源参与交易情况")
    @PostMapping("/getGreenTrade")
    public AjaxResult getGreenTrade() {
        try {
            return AjaxResult.success(iGreenConsumer.getGreenTrade());
        }catch (Exception e) {
            log.error("error: 接口: /greenConsumer/getGreenTrade调用失败!");
            return AjaxResult.error("获取新能源发电趋势数据失败!");
        }
    }
}
