package com.alonginfo.project.gansu.controller.forward;

import com.alonginfo.framework.web.domain.AjaxResult;
import com.alonginfo.project.gansu.service.forward.IInfoDisclosureService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * @author: HaoXs
 * @Date: 2023/7/6 14:20
 * @Description:  信息披露  服务地址: http://25.215.196.215/px-settlement-infpubgrid-lz
 */
@Api(tags = "接口转接-menuStatist")
@RestController
@RequestMapping("/menuStatist")
@Slf4j
public class InfoDisclosureController {

    @Autowired
    private IInfoDisclosureService iInfoDisclosureService;

    /**
     * 月度披露数据
     * @return
     */
    @ApiOperation("月度披露数据")
    @PostMapping("/getMonthInfpubData")
    public AjaxResult getMonthInfpubData() {
        try {
            return AjaxResult.success(iInfoDisclosureService.getMonthInfpubData());
        }catch (Exception e) {
            log.error("error: 获取信息披露-月底披露数据失败!", e);
            return AjaxResult.error("获取信息披露-月底披露数据失败!");
        }
    }

    /**
     * 获取累计披露数据
     * @return
     */
    @ApiOperation("累计披露数据")
    @PostMapping("/getTotalCount")
    public AjaxResult getTotalCount() {
        try {
            return AjaxResult.success(iInfoDisclosureService.getTotalCount());
        }catch (Exception e) {
            log.error("error: 获取信息披露-累计披露数据失败!", e);
            return AjaxResult.error("获取信息披露-累计披露数据失败!");
        }
    }

    /**
     * 年度披露数据
     * @return
     */
    @ApiOperation("年度披露数据")
    @PostMapping("/getYearInfpubData")
    public AjaxResult getYearInfpubData() {
        try {
            return AjaxResult.success(iInfoDisclosureService.getYearInfpubData());
        }catch (Exception e) {
            log.error("error: 获取信息披露-年底披露数据失败!", e);
            return AjaxResult.error("获取信息披露-年底披露数据失败!");
        }
    }

    /**
     * 累计披露数据条数及占比
     * @return
     */
    @ApiOperation("累计披露数据条数及占比")
    @PostMapping("/getToalInfpubData")
    public AjaxResult getToalInfpubData() {
        try {
            return AjaxResult.success(iInfoDisclosureService.getToalInfpubData());
        }catch (Exception e) {
            log.error("error: 获取信息披露-累计披露数据条数及占比数据失败!", e);
            return AjaxResult.error("获取信息披露-累计披露数据条数及占比数据失败!");
        }
    }
}
