package com.alonginfo.project.gansu.controller.forward;

import com.alonginfo.framework.web.domain.AjaxResult;
import com.alonginfo.project.gansu.service.forward.ITradeInfoService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.constraints.NotNull;

/**
 * @author: HaoXs
 * @Date: 2023/7/13 16:17
 * @Description:
 */
@Api(tags = "接口转接-tradeInfo")
@RestController
@RequestMapping("/tradeInfo")
@Slf4j
public class TradeInfoController {

    @Autowired
    private ITradeInfoService iTradeInfoService;

    /**
     * 交易情况总览统计
     * @param yearCode
     * @return
     */
    @ApiOperation(value = "交易情况总览统计-selectTotalTradeInfoByYear")
    @ApiImplicitParam(name = "yearCode", value = "年份(4位)", dataType = "String", paramType = "query", required = true)
    @PostMapping("/selectTotalTradeInfoByYear")
    public AjaxResult selectTotalTradeInfoByYear(@NotNull String yearCode) {
        try {
            return AjaxResult.success(iTradeInfoService.selectTotalTradeInfoByYear(yearCode));
        }catch (Exception e) {
            log.error("error: 接口:/tradeInfo/selectTotalTradeInfoByYear调用失败!");
            return AjaxResult.error("获取交易情况总览统计结果数据失败!");
        }
    }

    /**
     * 各类型交易组织情况
     * @param yearCode
     * @return
     */
    @ApiOperation(value = "各类型交易组织情况-selectTradeDetailByType")
    @ApiImplicitParam(name = "yearCode", value = "年份(4位)", dataType = "String", paramType = "query", required = true)
    @PostMapping("/selectTradeDetailByType")
    public AjaxResult selectTradeDetailByType(@NotNull String yearCode) {
        try {
            return AjaxResult.success(iTradeInfoService.selectTradeDetailByType(yearCode));
        }catch (Exception e) {
            log.error("error: 接口:/tradeInfo/selectTradeDetailByType调用失败!");
            return AjaxResult.error("获取各类型交易组织情况数据失败!");
        }
    }

    /**
     * 各类市场主体参与市场情况
     * @param yearCode
     * @return
     */
    @ApiOperation(value = "各类市场主体参与市场情况-selectMarketMemberNumByType")
    @ApiImplicitParam(name = "yearCode", value = "年份(4位)", dataType = "String", paramType = "query", required = true)
    @PostMapping("/selectMarketMemberNumByType")
    public AjaxResult selectMarketMemberNumByType(@NotNull String yearCode) {
        try {
            return AjaxResult.success(iTradeInfoService.selectMarketMemberNumByType(yearCode));
        }catch (Exception e) {
            log.error("error: 接口:/tradeInfo/selectMarketMemberNumByType调用失败!");
            return AjaxResult.error("获取各类市场主体参与市场情况数据失败!");
        }
    }

    /**
     * 历年直接交易规模
     * @param yearCode
     * @return
     */
    @ApiOperation(value = "历年直接交易规模-selectDirectTradeByType")
    @PostMapping("/selectDirectTradeByType")
    public AjaxResult selectDirectTradeByType() {
        try {
            return AjaxResult.success(iTradeInfoService.selectDirectTradeByType());
        }catch (Exception e) {
            log.error("error: 接口:/tradeInfo/selectDirectTradeByType调用失败!");
            return AjaxResult.error("获取历年直接交易规模数据失败!");
        }
    }

    /**
     * 各地市市场主体情况
     * @return
     */
    @ApiOperation(value = "各地市市场主体情况-selectTradeCityMemberResult")
    @ApiImplicitParam(name = "yearCode", value = "年份(4位)", dataType = "String", paramType = "query", required = true)
    @PostMapping("/selectTradeCityMemberResult")
    public AjaxResult selectTradeCityMemberResult(@NotNull String yearCode) {
        try {
            return AjaxResult.success(iTradeInfoService.selectTradeCityMemberResult(yearCode));
        }catch (Exception e) {
            log.error("error: 接口:/tradeInfo/selectTradeCityMemberResult调用失败!");
            return AjaxResult.error("获取各地市市场主体情况数据失败!");
        }
    }

    /**
     * 历年省内交易均价交易电量
     * @return
     */
    @ApiOperation(value = "历年省内交易均价交易电量")
    @PostMapping("/selectAvgPriceEnergyByYearResult")
    public AjaxResult selectAvgPriceEnergyByYearResult() {
        try {
            return AjaxResult.success(iTradeInfoService.selectAvgPriceEnergyByYearResult());
        }catch (Exception e) {
            log.error("error: 接口:/selectAvgPriceEnergyByYearResult调用失败!");
            return AjaxResult.error("获取历年省内交易均价交易电量数据失败!");
        }
    }

    /**
     * 历年省间外送交易均价交易电量
     * @return
     */
    @ApiOperation(value = "历年省间外送交易均价交易电量")
    @PostMapping("/selectOutSendAvgPriceEnergyByYearResult")
    public AjaxResult selectOutSendAvgPriceEnergyByYearResult() {
        try {
            return AjaxResult.success(iTradeInfoService.selectOutSendAvgPriceEnergyByYearResult());
        }catch (Exception e) {
            log.error("error: 接口:/selectOutSendAvgPriceEnergyByYearResult调用失败!");
            return AjaxResult.error("获取历年省同外送交易均价交易电量数据失败!");
        }
    }

    /**
     * 省间外送历年水火风光电量
     * @return
     */
    @ApiOperation(value = "省间外送历年水火风光电量")
    @PostMapping("/selectTradeEnergyPowerTypeResult")
    public AjaxResult selectTradeEnergyPowerTypeResult() {
        try {
            return AjaxResult.success(iTradeInfoService.selectTradeEnergyPowerTypeResult());
        }catch (Exception e) {
            log.error("error: 接口:/tradeInfo/selectTradeEnergyPowerTypeResult调用失败!");
            return AjaxResult.error("获取省间外送历年水火风光电量数据失败!");
        }
    }
}
