package com.alonginfo.project.gansu.controller.forward;

import com.alonginfo.framework.web.domain.AjaxResult;
import com.alonginfo.project.gansu.service.forward.ITradeMarketInfoService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.aspectj.weaver.loadtime.Aj;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.constraints.NotNull;

/**
 * @author: HaoXs
 * @Date: 2023/7/7 16:51
 * @Description:  远程接口服务: http://25.215.196.215:/px-trade-show
 */
@RestController
@RequestMapping("/tradeMarketInfo")
@Api(tags = "接口转接-tradeMarketInfo")
@Slf4j
public class TradeMarketInfoController {

    @Autowired
    private ITradeMarketInfoService iTradeMarketInfoService;

    /**
     * (接口调用)顶部发电数据
     * @param yearCode
     * @return
     */
    @ApiOperation(value = "(接口调用)顶部发电数据")
    @ApiImplicitParam(name = "yearCode", value = "年份(4位)", dataType = "String", paramType = "query", required = true)
    @PostMapping("/selectGeneratePowerDataByYear")
    public AjaxResult selectGeneratePowerDataByYear(@NotNull String yearCode) {
        try {
            return AjaxResult.success(iTradeMarketInfoService.selectGeneratePowerDataByYear(yearCode));
        }catch (Exception e) {
            log.error("error: 获取发电用电-发电数据失败!", e);
            return AjaxResult.error("获取发电用电-发电数据失败!");
        }
    }

    /**
     * (接口调用)当年市场化电量累计执行情况
     * @return
     */
    @ApiOperation(value = "(接口调用)当年市场化电量累计执行情况")
    @ApiImplicitParam(name = "yearCode", value = "年份(4位)", dataType = "String", paramType = "query", required = true)
    @PostMapping("/selectTradeEnergyRatio")
    public AjaxResult selectTradeEnergyRatio(@NotNull String yearCode) {
        try {
            return AjaxResult.success(iTradeMarketInfoService.selectTradeEnergyRatio(yearCode));
        }catch (Exception e){
            log.error("error: 获取当年市场化电量累计执行情况数据失败!", e);
            return AjaxResult.error("获取当年市场化电量累计执行情况数据失败!");
        }
    }

    /**
     * (接口调用)当年交易量价走势
     * @return
     */
    @ApiOperation(value = "(接口调用)当年交易量价走势")
    @ApiImplicitParam(name = "yearCode", value = "年份(4位)", dataType = "String", paramType = "query", required = true)
    @PostMapping("/selectTradePowerAvgPriceResult")
    public AjaxResult selectTradePowerAvgPriceResult(@NotNull String yearCode) {
        try {
            return AjaxResult.success(iTradeMarketInfoService.selectTradePowerAvgPriceResult(yearCode));
        }catch (Exception e) {
            log.error("error: 获取当年交易量价走势数据失败!", e);
            return AjaxResult.error("获取当年交易量价走势数据失败!");
        }
    }

    /**
     * (接口调用)发电装机情况与利用小时数
     * @return
     */
    @ApiOperation(value = "(接口调用)发电装机情况与利用小时数")
    @ApiImplicitParam(name = "yearCode", value = "年份(4位)", dataType = "String", paramType = "query", required = true)
    @PostMapping("/selectGeneratorCapacity")
    public AjaxResult selectGeneratorCapacity(@NotNull String yearCode) {
        try {
            return AjaxResult.success(iTradeMarketInfoService.selectGeneratorCapacity(yearCode));
        }catch (Exception e) {
            log.error("error: 获取发电装机情况与利用小时数数据失败!", e);
            return AjaxResult.error("获取发电装机情况与利用小时数数据失败!");
        }
    }

    /**
     * (接口调用)各类型资源装机容量与发电量
     * @param yearCode
     * @return
     */
    @ApiOperation(value = "(接口调用)各类型资源装机容量与发电量")
    @ApiImplicitParam(name = "yearCode", value = "年份(4位)", dataType = "String", paramType = "query", required = true)
    @PostMapping("/selectResourceCapacity")
    public AjaxResult selectResourceCapacity(@NotNull String yearCode) {
        try {
            return AjaxResult.success(iTradeMarketInfoService.selectResourceCapacity(yearCode));
        }catch (Exception e) {
            log.error("error: 获取各类型资源装机容量与发电量失败!", e);
            return AjaxResult.error("获取各类型资源装机容量与发电量失败!");
        }
    }

    /**
     * (接口调用)当年发电情况统计
     * @param yearCode
     * @return
     */
    @ApiOperation(value = "(接口调用)当年发电情况统计")
    @ApiImplicitParam(name = "yearCode", value = "年份(4位)", dataType = "String", paramType = "query", required = true)
    @PostMapping("/selectResourceDevDataList")
    public AjaxResult selectResourceDevDataList(@NotNull String yearCode) {
        try {
            return AjaxResult.success(iTradeMarketInfoService.selectResourceDevDataList(yearCode));
        }catch (Exception e) {
            log.error("error: 获取当年发电情况统计数据失败!", e);
            return AjaxResult.error("获取当年发电情况统计数据失败！");
        }
    }

    /**
     * 查询当年电力用户交易量价情况
     * @return
     */
    @ApiOperation(value = "(接口调用)查询当年电力用户交易量价情况")
    @PostMapping("/selectUserSumEnergyAvgPrice")
    public AjaxResult selectUserSumEnergyAvgPrice() {
        try {
            return AjaxResult.success(iTradeMarketInfoService.selectUserSumEnergyAvgPrice());
        }catch (Exception e) {
            log.error("error: 获取当年电力用户交易量价情况数据失败!", e);
            return AjaxResult.error("获取当年电力用户交易量价情况数据失败!");
        }
    }

    /**
     * 当年发电企业交易量价情况数据
     * @return
     */
    @ApiOperation(value = "(接口调用)当年发电企业交易量价情况数据")
    @PostMapping("/selectEnterpriseSumEnergyAvgPrice")
    public AjaxResult selectEnterpriseSumEnergyAvgPrice() {
        try {
            return AjaxResult.success(iTradeMarketInfoService.selectEnterpriseSumEnergyAvgPrice());
        }catch (Exception e) {
            log.error("error: 获取当年发电企业交易量价情况数据失败!", e);
            return AjaxResult.error("获取当年发电企业交易量价情况数据失败!");
        }
    }
}
