package com.alonginfo.project.gansu.controller.forward;

import com.alonginfo.framework.web.domain.AjaxResult;
import com.alonginfo.project.gansu.service.forward.IDeliveryService;
import com.alonginfo.project.gansu.service.forward.TransactionPowerService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * transactionPowerController
 *
 * @package_name： com.alonginfo.project.gansu.controller.forward
 * @author： 樊群靖
 * @date： 2023/8/9
 * @description:
 **/

@Api(tags = "接口转接-transactionPowerController")
@RestController
@RequestMapping("/transactionPowerController")
@Slf4j
@Validated
public class TransactionPowerController {

    @Autowired
    private TransactionPowerService transactionPowerService;

    @ApiOperation("直接交易电量")
    @PostMapping("/selectDirectPowerList")
    public AjaxResult selectDirectPowerList() {
        try {
            return AjaxResult.success(transactionPowerService.selectDirectPowerList());
        }catch (Exception e) {
            log.error("error: 接口/transactionPowerController/selectDirectPowerList!");
            return AjaxResult.error("获取直接交易电量数据失败!");
        }
    }

    @ApiOperation("发电权交易电量")
    @PostMapping("/selectGenerationRightPowerList")
    public AjaxResult selectGenerationRightPowerList() {
        try {
            return AjaxResult.success(transactionPowerService.selectGenerationRightPowerList());
        }catch (Exception e) {
            log.error("error: 接口/transactionPowerController/selectGenerationRightPowerList!");
            return AjaxResult.error("获取发电权交易电量数据失败!");
        }
    }

    @ApiOperation("当年发电侧结算情况")
    @PostMapping("/selectPowerList")
    public AjaxResult selectPowerList() {
        try {
            return AjaxResult.success(transactionPowerService.selectPowerList());
        }catch (Exception e) {
            log.error("error: 接口/transactionPowerController/selectPowerList!");
            return AjaxResult.error("获取当年发电侧结算情况数据失败!");
        }
    }

    @ApiOperation("省内交易情况")
    @PostMapping("/transactionInTheProvince")
    public AjaxResult transactionInTheProvince() {
        try {
            return AjaxResult.success(transactionPowerService.transactionInTheProvince());
        }catch (Exception e) {
            log.error("error: 接口/transactionPowerController/transactionInTheProvince调用失败!");
            return AjaxResult.error("获取省内交易情况数据失败!");
        }
    }

    @ApiOperation("月度结算")
    @PostMapping("/abschluss")
    public AjaxResult abschluss() {
        try {
            return AjaxResult.success(transactionPowerService.abschluss());
        }catch (Exception e) {
            log.error("error: 接口/transactionPowerController/abschluss调用失败!");
            return AjaxResult.error("获取月度结算数据失败!");
        }
    }
}
