package com.alonginfo.project.gansu.controller.generation;

import com.alonginfo.framework.web.domain.AjaxResult;
import com.alonginfo.project.gansu.domain.DealOrganizeDTO;
import com.alonginfo.project.gansu.domain.PowerByYearDTO;
import com.alonginfo.project.gansu.domain.PowerByYearMonthDTO;
import com.alonginfo.project.gansu.domain.SubjectJoinDTO;
import com.alonginfo.project.gansu.service.generation.IGenerationRightService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.constraints.Max;
import javax.validation.constraints.Min;
import javax.validation.constraints.NotNull;

/**
 * @author: HaoXs
 * @Date: 2023/5/17 15:09
 * @Description:  发电权交易情况 controller
 */
@Api(value = "发电权交易情况", tags = {"发电权交易情况"})
@RestController
@RequestMapping("/generation")
@Validated
public class GenerationRightController {

    @Autowired
    private IGenerationRightService iGenerationRightService;

    /**
     * (同步数据)当年发电权交易组织情况
     * @return
     */
    @ApiOperation(value = "(同步数据)当年发电权交易组织情况", response = DealOrganizeDTO.class)
    @PostMapping("/getDealOrganize")
    public AjaxResult getDealOrganize() {
        return AjaxResult.success(iGenerationRightService.getDealOrganize());
    }

    /**
     * (同步数据)当年发电权交易市场主体参与情况
     * @return
     */
    @ApiOperation(value = "(同步数据)当年发电权交易市场主体参与情况", response = SubjectJoinDTO.class)
    @PostMapping("/getSubjectJoin")
    public AjaxResult getSubjectJoin() {
        return AjaxResult.success(iGenerationRightService.getSubjectJoin());
    }

    /**
     * (同步数据)买入、卖出企业电量排名
     * @param type  0-卖出电量企业  1-买入电量企业
     * @return
     */
    @ApiOperation(value = "(同步数据)买入、卖出企业电量排名")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "type", value = "0-卖出电量企业排名, 1-买入电量企业排名",
                    dataType = "String", paramType = "query", required = true)
    })
    @PostMapping("/getSaleBuyOrder")
    public AjaxResult getSaleBuyOrder(@NotNull @Min(value = 0, message = "请输入0或1!")
                                               @Max(value = 1, message = "请输入0或1!") String type) {
        return AjaxResult.success(iGenerationRightService.getSaleBuyOrder(type));
    }

    /**
     * (同步数据)历年发电权交易电量趋势
     * @return
     */
    @ApiOperation(value = "(同步数据)历年发电权交易、结算电量趋势", response = PowerByYearDTO.class)
    @PostMapping("/getPowerByYear")
    public AjaxResult getPowerByYear() {
        return AjaxResult.success(iGenerationRightService.getPowerByYear());
    }

    /**
     * (同步数据)当年分月发电权交易、结算电量趋势
     * @return
     */
    @ApiOperation(value = "(同步数据)当年分月发电权交易、结算电量趋势", response = PowerByYearMonthDTO.class)
    @PostMapping("/getPowerByYearMonth")
    public AjaxResult getPowerByYearMonth() {
        return AjaxResult.success(iGenerationRightService.getPowerByYearMonth());
    }
}
