package com.alonginfo.project.gansu.controller.grid;

import com.alonginfo.framework.web.domain.AjaxResult;
import com.alonginfo.project.gansu.domain.LineCapacityDTO;
import com.alonginfo.project.gansu.domain.LineTransportDTO;
import com.alonginfo.project.gansu.domain.TransformerInfoVO;
import com.alonginfo.project.gansu.service.grid.IGridService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * @author: HaoXs
 * @Date: 2023/6/13 10:11
 * @Description:  甘肃网架图 Controller
 */
@Api(value = "甘肃网架图", tags = "甘肃网架图")
@Slf4j
@RestController
@RequestMapping("/grid")
public class GridController {

    @Autowired
    private IGridService iGridService;

    /**
     * 左下角文本框数据
     * @return
     */
    @ApiOperation(value = "(导入数据)左下角文本框数据")
    @PostMapping("/getTextBoxData")
    public AjaxResult getTextBoxData() {
        try {
            return AjaxResult.success(iGridService.getTextBoxData());
        }catch (Exception e) {
            log.error("error: 获取左下角文本框数据失败!", e);
            return AjaxResult.error("获取左下角文本框数据失败!");
        }
    }

    /**
     * 变电站信息
     * @return
     */
    @ApiOperation(value = "(导入数据)变电站信息", response = TransformerInfoVO.class)
    @PostMapping("/getTransformerInfo")
    public AjaxResult transformerSubstationInfo() {
        try {
            return AjaxResult.success(iGridService.getTransformerInfo());
        }catch (Exception e) {
            log.error("error: 获取变电站信息数据失败!", e);
            return AjaxResult.error("获取变电站信息数据失败!");
        }
    }

    /**
     * 各线路输送电量分析
     * @return
     */
    @ApiOperation(value = "(导入数据)各线路输送电量分析", response = LineTransportDTO.class)
    @PostMapping("/getLineTransport")
    public AjaxResult lineTransport() {
        try {
            return AjaxResult.success(iGridService.getLineTransport());
        }catch (Exception e) {
            log.error("error: 获取各线路输送电量分析数据失败!", e);
            return AjaxResult.error("获取各线路输送电量分析数据失败!");
        }
    }

    /**
     * 各线路整体容量情况
     * @return
     */
    @ApiOperation(value = "(导入数据)各线路整体容量情况", response = LineCapacityDTO.class)
    @PostMapping("/getLineCapacity")
    public AjaxResult lineCapacity() {
        try {
            return AjaxResult.success(iGridService.getLineCapacity());
        }catch (Exception e) {
            log.error("error: 获取各线路整体容量情况数据失败!", e);
            return AjaxResult.error("获取各线路整体容量情况数据失败!");
        }
    }
}
