package com.alonginfo.project.gansu.controller.marketsurvey;

import com.alonginfo.framework.web.domain.AjaxResult;
import com.alonginfo.project.gansu.domain.*;
import com.alonginfo.project.gansu.service.marketsurvey.IMarketSurveyService;
import io.swagger.annotations.*;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;
import javax.validation.constraints.Max;
import javax.validation.constraints.Min;
import javax.validation.constraints.NotNull;

/**
 * @author: HaoXs
 * @Date: 2023/1/4 10:37
 * @Description: 市场概况controller
 */
@Api(value = "市场概况", tags = {"市场概况"})
@RestController
@RequestMapping("/")
@Slf4j
@Validated
public class MarketSurveyController {

    @Autowired
    private IMarketSurveyService iMarketSurveyService;

    /**
     * (同步数据)当前市场主体情况
     * @return
     */
    @ApiOperation(value = "(同步数据)当前市场主体情况", response = SubjectInfoDTO.class)
    @PostMapping("/marketSurvey/getMarketSubjectInfo")
    public AjaxResult marketSubjectInfo(){
        return AjaxResult.success(iMarketSurveyService.getMarketSubjectInfo());
    }

    /**
     * (导入数据)发电、用电
     *
     * 注：接口取消
     *
     * @return 发电信息 【当年全口径发电量，火电发电量，水电发电量，新能源发电量】
     *         用电信息 【全社会用电量，第一产业用电量，第二产业用电量，第三产业用电量】
     */
    @ApiOperation(value = "(导入数据)发电、用电;  返回结果:{发电: 【当年全口径发电量，火电发电量，水电发电量，新能源发电量】, 用电:【全社会用电量，第一产业用电量，第二产业用电量，第三产业用电量】}")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "flag", value = "0-用电数据、1-发电数据",
            dataType = "String", paramType = "query", required = true)
    })
    @PostMapping("/marketSurvey/getUseGeneration")
    public AjaxResult getUseGeneration(@NotNull @Max(value = 1, message = "请输入0或1!")
                                                @Min(value = 0, message = "请输入0或1!") String flag) {
        try {
            return AjaxResult.success(iMarketSurveyService.getUseGeneration(flag));
        }catch (Exception e) {
            log.error("error: 获取发电、用电数据失败!", e);
            return AjaxResult.error("获取发电、用电数据失败!");
        }
    }

    /**
     * (导入数据)发电情况-各类型电量累计发用电
     * @return
     */
    @ApiOperation(value = "(导入数据)发电情况-各类型电量累计发用电", response = CountPowerByTypeDTO.class)
    @PostMapping("/marketSurvey/getCountPowerByType")
    public AjaxResult getCountPowerByType() {
        try {
            return AjaxResult.success(iMarketSurveyService.getCountPowerByType());
        }catch (Exception e) {
            log.error("error: 获取各类型电量累计发用电数据失败!", e);
            return AjaxResult.error("获取各类型电量累计发用电数据失败!");
        }
    }

    /**
     * (导入数据)发电情况-当年用电趋势
     * @return
     */
    @ApiOperation(value = "(导入数据)发电情况-当年用电趋势", response = UseTrendCurrentYearDTO.class)
    @PostMapping("/marketSurvey/getUseTrendCurrentYear")
    public AjaxResult getUseTrendCurrentYear() {
        try {
            return AjaxResult.success(iMarketSurveyService.getUseTrendCurrentYear());
        }catch (Exception e) {
            log.error("error: 获取当年用电趋势数据失败!", e);
            return AjaxResult.error("获取当年用电趋势数据失败!");
        }
    }

    /**
     * (导入数据)当年交易量趋势
     * @return
     */
    //@ApiOperation(value = "(导入数据)当年交易量趋势")
    //@PostMapping("/marketSurvey/getTradeVolumeTrendCurrent")
    public AjaxResult getTradeVolumeTrendCurrent() {
        try {
            return AjaxResult.success(iMarketSurveyService.getTradeVolumeTrendCurrent());
        }catch (Exception e) {
            log.error("error: 获取当年交易量趋势数据失败!", e);
            return AjaxResult.error("获取当年交易量趋势数据失败!");
        }
    }

    /**
     * (导入数据)当年市场化电量累计执行情况
     * 注: 接口取消
     * @return
     */
    @ApiOperation(value = "(导入数据)当年市场化电量累计执行情况", response = MarketCountExecuteDTO.class)
    @PostMapping("/marketSurvey/getMarketCountExecute")
    public AjaxResult getMarketCountExecute() {
        try {
            return AjaxResult.success(iMarketSurveyService.getMarketCountExecute());
        }catch (Exception e) {
            log.error("error: 当年市场化电量累计执行情况数据失败!", e);
            return AjaxResult.error("当年市场化电量累计执行情况数据失败!");
        }
    }

    /**
     * (导入数据)发电装机情况与利用小时数
     * @return
     */
    @ApiOperation(value = "(导入数据)发电装机情况与利用小时数", response = InstallAndHoursDTO.class)
    @PostMapping("/marketSurvey/getInstallAndHours")
    public AjaxResult getInstallAndHours() {
        try {
            return AjaxResult.success(iMarketSurveyService.getInstallAndHours());
        }catch (Exception e) {
            log.error("error: 获取发电装机情况与利用小时数数据失败!", e);
            return AjaxResult.error("获取发电装机情况与利用小时数数据失败!");
        }
    }

}

