package com.alonginfo.project.gansu.controller.mltermcontract;

import com.alonginfo.framework.web.domain.AjaxResult;
import com.alonginfo.project.gansu.domain.common.EchartsCommonDTO;
import com.alonginfo.project.gansu.domain.SupplyTypeDTO;
import com.alonginfo.project.gansu.domain.TypePowerDTO;
import com.alonginfo.project.gansu.domain.OutsideDeliverDTO;
import com.alonginfo.project.gansu.service.mltermcontract.IMediumLongTermContractService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * @author: HaoXs
 * @Date: 2023/5/15 11:26
 * @Description:  中长期合同签订情况controller
 */
@Api(value = "中长期合同签订情况", tags = {"中长期合同签订情况"})
@RestController
@RequestMapping("/mediumLongTerm")
@Slf4j
public class MediumLongTermContractController {

    @Autowired
    private IMediumLongTermContractService iMediumLongTermContractService;

    /**
     * (同步数据)中长期省内交易品种及电量
     * @return
     */
    @ApiOperation(value = "(同步数据)省内交易品种及电量", response = TypePowerDTO.class)
    @PostMapping("/getTypePower")
    public AjaxResult getTypePower() {
        return AjaxResult.success(iMediumLongTermContractService.getTypePower());
    }

    /**
     * (同步数据)电源类型及成交电量
     * @return
     */
    @ApiOperation(value = "(同步数据)电源类型及成交电量", response = SupplyTypeDTO.class)
    @PostMapping("/getSupplyType")
    public AjaxResult getSupplyType() {
        return AjaxResult.success(iMediumLongTermContractService.getSupplyType());
    }

    /**
     * (导入数据)外送交易
     * @return
     */
    @ApiOperation(value = "(导入数据)外送交易", response = OutsideDeliverDTO.class)
    @PostMapping("/getOutsideDeliver")
    public AjaxResult getOutsideDeliver() {
        try {
            return AjaxResult.success(iMediumLongTermContractService.getOutsideDeliver());
        }catch (Exception e) {
            log.error("error: 获取中长期合同签订情况-外送交易数据失败!", e);
            return AjaxResult.error("获取中长期合同签订情况-外送交易数据失败!");
        }
    }

    /**
     * (导入数据)外购交易
     * @return
     */
    @ApiOperation(value = "(导入数据)外购交易", response = EchartsCommonDTO.class)
    @PostMapping("/getOutsideBuy")
    public AjaxResult getOutsideBuy() {
        try {
            return AjaxResult.success(iMediumLongTermContractService.getOutsideBuy());
        }catch (Exception e) {
            log.error("error: 获取中长期合同签订情况-外购交易数据失败!", e);
            return AjaxResult.error("获取中长期合同签订情况-外购交易数据失败!");
        }
    }
}
