package com.alonginfo.project.gansu.controller.newenergy;

import com.alonginfo.framework.web.domain.AjaxResult;
import com.alonginfo.project.gansu.domain.*;
import com.alonginfo.project.gansu.domain.JoinEnergyTrendDTO;
import com.alonginfo.project.gansu.service.newEnergy.INewEnergySurveyService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * @author: HaoXs
 * @Date: 2023/5/17 14:33
 * @Description:  新能源概览controller
 */
@Api(value = "新能源概览", tags = {"新能源概览"})
@RestController
@RequestMapping("/newEnergySurvey")
@Slf4j
public class NewEnergySurveyController {

    @Autowired
    private INewEnergySurveyService iNewEnergySurveyService;

    /**
     * (同步数据)新能源参与交易电量趋势
     * @return
     */
    @ApiOperation(value = "(同步数据)新能源参与交易电量趋势", response = JoinEnergyTrendDTO.class)
    @PostMapping("/getJoinEnergyTrend")
    public AjaxResult getJoinEnergyTrend() {
        return AjaxResult.success(iNewEnergySurveyService.getJoinEnergyTrend());
    }

    /**
     * (导入数据)新能源装机结构
     *
     * @return
     */
    @ApiOperation(value = "(导入数据)新能源装机结构", response = InstallStructureDTO.class)
    @PostMapping("/getInstallStructure")
    public AjaxResult getInstallStructure() {
        try {
            return AjaxResult.success(iNewEnergySurveyService.getInstallStructure());
        } catch (Exception e) {
            log.error("error: 获取新能源装机结构数据失败!", e);
            return AjaxResult.error("获取新能源装机结构数据失败!");
        }
    }

    /**
     * (导入数据)新能源装机情况
     *
     * @return
     */
    @ApiOperation(value = "(导入数据)新能源装机情况", response = InstallSituationDTO.class)
    @PostMapping("/getInstallSituation")
    public AjaxResult getInstallSituation() {
        try {
            return AjaxResult.success(iNewEnergySurveyService.getInstallSituation());
        } catch (Exception e) {
            log.error("error: 获取新能源装机情况数据失败!", e);
            return AjaxResult.error("获取新能源装机情况数据失败!");
        }
    }

    /**
     * (导入数据)新能源发电趋势
     *
     * @return
     */
    @ApiOperation(value = "(导入数据)新能源发电趋势", response = ElectricTrendDTO.class)
    @PostMapping("/getElectricTrend")
    public AjaxResult getElectricTrend() {
        try {
            return AjaxResult.success(iNewEnergySurveyService.getElectricTrend());
        } catch (Exception e) {
            log.error("error: 获取新能源发电趋势数据失败!", e);
            return AjaxResult.error("获取新能源发电趋势数据失败!");
        }
    }

    /**
     * (导入数据)新能源发电与消纳情况
     * @return
     */
    @ApiOperation(value = "(导入数据)新能源发电与消纳情况", response = ElectricAbsorptionDTO.class)
    @PostMapping("/getElectricAbsorption")
    public AjaxResult getElectricAbsorption() {
        try {
            return AjaxResult.success(iNewEnergySurveyService.getElectricAbsorption());
        }catch (Exception e) {
            log.error("error: 获取新能源发电与消纳情况数据失败!", e);
            return AjaxResult.error("获取新能源发电与消纳情况数据失败!");
        }
    }

    /**
     * (导入数据)新能源参与交易情况
     * @return
     */
    @ApiOperation(value = "(导入数据)新能源参与交易情况", response = JoinTradeDTO.class)
    @PostMapping("/getJoinTrade")
    public AjaxResult getJoinTrade() {
        try {
            return AjaxResult.success(iNewEnergySurveyService.getJoinTrade());
        }catch (Exception e) {
            log.error("error: 获取新能源参与交易情况数据失败!", e);
            return AjaxResult.error("获取新能源参与交易情况数据失败!");
        }
    }

    /**
     * (导入数据)地图上方概览
     * @return
     */
    @ApiOperation(value = "(导入数据)地图上方概览", response = MapTopOverviewDTO.class)
    @PostMapping("/getMapTopOverview")
    public AjaxResult getMapTopOverview() {
        try {
            return AjaxResult.success(iNewEnergySurveyService.getMapTopOverview());
        }catch (Exception e) {
            log.error("error: 获取地图上方概览数据失败!", e);
            return AjaxResult.error("获取地图上方概览数据失败!");
        }
    }
}
