package com.alonginfo.project.gansu.controller.provinceinner;

import com.alonginfo.framework.web.domain.AjaxResult;
import com.alonginfo.project.gansu.domain.*;
import com.alonginfo.project.gansu.service.provinceinner.IProvinceInnerService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * @author: HaoXs
 * @Date: 2023/5/12 09:56
 * @Description:  省内交易情况
 */
@Api(value = "省内交易情况", tags = {"省内交易情况"})
@RestController
@RequestMapping("/provinceInner")
@Slf4j
public class ProvinceInnerController {

    @Autowired
    private IProvinceInnerService iProvinceInnerService;

    /**
     * (同步数据当年交易组织情况
     * @return
     */
    @ApiOperation(value = "(同步数据)当年交易组织情况", response = PiDealOrganizeVo.class)
    @PostMapping("/getDealOrganize")
    public AjaxResult getDealOrganize() {
        return AjaxResult.success(iProvinceInnerService.getDealOrganize());
    }

    /**
     * (同步数据当年市场主体参与情况
     * @return
     */
    @ApiOperation(value = "(同步数据)当年市场主体参与情况", response = PiSubjectJoinVo.class)
    @PostMapping("/getSubjectJoinInfo")
    public AjaxResult getSubjectJoinInfo() {
        return AjaxResult.success(iProvinceInnerService.getSubjectJoinInfo());
    }

    /**
     * (同步数据各电源类型交易电量占比
     * @return
     */
    @ApiOperation(value = "(同步数据)各电源类型交易电量占比", response = PiCleanEnergyVo.class)
    @PostMapping("/getCleanEnergy")
    public AjaxResult getCleanEnergy() {
        return AjaxResult.success(iProvinceInnerService.getCleanEnergy());
    }

    /**
     * (同步数据交易概览
     * @return
     */
    @ApiOperation(value = "(同步数据)交易概览", response = PiDealSurveyDTO.class)
    @PostMapping("/getDealSurvey")
    public AjaxResult getDealSurvey() {
        return AjaxResult.success(iProvinceInnerService.getDealSurvey());
    }

    /**
     * (同步数据当年交易量价走势
     * @return
     */
    @ApiOperation(value = "(同步数据)当年交易量价走势", response = PiPowerPriceTrendDTO.class)
    @PostMapping("/getPowerPriceTrend")
    public AjaxResult getPowerPriceTrend() {
        return AjaxResult.success(iProvinceInnerService.getPowerPriceTrend());
    }

    /**
     * (导入数据)地图弹框数据
     * @return
     */
    @ApiOperation(value = "(导入数据)地图弹框数据", response = MapTextDTO.class)
    @PostMapping("/getMapText")
    public AjaxResult getMapText() {
        try {
            return AjaxResult.success(iProvinceInnerService.getMapText());
        }catch (Exception e) {
            log.error("error: 获取省内交易情况-地图弹框数据失败!", e);
            return AjaxResult.error("获取省内交易情况-地图弹框数据失败!");
        }
    }

    /**
     * (导入数据)历年降低购电成本与交易均价
     * @return
     */
    @ApiOperation(value = "(导入数据)历年降低购电成本与交易均价", response = CostAndAvgDTO.class)
    @PostMapping("/costAndAvgByYear")
    public AjaxResult getCostAndAvgByYear() {
        try {
            return AjaxResult.success(iProvinceInnerService.getCostAndAvgByYear());
        }catch (Exception e) {
            log.error("error: 获取历年降低购电成本与交易均价数据失败!", e);
            return AjaxResult.error("获取历年降低购电成本与交易均价数据失败!");
        }
    }

    /**
     * (导入数据)历年交易规模趋势
     * @return
     */
    @ApiOperation(value = "(导入数据)历年交易规模趋势", response = TradeSizeDTO.class)
    @PostMapping("/tradeSizeByYear")
    public AjaxResult getTradeSizeByYear() {
        try {
            return AjaxResult.success(iProvinceInnerService.getTradeSizeByYear());
        }catch (Exception e) {
            log.error("error: 获取历年交易规模趋势数据失败!", e);
            return AjaxResult.error("获取历年交易规模趋势数据失败!");
        }
    }
}
