package com.alonginfo.project.gansu.controller.provincemiddle;

import com.alonginfo.framework.web.domain.AjaxResult;
import com.alonginfo.project.gansu.domain.*;
import com.alonginfo.project.gansu.service.provincemiddle.IProvinceMiddleService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * @author: HaoXs
 * @Date: 2023/6/14 16:00
 * @Description:  省间交易情况(导入数据)
 */
@Api(value = "省间交易情况", tags = "省间交易情况")
@Slf4j
@RestController
@RequestMapping("/provinceMiddle")
public class ProvinceMiddleController {

    @Autowired
    private IProvinceMiddleService iProvinceMiddleService;

    /**
     * (导入数据)交易组织情况
     * @return
     */
    @ApiOperation(value = "(导入数据)交易组织情况", response = OrganizeAndTypeVO.class)
    @PostMapping("/getOrganize")
    public AjaxResult getOrganize() {
        try {
            return AjaxResult.success(iProvinceMiddleService.getOrganize());
        }catch (Exception e) {
            log.error("error: 获取省内交易情况-交易组织情况与交易类型数据失败!", e);
            return AjaxResult.error("获取省内交易情况-交易组织情况与交易类型数据失败!");
        }
    }

    /**
     * (导入数据)当年外送电量成分
     * @return
     */
    @ApiOperation(value = "(导入数据)当年外送电量成分", response = TradeElectricTypeDTO.class)
    @PostMapping("/getElectricType")
    public AjaxResult getTradeElectricType() {
        try {
            return AjaxResult.success(iProvinceMiddleService.getTradeElectricType());
        }catch (Exception e) {
            log.error("error: 获取各类型电量交易情况数据失败!", e);
            return AjaxResult.error("获取各类型电量交易情况数据失败!");
        }
    }

    /**
     * (导入数据)本年省间交易电量情况
     * @return
     */
    @ApiOperation(value = "(导入数据)本年省间交易电量情况", response = TradeElectricCurrentYearDTO.class)
    @PostMapping("/getTradeElectricCurrentYear")
    public AjaxResult getTradeElectricCurrentYear() {
        try {
            return AjaxResult.success(iProvinceMiddleService.getTradeElectricCurrentYear());
        }catch (Exception e) {
            log.error("error: 获取本年省间交易电量情况数据失败!", e);
            return AjaxResult.error("获取本年省间交易电量情况数据失败!");
        }
    }

    /**
     * (导入数据)历年省间交易电量情况
     * @return
     */
    @ApiOperation(value = "(导入数据)历年省间交易电量情况", response = TradeELectricCalendarYearDTO.class)
    @PostMapping("/getTradeElectricCalendarYear")
    public AjaxResult getTradeElectricCalendarYear() {
        try {
            return AjaxResult.success(iProvinceMiddleService.getTradeElectricCalendarYear());
        }catch (Exception e) {
            log.error("error: 获取历年省间交易电量情况数据失败!", e);
            return AjaxResult.error("获取历年省间交易电量情况数据失败!");
        }
    }

    /**
     * (导入数据)地图上方概览
     * @return
     */
    @ApiOperation(value = "(导入数据)地图上方概览", response = OverviewDTO.class)
    @PostMapping("/getOverview")
    public AjaxResult getOverview() {
        try {
            return AjaxResult.success(iProvinceMiddleService.getOverview());
        }catch (Exception e) {
            log.error("error: 获取地图上方概览数据失败!", e);
            return AjaxResult.error("获取地图上方概览数据失败!");
        }
    }

    /**
     * (导入数据)外送省份及外送电量
     * @return
     */
    @ApiOperation(value = "(导入数据)外送省份及外送电量", response = OutProvinceDTO.class)
    @PostMapping("/getOutProvince")
    public AjaxResult getOutProvince() {
        try {
            return AjaxResult.success(iProvinceMiddleService.getOutProvince());
        }catch (Exception e) {
            log.error("error: 获取外送省份及外送电量数据失败!", e);
            return AjaxResult.error("获取外送省份及外送电量数据失败!");
        }
    }
}
