package com.alonginfo.project.gansu.controller.resources;

import com.alonginfo.framework.web.domain.AjaxResult;
import com.alonginfo.project.gansu.domain.InstallCapicatyPowerDTO;
import com.alonginfo.project.gansu.domain.MapInfoDTO;
import com.alonginfo.project.gansu.domain.MapTopCanvasDTO;
import com.alonginfo.project.gansu.service.resources.IResourcesService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * @author: HaoXs
 * @Date: 2023/6/9 16:38
 * @Description: 资源概况
 */
@Api(value = "资源概览", tags = {"资源概览"})
@RestController
@RequestMapping("/resources")
@Slf4j
public class ResourcesController {

    @Autowired
    private IResourcesService iResourcesService;

    /**
     * (导入数据)地图分布数据
     * @return
     */
    @ApiOperation(value = "(导入数据)地图分布; modelText-弹框数据, mapText-地图数据", response = MapInfoDTO.class)
    @PostMapping("/getMapInfo")
    public AjaxResult getMapInfo() {
        try {
            return AjaxResult.success(iResourcesService.getMapInfo());
        }catch (Exception e) {
            log.error("error: 资源概览-地图分布数据获取失败!");
            return AjaxResult.error("资源概览-地图分布数据获取失败!");
        }
    }

    /**
     * (导入数据)地图右上方图表
     * @return
     */
    @ApiOperation(value = "(导入数据)地图右上方图表", response = MapTopCanvasDTO.class)
    @PostMapping("/getMapTopCanvas")
    public AjaxResult getMapTopData() {
        try {
            return AjaxResult.success(iResourcesService.getMapTopCanvas());
        }catch (Exception e) {
            log.error("error: 资源概览-地图右上方图表数据获取失败!");
            return AjaxResult.error("资源概览-地图右上方图表数据获取失败!");
        }
    }

    /**
     * (导入数据)各类资源装机容量发电量对比
     * @return
     */
    @ApiOperation(value = "(导入数据)各类资源装机容量发电量对比", response = InstallCapicatyPowerDTO.class)
    @PostMapping("/getInstallAndPower")
    public AjaxResult getInstallAndPower() {
        try {
            return AjaxResult.success(iResourcesService.getInstallAndPower());
        }catch (Exception e) {
            log.error("error: 资源概览-各类资源装机容量发电量对比数据获取失败!");
            return AjaxResult.error("资源概览-各类资源装机容量发电量对比数据获取失败!");
        }
    }

    /**
     * (导入数据)资源开发情况
     * @return
     */
    @ApiOperation(value = "(导入数据)资源开发情况")
    @PostMapping("/getResourcesDevelop")
    public AjaxResult getResourcesDevelop() {
        try {
            return AjaxResult.success(iResourcesService.getResourcesDevelop());
        }catch (Exception e) {
            log.error("error: 资源概览-资源开发情况统计数据获取失败!");
            return AjaxResult.error("资源概览-资源开发情况统计数据获取失败!");
        }
    }

    /**
     * (导入数据)各地市资源装机情况
     * @return
     */
    @ApiOperation(value = "(导入数据)各地市资源装机情况")
    @PostMapping("/getPrefectureInstall")
    public AjaxResult getPrefectureInstall() {
        try {
            return AjaxResult.success(iResourcesService.getPrefectureInstall());
        }catch (Exception e) {
            log.error("error: 资源概览-各地市资源装机情况统计数据获取失败!");
            return AjaxResult.error("资源概览-各地市资源装机情况统计数据获取失败!");
        }
    }
}
