package com.alonginfo.project.gansu.controller.tradeSettle;

import com.alonginfo.framework.web.domain.AjaxResult;
import com.alonginfo.project.gansu.domain.*;
import com.alonginfo.project.gansu.service.provincemiddle.IProvinceMiddleService;
import com.alonginfo.project.gansu.service.tradeSettle.TradeSettleService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * @author: HaoXs
 * @Date: 2023/6/14 16:00
 * @Description:  交易结算情况(导入数据)
 */
@Api(value = "交易结算情况", tags = "交易结算情况")
@Slf4j
@RestController
@RequestMapping("/tradeSettle")
public class TradeSettleController {

    @Autowired
    private TradeSettleService tradeSettleService;

    /**
     * (导入数据)省间交易结算情况
     * @return
     */
    @ApiOperation(value = "(导入数据)省间交易结算情况", response = OrganizeAndTypeVO.class)
    @PostMapping("/getProvinceTradeSettle")
    public AjaxResult getProvinceTradeSettle() {
        try {
            return AjaxResult.success(tradeSettleService.getProvinceTradeSettle());
        }catch (Exception e) {
            log.error("error: 获取交易结算情况-省间交易结算情况数据失败!", e);
            return AjaxResult.error("获取交易结算情况-省间交易结算情况数据失败!");
        }
    }

    /**
     * 中间顶部-年度结算电量、年度结算笔数、年度结算均价
     * @return
     */
    @PostMapping("/emossData/emossInfo")
    public AjaxResult getEmossInfo() {
        try {
            return AjaxResult.success(tradeSettleService.getEmossInfo());
        }catch (Exception e) {
            log.error("error: 获取交易结算情况-年度结算电量、年度结算笔数、年度结算均价数据失败!", e);
            return AjaxResult.error("获取交易结算情况-年度结算电量、年度结算笔数、年度结算均价数据失败!");
        }
    }

    /**
     * (导入数据)中间地图数据
     * @return
     */
    @ApiOperation(value = "(导入数据)中间地图数据", response = MapTextDTO.class)
    @PostMapping("/getMapInfo")
    public AjaxResult getMapInfo() {
        try {
            return AjaxResult.success(tradeSettleService.getMapInfo());
        }catch (Exception e) {
            log.error("error: 获取交易结算情况-中间地图数据失败！", e);
            return AjaxResult.error("获取交易结算情况-中间地图数据失败!");
        }
    }
}
