package com.alonginfo.project.gansu.controller.uploadnotice;

import com.alonginfo.framework.web.domain.AjaxResult;
import com.alonginfo.project.gansu.domain.MarketBuildUploadVo;
import com.alonginfo.project.gansu.domain.UploadNoticeVo;
import com.alonginfo.project.gansu.service.uploadnotice.IUploadNoticeService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;
import javax.validation.constraints.NotNull;
import java.util.Map;

/**
 * 交易公告上传页面相关接口
 */
@RestController
@RequestMapping("/uploadNotice")
@Slf4j
public class UploadNoticeController {

    @Autowired
    private IUploadNoticeService iUploadNoticeService;

    /**
     * 获取交易公告上传记录列表
     * @param searchParam
     * @return
     */
    @PostMapping("/getSeqList")
    public AjaxResult getSeqList(@RequestBody Map<String, String> searchParam) {
        try {
            return AjaxResult.success(iUploadNoticeService.getSeqList(searchParam));
        }catch (Exception e) {
            log.error("error: 获取交易公告上传记录列表失败!", e);
            return AjaxResult.error("获取交易公告上传记录列表失败!");
        }
    }

    /**
     * 交易公告上传-文件上传
     * @param uploadNoticeVo
     * @param result
     * @return
     */
    @PostMapping("/uploadNotice")
    public AjaxResult uploadNotice(@Valid UploadNoticeVo uploadNoticeVo, BindingResult result) {
        if (result.hasFieldErrors()) {
            return AjaxResult.error(result.getFieldError().getDefaultMessage());
        }
        try {
            iUploadNoticeService.uploadNotice(uploadNoticeVo);
            return AjaxResult.success("交易公告上传成功!");
        }catch (Exception e) {
            log.error("error: 交易公告上传失败!", e);
            return AjaxResult.error("error: 交易公告上传失败!");
        }
    }

    /**
     * 交易公告上传-删除交易公告
     * @return
     */
    @PostMapping("/delNotice")
    public AjaxResult delNotice(@Valid @NotNull(message = "交易序列id不可为空!") String seqId,
                                @NotNull(message = "文件路径不可为空!") String filePath) {
        iUploadNoticeService.delNotice(seqId, filePath);
        return AjaxResult.success();
    }

    /**
     * 市场建设情况 公告文件上传
     * @param marketBuildUpload
     * @return
     */
    @PostMapping("/marketBuildUpload")
    public AjaxResult marketBuildUpload(@Valid MarketBuildUploadVo marketBuildUpload, BindingResult result) {
        if (result.hasFieldErrors()) {
            return AjaxResult.error(result.getFieldError().getDefaultMessage());
        }
        try {
            iUploadNoticeService.marketBuildUpload(marketBuildUpload);
            return AjaxResult.success("市场建设信息-公告信息上传成功!");
        }catch (Exception e) {
            log.error("error: 市场建设信息-公告信息上传失败!", e);
            return AjaxResult.error("error: 市场建设信息-公告信息上传失败!");
        }
    }

    /**
     * 获取市场建设情况公告列表
     * @param searchParam
     * @return
     */
    @PostMapping("/getMarketList")
    public AjaxResult getMarketList(@RequestBody Map<String, String> searchParam) {
        try {
            return AjaxResult.success(iUploadNoticeService.getMarketList(searchParam));
        }catch (Exception e) {
            log.error("error: 获取市场建设情况公告列表失败!", e);
            return AjaxResult.error("获取市场建设情况公告列表失败!");
        }
    }

    /**
     * 市场建设情况-删除交易公告
     * @return
     */
    @PostMapping("/delMarketImageAndFile")
    public AjaxResult delNotice(@Valid @NotNull(message = "文件标题不可为空!") String fileTitle,
                                @NotNull(message = "文件路径不可为空!") String fileUploadPath,
                                @NotNull(message = "图片路径不可为空!") String imageUploadPath) {
        iUploadNoticeService.delMarketImageAndFile(fileTitle, fileUploadPath, imageUploadPath);
        return AjaxResult.success();
    }
}
