package com.alonginfo.project.gansu.serviceimpl.bilateraconsult;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.TypeReference;
import com.alonginfo.common.utils.http.HttpUtils;
import com.alonginfo.project.gansu.mapper.*;
import com.alonginfo.project.gansu.service.SgccAddressService;
import com.alonginfo.project.gansu.sync.BilateralConsultDataSync;
import com.alonginfo.project.gansu.service.bilateralconsult.BilateralConsultService;
import com.alonginfo.utils.DataPushUtils;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.util.*;
import java.util.concurrent.CompletableFuture;
import java.util.concurrent.ExecutionException;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;
import java.util.stream.Collectors;

/**
 * 双边协商  业务数据处理
 * @author Haoxs
 */
@Service
@Slf4j
public class BilateralConsultServiceImpl implements BilateralConsultService {

    @Value("${env.key}")
    private String ENV_KEY;

    @Value("${sgcc.publicKey}")
    private String PUBLIC_KEY;

    @Autowired
    private SgccAddressService sgccAddressService;

    @Autowired
    private BilateralConsultDataSync bilateralConsultDataSync;

    @Autowired
    private TradeSeqDao tradeSeqDao;

    @Autowired
    private TradeNoticeDao tradeNoticeDao;

    @Autowired
    private TradeStatusDao tradeStatusDao;

    @Autowired
    private EnergyCensusDao energyCensusDao;

    @Autowired
    private RealTimeManyDayDao realTimeManyDayDao;

    @Autowired
    private PriceTrendDao priceTrendDao;

    @Autowired
    private PriceTrendReplayDao priceTrendReplayDao;

    @Override
    public Map<String, Object> getBilateralConsult(String seqId) {
        //判断当前是连接电力交易平台测试环境 or 正式环境
        int environmentId = DataPushUtils.isFormal(sgccAddressService.getSgccAddress(ENV_KEY));

        //获取该屏幕的交易序列列表数据(新增交易序列时, 页面及时刷新)
        Map<String, Object> seqList = environmentId == 1 ? DataPushUtils.handleSeqList(tradeSeqDao.getAll("0")) : DataPushUtils.handleSeqList(tradeSeqDao.getAllTest("0"));
        //获取当前交易序列下的交易公告详情数据
        Map<String, String> notice = DataPushUtils.mapIsEmpty(environmentId == 1 ? tradeNoticeDao.getNoticeBySeqId(seqId) : tradeNoticeDao.getTestNoticeBySeqId(seqId));
        //获取当前交易序列下的购售方确认信息 - 表格数据
        //处理表格数据
        List<LinkedList<String>> buySaleDetails = DataPushUtils.dealBuySaleDetail(bilateralConsultDataSync.getDeclareDetailList(seqId));
        //获取当前交易序列下的交易情况
        Map<String, String> tradeStatus = DataPushUtils.mapIsEmpty(environmentId == 1 ? tradeStatusDao.getStatusBySeqId(seqId) : tradeStatusDao.getTestStatusBySeqId(seqId));
        //获取当前交易序列下的发电类型统计
        List<Map<String, String>> cenSus = environmentId == 1 ? energyCensusDao.getCenSusBySeqId(seqId) : energyCensusDao.getTestCenSusBySeqId(seqId);
        //获取当前交易序列下的交易量价走势分析
        //处理交易量价走势数据
        //判断是实时多日成交/实时非多日成交还是回演
        List<Map<String, String>> seqDataList= (List<Map<String, String>>) seqList.get("list");
        int type = 0;
        for (Map<String, String> map : seqDataList) {
            String tradeSeqId = map.get("tradeSeqId");
            if (seqId.equals(tradeSeqId)) {
                type = Integer.valueOf(map.get("type"));
            }
        }
        //交易量价走势
        Map<String, Object> dealTrends = new HashMap<>();
        if (type == 2) {
            //实时多日成交
            Map<String, List<String>> peak = DataPushUtils.handleRealTimeManyDay(environmentId == 1 ? realTimeManyDayDao.getRealTimeManyDay("峰") : realTimeManyDayDao.getTestRealTimeManyDay("峰"));
            Map<String, List<String>> flat = DataPushUtils.handleRealTimeManyDay(environmentId == 1 ? realTimeManyDayDao.getRealTimeManyDay("平") : realTimeManyDayDao.getTestRealTimeManyDay("平"));
            Map<String, List<String>> valley = DataPushUtils.handleRealTimeManyDay(environmentId == 1 ? realTimeManyDayDao.getRealTimeManyDay("谷") : realTimeManyDayDao.getTestRealTimeManyDay("谷"));
            dealTrends.put("peak", peak);
            dealTrends.put("flat", flat);
            dealTrends.put("valley", valley);
        }else if (type == 1) {
            //实时非多日成交 20230824修改: 接口传递全量峰、平、谷数据
            try {
                dealTrends = dealTrendsByAllData(getTrendsReplayByInterface(seqId));
            } catch (Exception e) {
                log.error("交易量价走势-实时非多日成交Error: ", e);
            }
        }else {
            //回演
            dealTrends = DataPushUtils.dealTrendReplays(environmentId == 1 ? priceTrendReplayDao.getTrendReplayBySeqId(seqId) : priceTrendReplayDao.getTestTrendReplayBySeqId(seqId));

        }
        //封装结果
        Map<String, Object> resultMap = new HashMap<>();
        resultMap.put("seqList", seqList);
        resultMap.put("tradeNotice", notice == null ? new HashMap<>() : notice);
        resultMap.put("buySaleDetails", buySaleDetails);
        resultMap.put("tradeStatus", tradeStatus == null ? new HashMap<>() : tradeStatus);
        resultMap.put("cenSus", cenSus);
        resultMap.put("dealTrends", dealTrends);
        return resultMap;
    }


    /**
     * 处理交易量价走势数据 - 实时月度数据(峰、平、谷全量数据)
     * @param trends
     * @return
     * @throws ExecutionException
     * @throws InterruptedException
     */
    private Map<String, Object> dealTrendsByAllData(List<Map<String, String>> trends) throws InterruptedException, ExecutionException {
        long start = System.currentTimeMillis();
        if (trends==null || trends.size()==0) {
            return new HashMap<>();
        }
        //按createTime分组
        Map<String, List<Map<String, String>>> treadsGroupResult = trends.stream().collect(Collectors.groupingBy(t -> t.get("createTime")));
        //将map进行拆分
        List<Map<String, List<Map<String, String>>>> splitByGroupList = DataPushUtils.splitByGroupSize(treadsGroupResult, 10);

        ExecutorService executor = Executors.newFixedThreadPool(10);
        //多线程处理
        List<CompletableFuture<List<Map<String, String>>>> handleFutures = splitByGroupList.stream().map(groupList ->
                CompletableFuture.supplyAsync(() -> handlePeakFlatValley(groupList), executor)).collect(Collectors.toList());
        //收集结果数据
        CompletableFuture<Void> allFutures = CompletableFuture
                .allOf(handleFutures.toArray(new CompletableFuture[handleFutures.size()]));
        //阻塞
        allFutures.get();

        List<Map<String, String>> noOrderResList = new ArrayList<>();
        for(CompletableFuture<List<Map<String, String>>> future : handleFutures) {
            List<Map<String, String>> list = future.get();
            noOrderResList.addAll(list);
        }
        long endOne = System.currentTimeMillis();
        log.info("处理峰、平、谷数据耗时: {}毫秒 ", (endOne - start));

        List<Map<String, String>> orderList = noOrderResList.stream().sorted(Comparator.comparing(map -> String.valueOf(map.get("reportTime")))).collect(Collectors.toList());
        Map<String, Object> result = DataPushUtils.dealTrends(orderList);
        long endTwo = System.currentTimeMillis();
        log.info("封装前端所需数据耗时: {} 毫秒", (endTwo - start));
        return result;
    }

    /**
     * 数据处理
     * @param map
     * @return
     */
    private List<Map<String, String>> handlePeakFlatValley(Map<String, List<Map<String, String>>> map) {
        if (map == null || map.size() == 0) {
            return new ArrayList<>();
        }

        List<Map<String, String>> result = new ArrayList<>();
        try {
            for(Map.Entry<String, List<Map<String, String>>> m : map.entrySet()) {
                String time = m.getKey();
                //峰
                Map<String, String> peakMap = m.getValue().stream().filter(f -> "峰".equals(f.get("timeRange"))).findFirst().orElse(new HashMap<>());
                //平
                Map<String, String> flatMap = m.getValue().stream().filter(f -> "平".equals(f.get("timeRange"))).findFirst().orElse(new HashMap<>());
                //谷
                Map<String, String> valleyMap = m.getValue().stream().filter(f -> "谷".equals(f.get("timeRange"))).findFirst().orElse(new HashMap<>());

                Map<String, String> itemMap = new HashMap<>();
                itemMap.put("reportTime", time);
                itemMap.put("peakEnergy", Optional.ofNullable(peakMap.get("sumEnergy")).orElse("0"));
                itemMap.put("peakAvgValue", Optional.ofNullable(peakMap.get("avgPrice")).orElse("0"));
                itemMap.put("flatEnergy", Optional.ofNullable(flatMap.get("sumEnergy")).orElse("0"));
                itemMap.put("flatAvgValue", Optional.ofNullable(flatMap.get("avgPrice")).orElse("0"));
                itemMap.put("valleyEnergy", Optional.ofNullable(valleyMap.get("sumEnergy")).orElse("0"));
                itemMap.put("valleyAvgValue", Optional.ofNullable(valleyMap.get("avgPrice")).orElse("0"));
                result.add(itemMap);
            }
        } catch (Exception e) {
            log.error("error:", e);
        }
        return result;
    }

    /**
     *  获取交易量价走势(非多日成交) - 实时数据
     * @param seqId
     * @throws Exception
     */
    private List<Map<String, String>> getTrendsReplayByInterface(String seqId) {

        try {
            long startTime = System.currentTimeMillis();
            String sgccUrl = sgccAddressService.getSgccAddress(ENV_KEY);
            String priceTrendResult = HttpUtils.sendPost(sgccUrl + "/dataPush/tradeEnergyPriceLine/selectTradeEnergyPriceBySeqId", "seqId="+seqId, DataPushUtils.createToken(PUBLIC_KEY));
            //String priceTrendResult = HttpUtils.sendPost("http://localhost:16016/dataPush/tradeEnergyPriceLine/selectTradeEnergyPriceLineData", "seqId="+seqId, DataPushUtils.createToken(PUBLIC_KEY));
            log.info("获取双边协商-交易量价走势-实时数据, 接口调用结果: {}", priceTrendResult);
            if(priceTrendResult == null || "".equals(priceTrendResult)) {
                log.info("获取双边协商-交易量价走势-实时数据, 接口调用结果为空！");
                return new ArrayList<>();
            }
            Map<String, Object> priceTrendObj = JSON.parseObject(priceTrendResult, Map.class);
            List<Map<String, String>> priceTrendData =  JSON.parseObject(JSON.toJSONString(priceTrendObj.get("data")), new TypeReference<List<Map<String, String>>>(){});
            if (priceTrendData == null || priceTrendData.size() == 0) {
                log.info("获取双边协商-交易量价走势-实时数据, data值为NUll或者为空! data: {}", priceTrendData);
                return new ArrayList<>();
            }
            long entTime = System.currentTimeMillis();
            log.info("双边协商-交易量价走势-实时数据接口耗时：{}", (entTime-startTime)/1000);
            return priceTrendData;
        } catch (Exception e) {
            log.info("交易量价走势(非多日成交) - 实时数据接口数据获取失败!, 方法名: {}, 接口路径: {} ", "getTrendsReplayByInterface", "/dataPush/tradeEnergyPriceLine/selectTradeEnergyPriceLineData");
            e.printStackTrace();
            return new ArrayList<>();
        }
    }
}
