package com.alonginfo.project.gansu.serviceimpl.carbon;

import com.alonginfo.common.utils.StringUtils;
import com.alonginfo.project.gansu.domain.common.EchartsCommonDTO;
import com.alonginfo.project.gansu.domain.CarbonMapTopContentDTO;
import com.alonginfo.project.gansu.domain.ClearInstallTrendDTO;
import com.alonginfo.project.gansu.domain.ClearReduceGainDTO;
import com.alonginfo.project.gansu.domain.IndustryEmissionDTO;
import com.alonginfo.project.gansu.mapper.CarbonMonitorMapper;
import com.alonginfo.project.gansu.service.carbon.ICarbonMonitorService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.LinkedList;
import java.util.List;
import java.util.Map;

/**
 * @author: HaoXs
 * @Date: 2023/6/19 10:20
 * @Description: 双碳检测
 */
@Service
public class CarbonMonitorServiceImpl implements ICarbonMonitorService {

    @Autowired
    private CarbonMonitorMapper carbonMonitorMapper;

    /**
     * 发电企业碳排放情况
     * @return
     */
    @Override
    public EchartsCommonDTO<String> getEnterpriseEmission() {
        List<Map<String, String>> emissions = carbonMonitorMapper.queryEnterpriseEmission();
        if (StringUtils.isEmpty(emissions)) {
            return new EchartsCommonDTO<>();
        }
        List<String> xAxis = new LinkedList<>();
        List<String> seriesData = new LinkedList<>();
        for (Map<String, String> emission : emissions) {
            xAxis.add(emission.get("dataYear"));
            seriesData.add(emission.get("emissionValue"));
        }

        EchartsCommonDTO<String> result = new EchartsCommonDTO<>();
        result.setXAxisData(xAxis);
        result.setSeriesData(seriesData);
        return result;
    }

    /**
     * 各行业电力用户碳排放情况
     * @return
     */
    @Override
    public IndustryEmissionDTO getIndustryEmission() {
        Map<String, String> industry = carbonMonitorMapper.queryIndustryEmission();
        if (StringUtils.isEmpty(industry)) {
            return new IndustryEmissionDTO();
        }
        return IndustryEmissionDTO.builder()
                .sum(industry.get("summary"))
                .nlmyy(industry.get("farming"))
                .gy(industry.get("industry"))
                .jzy(industry.get("building"))
                .jtyscc(industry.get("traffic"))
                .rjxxjs(industry.get("software"))
                .pflsy(industry.get("retailWholesale"))
                .zscyy(industry.get("stayFoot"))
                .jry(industry.get("finance"))
                .fdcy(industry.get("realEstate"))
                .zlsfwy(industry.get("leaseService"))
                .ggfwglzz(industry.get("commonManage")).build();
    }

    /**
     * 清洁能源装机趋势
     * @return
     */
    @Override
    public ClearInstallTrendDTO getClearInstallTrend() {
        List<Map<String, String>> clearInstallTrends = carbonMonitorMapper.queryClearInstallTrend();
        if (StringUtils.isEmpty(clearInstallTrends)) {
            return new ClearInstallTrendDTO();
        }
        List<String> xAxis = new LinkedList<>();
        List<String> installCapacityList = new LinkedList<>();
        List<String> installRatioList = new LinkedList<>();
        for (Map<String, String> clearInstallTrend : clearInstallTrends) {
            xAxis.add(clearInstallTrend.get("dataYear"));
            installCapacityList.add(clearInstallTrend.get("installCapacity"));
            installRatioList.add(clearInstallTrend.get("installRatio"));
        }

        ClearInstallTrendDTO result = new ClearInstallTrendDTO();
        result.setXData(xAxis);
        result.setInstallCapacity(installCapacityList);
        result.setInstallRatio(installRatioList);
        return result;
    }

    /**
     * 清洁能源减排成果
     * @return
     */
    @Override
    public ClearReduceGainDTO getClearReduceGain() {
        List<Map<String, String>> clearReduceGains = carbonMonitorMapper.queryClearReduceGain();
        if(StringUtils.isEmpty(clearReduceGains)) {
            return new ClearReduceGainDTO();
        }
        List<String> xAxis = new LinkedList<>();
        List<String> seriesData = new LinkedList<>();
        for (Map<String, String> clearReduceGain : clearReduceGains) {
            xAxis.add(clearReduceGain.get("dataYear"));
            seriesData.add(clearReduceGain.get("clearReduceValue"));
        }

        ClearReduceGainDTO result = new ClearReduceGainDTO();
        result.setXAxisData(xAxis);
        result.setSeriesData(seriesData);
        return result;
    }

    /**
     * 地图上方概览
     * @return
     */
    @Override
    public CarbonMapTopContentDTO getCarbonMapTopContent() {
        Map<String, String> carbonMapTopContent = carbonMonitorMapper.queryCarbonMapTopContent();
        if (StringUtils.isEmpty(carbonMapTopContent)) {
            return new CarbonMapTopContentDTO();
        }
        return CarbonMapTopContentDTO.builder()
                .societyUsePower(carbonMapTopContent.get("societyUse"))
                .societyUsePowerYoy(carbonMapTopContent.get("societyUserYoy"))
                .clearReduce(carbonMapTopContent.get("clearReduce"))
                .clearReduceYoy(carbonMapTopContent.get("clearReduceYoy"))
                .clearEnergyRatio(carbonMapTopContent.get("clearEnergyRatio"))
                .clearEnergyRatioYoy(carbonMapTopContent.get("clearEnergyYoy")).build();
    }
}
