package com.alonginfo.project.gansu.serviceimpl.clearenergy;

import com.alonginfo.common.utils.StringUtils;
import com.alonginfo.project.gansu.domain.common.EchartsCommonDTO;
import com.alonginfo.project.gansu.domain.ClearAbsorptionAnalysisDTO;
import com.alonginfo.project.gansu.domain.ClearRationDTO;
import com.alonginfo.project.gansu.domain.MapTopContentDTO;
import com.alonginfo.project.gansu.mapper.ClearEnergyAbsorptionMapper;
import com.alonginfo.project.gansu.service.clearenergy.IClearEnergyAbsorptionService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.*;

/**
 * @author: HaoXs
 * @Date: 2023/6/16 15:35
 * @Description:  清洁能源消纳
 */
@Service
public class ClearEnergyAbsorptionServiceImpl implements IClearEnergyAbsorptionService {

    @Autowired
    private ClearEnergyAbsorptionMapper clearEnergyAbsorptionMapper;

    /**
     * 当年清洁能源消纳趋势
     * @return
     */
    @Override
    public EchartsCommonDTO<String> getAbsorptionTrendCurrentYear() {
        List<Map<String, String>> currentYearTrends = clearEnergyAbsorptionMapper.queryAbsorptionTrendByNowYear();
        if (StringUtils.isEmpty(currentYearTrends)) {
            return new EchartsCommonDTO<>();
        }

        List<String> xData = new LinkedList<>();
        List<String> seriesData = new LinkedList<>();
        for (Map<String, String> currentYearTrend : currentYearTrends) {
            xData.add(currentYearTrend.get("dataMonth"));
            seriesData.add(currentYearTrend.get("absorptionValue"));
        }

        EchartsCommonDTO<String> result = new EchartsCommonDTO<>();
        result.setXAxisData(xData);
        result.setSeriesData(seriesData);
        return result;
    }

    /**
     * 历年清洁能源消纳情况
     * @return
     */
    @Override
    public ClearRationDTO getClearRatioByCalendarYear() {
        List<Map<String, String>> clearRatioCalendarYears = clearEnergyAbsorptionMapper.queryClearRatioByCalendarYear();
        if (StringUtils.isEmpty(clearRatioCalendarYears)) {
            return new ClearRationDTO();
        }

        List<String> yData = new LinkedList<>();
        List<String> gf = new LinkedList<>();
        List<String> sd = new LinkedList<>();
        List<String> fd = new LinkedList<>();
        for (Map<String, String> clearRatioCalendarYear : clearRatioCalendarYears) {
            String dataYear = clearRatioCalendarYear.get("dataYear");
            String dataYearRes = dataYear.contains("年") ? dataYear : dataYear + "年";
            yData.add(dataYearRes);
            gf.add(clearRatioCalendarYear.get("lightRatio"));
            sd.add(clearRatioCalendarYear.get("waterRatio"));
            fd.add(clearRatioCalendarYear.get("windRatio"));
        }

        ClearRationDTO result = new ClearRationDTO();
        result.setYData(yData);
        result.setGf(gf);
        result.setSd(sd);
        result.setFd(fd);
        return result;
    }

    /**
     * 清洁能源消纳分析
     * @return
     */
    @Override
    public ClearAbsorptionAnalysisDTO getClearAbsorptionAnalysis() {
        List<Map<String, String>> clearAbsorptionAnalysisList = clearEnergyAbsorptionMapper.queryClearAbsorptionAnalysis();
        if (StringUtils.isEmpty(clearAbsorptionAnalysisList)) {
            return new ClearAbsorptionAnalysisDTO();
        }

        List<Map<String, String>> echartDataList = new ArrayList<>();
        Map<String, String> water = new HashMap<>();
        Map<String, String> wind = new HashMap<>();
        Map<String, String> light = new HashMap<>();
        for (Map<String, String> map : clearAbsorptionAnalysisList) {
            String energyType = map.get("energyType");
            String absorptionValue = map.get("absorptionValue");
            String absorptionRatio = map.get("absorptionRatio");
            String flag = map.get("yoyTrend");
            String yoyValue = map.get("yoyValue");

            //饼图
            Map<String, String> echartDataItem = new HashMap<>();
            echartDataItem.put("name", energyType);
            echartDataItem.put("value", absorptionValue);
            echartDataList.add(echartDataItem);

            //表格
            Map<String, String> tableData = new HashMap<>();
            tableData.put("xn", absorptionValue);
            tableData.put("xnl", absorptionRatio);
            tableData.put("tb", yoyValue);
            tableData.put("flag", flag);
            if (energyType.contains("水")) {
                water = tableData;
            } else if (energyType.contains("风")) {
                wind = tableData;
            } else if (energyType.contains("光")) {
                light = tableData;
            } else {

            }
        }
        ClearAbsorptionAnalysisDTO result = new ClearAbsorptionAnalysisDTO();
        result.setEchartData(echartDataList);
        result.setWater(water);
        result.setLight(light);
        result.setWind(wind);
        return result;
    }

    /**
     * 清洁能源消纳趋势
     * @return
     */
    @Override
    public EchartsCommonDTO<String> getClearAbsorptionTrend() {
        List<Map<String, String>> trends = clearEnergyAbsorptionMapper.queryClearAbsorptionTrend();
        if (StringUtils.isEmpty(trends)) {
            return new EchartsCommonDTO<>();
        }
        List<String> xData = new LinkedList<>();
        List<String> seriesData = new LinkedList<>();
        for (Map<String, String> trend : trends) {
            xData.add(trend.get("dataYear"));
            seriesData.add(trend.get("dataValue"));
        }

        EchartsCommonDTO<String> result = new EchartsCommonDTO<>();
        result.setXAxisData(xData);
        result.setSeriesData(seriesData);
        return result;
    }

    /**
     * 地图上方概览
     * @return
     */
    @Override
    public MapTopContentDTO getMapTopContent() {
        Map<String, String> mapTopContent = clearEnergyAbsorptionMapper.queryMapTopContent();
        if (StringUtils.isEmpty(mapTopContent)) {
            return new MapTopContentDTO();
        }
        MapTopContentDTO mapTopContentDTO = new MapTopContentDTO();
        mapTopContentDTO.setAbsorption(mapTopContent.get("absorption"));
        mapTopContentDTO.setPower(mapTopContent.get("power"));
        mapTopContentDTO.setSaveCoal(mapTopContent.get("saveCoal"));
        mapTopContentDTO.setReductionCo2(mapTopContent.get("reductionCo2"));
        mapTopContentDTO.setAbsorptionRateTb(mapTopContent.get("absorptionRateTb"));
        mapTopContentDTO.setAbsorptionRateAllLow(mapTopContent.get("absorptionRateAllLow"));
        mapTopContentDTO.setAbsorptionRateNoWaterLow(mapTopContent.get("absorptionRateNoWaterLow"));
        mapTopContentDTO.setAbsorptionRateCompleteAll(mapTopContent.get("absorptionRateCompleteAll"));
        mapTopContentDTO.setAbsorptionRateCompleteNoWater(mapTopContent.get("absorptionRateCompleteNoWater"));
        return mapTopContentDTO;
    }
}
