package com.alonginfo.project.gansu.serviceimpl.dayaddthree;

import com.alibaba.fastjson.JSON;
import com.alonginfo.project.gansu.service.dayaddthree.DayAddThreeService;
import com.alonginfo.project.gansu.service.dayaddthree.DayAddThreeSyncGet;
import lombok.extern.slf4j.Slf4j;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.concurrent.CompletableFuture;

@Service
@Slf4j
public class DayAddThreeDataReturnImpl implements DayAddThreeSyncGet {

	private static final Logger logger = LoggerFactory.getLogger(DayAddThreeSyncGet.class);

	@Autowired
	private DayAddThreeService dayAddThreeService;

	/**
	 *  D+3页面异步数据返回
	 */
	@Override
	public Map<String, Object> dayAddThreeDataReturn(String seqId) {
		try {
			long startTime = System.currentTimeMillis();
			//交易序列
			CompletableFuture<Map<String, Object>> seq = dayAddThreeService.getDayAddTreeTradeSeq();
			//交易公告
			CompletableFuture<Map<String, Object>> tradeNotice = dayAddThreeService.getDayAddThreeTradeNotice();

			//交易情况-发电、用户申报电量、成交电量
			//买方、卖方发电申报电量+用户申报电量  (赋值给)= 申报明细-买卖方申报电量
			//买方发电成交电量+用户成交电量 = 卖方发电成交电量+用户成交电量(一直是0) = 实时成交成交电量
			CompletableFuture<Map<String, Object>> yieldUserForStatus = dayAddThreeService.getYieldUserForStatus();

			//交易情况(成交电量、成交均价、最高最低成交价展示在实时成交模块)
			CompletableFuture<Map<String, Object>> tradeStatus = dayAddThreeService.getDayAddThreeTradeStatus();
			//申报明细
			CompletableFuture<List<List<String>>> reportDetails = dayAddThreeService.getDayAddThreeReportDetails(seqId);
			//实时成交
			CompletableFuture<List<List<String>>> realTimeDeal = dayAddThreeService.getDayAddThreeRealTimeDeal();
			//当日分时段
			CompletableFuture<Map<String, Object>> everyTimeSlotDeal = dayAddThreeService.getDayAddThreeEveryTimeSlotDeal();
			//各日成交
			CompletableFuture<Map<String, Object>> everyDayDeal = dayAddThreeService.getDayAddThreeEveryDayDeal();
			//累计申报、累计成交
			CompletableFuture<Map<String, Object>> reportDealNum = dayAddThreeService.getReportDealNum();

			//申报明细-买卖方申报电量、申报均价
			CompletableFuture<Map<String, Object>>energyPriceForDetails = dayAddThreeService.getEnergyPriceForDetails();

			//收集返回值
			CompletableFuture.allOf(seq, tradeNotice, yieldUserForStatus, tradeStatus, reportDetails, realTimeDeal, everyTimeSlotDeal, everyDayDeal, reportDealNum, energyPriceForDetails);

			log.info("交易序列: {}", JSON.toJSONString(seq.get()));
			log.info("交易公告: {}", JSON.toJSONString(tradeNotice.get()));
			log.info("交易情况-发电、用户申报电量、成交电量: {}", JSON.toJSONString(yieldUserForStatus.get()));
			log.info("交易情况: {}", JSON.toJSONString(tradeStatus.get()));
			log.info("申报明细: {}", JSON.toJSONString(reportDetails.get()));
			log.info("实时成交: {}", JSON.toJSONString(realTimeDeal.get()));
			log.info("当日分时段: {}", JSON.toJSONString(everyTimeSlotDeal.get()));
			log.info("各日成交: {}", JSON.toJSONString(everyDayDeal.get()));
			log.info("累计申报、累计成交: {}", JSON.toJSONString(reportDealNum.get()));
			log.info("申报明细-买卖方申报电量、申报均价: {}", JSON.toJSONString(energyPriceForDetails.get()));
			Map<String, Object> result = new HashMap<>();
			result.put("seqList", seq.get());
			result.put("tradeNotice", tradeNotice.get());
			result.put("tradeStatus", tradeStatus.get());
			result.put("reportDetails", reportDetails.get());
			result.put("realTimeDeal", realTimeDeal.get());
			result.put("timeSlotDeal", everyTimeSlotDeal.get());
			result.put("everyDayDeal", everyDayDeal.get());
			result.put("reportDealNum", reportDealNum.get());
			result.put("yieldUserForStatus", yieldUserForStatus.get());
			result.put("energyPriceForDetails", energyPriceForDetails.get());
			long endTime = System.currentTimeMillis();
			logger.info("-----D+3滚动交易页面总耗时:  {}s", (endTime-startTime)/1000);
			return result;
		} catch (Exception e) {
			e.printStackTrace();
			return new HashMap<>();
		}
	}
}
