package com.alonginfo.project.gansu.serviceimpl.dayaddthree;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.alonginfo.common.utils.StringUtils;
import com.alonginfo.common.utils.http.HttpUtils;
import com.alonginfo.project.gansu.mapper.DayAddThreeDao;
import com.alonginfo.project.gansu.service.SgccAddressService;
import com.alonginfo.project.gansu.service.dayaddthree.DayAddThreeService;
import com.alonginfo.utils.DataPushUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.scheduling.annotation.Async;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.time.LocalDate;
import java.time.format.DateTimeFormatter;
import java.util.*;
import java.util.concurrent.CompletableFuture;
import java.util.stream.Collectors;

/**
 * D+3滚动交易 业务层实现
 * @author Administrator
 *
 */
@Service
public class DayAddThreeServiceImpl implements DayAddThreeService {

    private static final Logger logger = LoggerFactory.getLogger(DayAddThreeServiceImpl.class);

    private final Map<String, Object> map = new HashMap<>();

    private final List<List<String>> list = new ArrayList<>();

    @Value("${env.key}")
    private String ENV_KEY;

    @Value("${sgcc.publicKey}")
    private String PUBLIC_KEY;

    @Autowired
    private SgccAddressService sgccAddressService;

    @Autowired
    private DayAddThreeDao dayAddThreeDao;

    /**
     * 	实时成交
     */
    public ThreadLocal<BigDecimal> energyThreadLocal = new ThreadLocal<>();

    /**
     * 	买方申报电量 = 买方发电申报电量+买方用户申报电量
     */
    public ThreadLocal<BigDecimal> buyReportThreadLocal = new ThreadLocal<>();

    /**
     * 	 卖方申报电量 = 卖方发电申报电量+卖方用户申报电量
     */
    public ThreadLocal<BigDecimal> saleReportThreadLocal = new ThreadLocal<>();

    /**
     * 获取D+3滚动交易 --- 交易序列
     * @throws Exception
     */
    @Override
    @Async
    public CompletableFuture<Map<String, Object>> getDayAddTreeTradeSeq() {
        try {
            //获取电力交易平台地址
            long start = System.currentTimeMillis();
            String sgccUrl = sgccAddressService.getSgccAddress(ENV_KEY);
//			String sgccUrl = "http://39.96.27.4:17017";
//			String sgccUrl = "http://127.0.0.1:16016";
            //接口地址
            String mappingAddress = sgccUrl + "/dataPush/dayRolls/selectDayRolls";
            String tradeSeqResultString = HttpUtils.sendPost(mappingAddress, "", DataPushUtils.createToken(PUBLIC_KEY));
            logger.info("-D+3: 获取D+3滚动交易 - 交易序列数据结果：{}", tradeSeqResultString);
            if (StringUtils.isEmpty(tradeSeqResultString)) {
                logger.info("-D+3: 获取D+3滚动交易 - 交易序列数据结果为空, ip: {}, 接口地址: {}", sgccUrl, mappingAddress);
                return CompletableFuture.completedFuture(map);
            }
            Map<String, Object> resultObj = JSON.parseObject(tradeSeqResultString, Map.class);
            List<Map> tradeSeqList = JSON.parseArray(JSON.toJSONString(resultObj.get("data")), Map.class);
            //遍历重组数据
            //交易序列数据
            List<Map<String, String>> seqResult = new ArrayList<Map<String,String>>();
            //交易序列id数据
            List<String> tradeIds = new ArrayList<>();
            for(Map item : tradeSeqList) {
                Map<String, String> map = new HashMap<String, String>();
                map.put("tradeSeqId", String.valueOf(item.get("tradeSeqId")));
                map.put("tradeSeqCaption", String.valueOf(item.get("tradeSeqCaption")));
                seqResult.add(map);
                tradeIds.add(String.valueOf(item.get("tradeSeqId")));

            }
            //封装结果
            //交易序列id目的是昨日数据切换到今日数据时，下拉框绑定值改变
            Map<String, Object> result = new HashMap<>();
            result.put("list", seqResult);
            result.put("arr", tradeIds);
            long end = System.currentTimeMillis();
            logger.info("-D+3获取交易序列接口耗时: {}s", (end - start) / 1000);
            return CompletableFuture.completedFuture(result);
        } catch (Exception e) {
            logger.error("D+3 - 交易序列数据获取失败!, {}", e);
            return CompletableFuture.completedFuture(map);
        }
    }

    /**
     *  获取D+3滚动交易 -- 交易公告
     * 异步获取接口返回数据, 同步封装返回 CompletableFuture
     */
    @Override
    @Async
    public CompletableFuture<Map<String, Object>> getDayAddThreeTradeNotice() {
        try {
            //获取电力交易平台地址
            long start = System.currentTimeMillis();
            String sgccUrl = sgccAddressService.getSgccAddress(ENV_KEY);
//			String sgccUrl = "http://39.96.27.4:17017";
//			String sgccUrl = "http://127.0.0.1:16016";
            //接口地址
            String mappingAddress = sgccUrl + "/dataPush/dayRolls/selectDayRollsNotice";
            String tradeNoticeResultString = HttpUtils.sendPost(mappingAddress, "", DataPushUtils.createToken(PUBLIC_KEY));
            logger.info("-D+3: 获取D+3滚动交易 - 交易公告结果：{}", tradeNoticeResultString);
            if (StringUtils.isEmpty(tradeNoticeResultString)) {
                logger.info("-D+3: 获取D+3滚动交易 - 交易公告数据结果为空, ip: {}, 接口地址: {}", sgccUrl, mappingAddress);
                return CompletableFuture.completedFuture(map);
            }
            Map<String, Object> resultObj = JSON.parseObject(tradeNoticeResultString, Map.class);
            Map<String, Object> data = (Map<String, Object>) resultObj.get("data");

            //结果数据
            Map<String, Object> result = new HashMap<>();
            result.put("tradeTypeMode", Optional.ofNullable(data.get("tradeType")).orElse(""));
            result.put("resPubTime", Optional.ofNullable(data.get("ntime")).orElse(""));
            result.put("beginDate", Optional.ofNullable(data.get("beginTime")).orElse(""));
            result.put("endDate", Optional.ofNullable(data.get("endTime")).orElse(""));
            result.put("saleNum", Optional.ofNullable(data.get("perCount")).orElse(""));
            result.put("vendeeNum", Optional.ofNullable(data.get("vendeeCount")).orElse(""));

            //修改交易周期格式  xxxx年xx月xx日 -> xxxx-xx-xx
            Date date = new SimpleDateFormat("yyyy年MM月dd日").parse(String.valueOf(Optional.ofNullable(data.get("tradeCyc")).orElse("")).split("-")[0]);
            String format = new SimpleDateFormat("yyyy-MM-dd").format(date);
            result.put("tradeSeqCycle", format);
            result.put("resultIssue", String.valueOf(Optional.ofNullable(data.get("pubTime")).orElse("")).split(" ")[0]);
            long end = System.currentTimeMillis();
            logger.info("-D+3获取交易公告接口耗时: {}s", (end - start)/1000);
            return CompletableFuture.completedFuture(result);
        } catch (Exception e) {
            logger.error("D+3 - 交易公告数据获取失败!, {}", e);
            return CompletableFuture.completedFuture(map);
        }
    }

    /**
     * 获取D+3滚动交易  -- 交易情况
     * @return
     * @throws Exception
     */
    @Override
    @Async
    public CompletableFuture<Map<String, Object>> getDayAddThreeTradeStatus() {
        try {
            //获取电力交易平台地址
            long start = System.currentTimeMillis();
            String sgccUrl = sgccAddressService.getSgccAddress(ENV_KEY);
//			String sgccUrl = "http://39.96.27.4:17017";
//			String sgccUrl = "http://127.0.0.1:16016";
            //接口地址
            String mappingAddress = sgccUrl + "/dataPush/dayRolls/selectDayRollsTradeReport";
            String tradeStatusResultString = HttpUtils.sendPost(mappingAddress, "", DataPushUtils.createToken(PUBLIC_KEY));
            logger.info("-D+3: 获取D+3滚动交易 - 交易情况数据结果, {}", tradeStatusResultString);
            if (StringUtils.isEmpty(tradeStatusResultString)) {
                logger.info("-D+3: 获取D+3滚动交易 - 交易情况数据结果为空, ip: {}, 接口地址: {}", sgccUrl, mappingAddress);
                return CompletableFuture.completedFuture(map);
            }
            Map<String, Object> tradeStatusResultMap = JSON.parseObject(tradeStatusResultString, Map.class);
            Map<String, Object> data = (Map<String, Object>) tradeStatusResultMap.get("data");

            //结果封装
            Map<String, Object> result = new HashMap<>();
            result.put("saleSuoteNum", data.get("saleReportNum"));
            result.put("saleEnergy", retainDigit(data.get("saleReportEnergy")));
            result.put("saleResultNum", data.get("saleDealNum"));
            result.put("vendeeConfimNum", data.get("vendeeReportNum"));
            result.put("vendeeEnergy", retainDigit(data.get("vendeeReportEnergy")));
            result.put("vendeeNum", data.get("vendeeDealNum"));
            //展示到页面实时成交模块右侧
            result.put("energy",  energyThreadLocal.get());
            result.put("avgPrice", retainDigit(data.get("avgPrice")));
            result.put("maxPrice", retainDigit(data.get("maxPrice")));
            result.put("minPrice", retainDigit(data.get("minPrice")));
            long end = System.currentTimeMillis();
            logger.info("-D+3获取交易情况接口耗时: {} s", (end -start)/1000);
            return CompletableFuture.completedFuture(result);
        } catch (Exception e) {
            logger.error("D+3-交易情况数据获取失败!: {}", e);
            return CompletableFuture.completedFuture(map);
        }
    }

    /**
     * 获取D+3滚动交易 -- 申报明细数据
     * @return
     * @throws Exception
     */
    @Override
    @Async
    public CompletableFuture<List<List<String>>> getDayAddThreeReportDetails(String seqId){
        try {
            //获取电力交易平台地址
            long start = System.currentTimeMillis();
            String sgccUrl = sgccAddressService.getSgccAddress(ENV_KEY);
//			String sgccUrl = "http://39.96.27.4:17017";
//			String sgccUrl = "http://127.0.0.1:16016";
            //接口地址
            String mappingAddress = sgccUrl + "/dataPush/dayRolls/selectReportDetailed";
            String reportDetailsResultString = HttpUtils.sendPost(mappingAddress, "seqId="+seqId, DataPushUtils.createToken(PUBLIC_KEY));
            logger.info("-D+3: 获取D+3滚动交易 - 申报明细数据结果:{}", reportDetailsResultString);
            if (StringUtils.isEmpty(reportDetailsResultString)) {
                logger.info("-D+3: 获取D+3滚动交易 - 申报明细数据结果为空, ip:{} 接口地址: {}", sgccUrl, mappingAddress);
                return CompletableFuture.completedFuture(list);
            }
            Map reportDetailsMap = JSON.parseObject(reportDetailsResultString, Map.class);
            //返回结果data数据
            List<Map> parseArray = JSON.parseArray(JSON.toJSONString(reportDetailsMap.get("data")), Map.class);
            //按时间排序
            Collections.sort(parseArray, new Comparator<Map>() {
                @Override
                public int compare(Map o1, Map o2) {
                    Integer o1BeginTime = Integer.parseInt(String.valueOf(Optional.ofNullable(o1.get("beginTime")).orElse("00:00")).split(":")[0]);
                    Integer o2BeginTime = Integer.parseInt(String.valueOf(Optional.ofNullable(o2.get("beginTime")).orElse("00:00")).split(":")[0]);
                    return o1BeginTime.compareTo(o2BeginTime);
                }
            });
            //封装结果数据
            List<List<String>> result = new ArrayList<List<String>>();
            for (Map map : parseArray) {
                //交易时段
                String tradeTimeSlot = map.get("beginTime").toString() + "-" + map.get("endTime").toString();

                //买入卖出数据反了  修改后: 买入-saleEnergy  卖出-vendeeEnergy
                //申报电量-买入
                String vendeeEnergy = Optional.ofNullable(map.get("saleEnergy")).orElse("").toString();
                //申报电量-卖出
                String saleEnergy = Optional.ofNullable(map.get("vendeeEnergy")).orElse("").toString();
                //申报电价 - 买家
                BigDecimal[] buyPriceArray = new BigDecimal[] {
                        retainDigit(map.get("reportPriceBuy1")),
                        retainDigit(map.get("reportPriceBuy2")),
                        retainDigit(map.get("reportPriceBuy3")),
                };
                List<BigDecimal> buyPriceResult = arraySorted(buyPriceArray, 1);

                //申报电价 - 卖家
                BigDecimal[] salePriceArray = new BigDecimal[] {
                        retainDigit(map.get("reportPriceSale1")),
                        retainDigit(map.get("reportPriceSale2")),
                        retainDigit(map.get("reportPriceSale3")),
                };
                List<BigDecimal> salePriceResult = arraySorted(salePriceArray, 2);

                List<String> row = new LinkedList<>();
                row.add(tradeTimeSlot);
                row.add(vendeeEnergy);
                row.add(saleEnergy);
                row.add(buyPriceResult.get(0).toString());
                row.add(buyPriceResult.get(1).toString());
                row.add(buyPriceResult.get(2).toString());
                row.add(salePriceResult.get(0).toString());
                row.add(salePriceResult.get(1).toString());
                row.add(salePriceResult.get(2).toString());
                result.add(row);
            }
            long end = System.currentTimeMillis();
            logger.info("-D+3获取申报明细数据接口耗时: {}s", (end - start)/1000);
            return CompletableFuture.completedFuture(result);
        } catch (Exception e) {
            logger.error("D+3 - 申报明细数据获取失败!: {}", e);
            return CompletableFuture.completedFuture(list);
        }
    }

    /**
     * 获取D+3滚动交易 -- 各时段成交情况
     * @throws Exception
     */
    @Override
    @Async
    public CompletableFuture<Map<String, Object>> getDayAddThreeEveryTimeSlotDeal() {
        try {
            //获取电力交易平台地址
            long start = System.currentTimeMillis();
            String sgccUrl = sgccAddressService.getSgccAddress(ENV_KEY);
//			String sgccUrl = "http://39.96.27.4:17017";
//			String sgccUrl = "http://127.0.0.1:16016";
            //接口地址
            String mappingAddress = sgccUrl + "/dataPush/dayRolls/selectTodayTradeDetailed";
            String everyTimeSlotdealResultStr = HttpUtils.sendPost(mappingAddress, "", DataPushUtils.createToken(PUBLIC_KEY));
            logger.info("-D+3: 获取D+3滚动交易 - 各时段成交情况结果:{}", everyTimeSlotdealResultStr);
            if (StringUtils.isEmpty(everyTimeSlotdealResultStr)) {
                logger.info("-D+3: 获取D+3滚动交易 - 各时段成交情况结果为空, ip:{}, 接口地址: {}", sgccUrl, mappingAddress);
                return CompletableFuture.completedFuture(map);
            }
            Map timeSlotDealMap = JSON.parseObject(everyTimeSlotdealResultStr, Map.class);
            //获取data
            List<Map> timeSlotResultList = JSON.parseArray(JSON.toJSONString(timeSlotDealMap.get("data")), Map.class);
            //发电侧数据 type=1
            List<Map> yieldEnergyData = timeSlotResultList.stream().filter(map -> "1".equals(String.valueOf(map.get("type")))).collect(Collectors.toList());
            //用户侧数据 type=2
            List<Map> userEnergyData = timeSlotResultList.stream().filter(map -> "2".equals(String.valueOf(map.get("type")))).collect(Collectors.toList());
            //均价数据 type=3
            List<Map> avgPriceData = timeSlotResultList.stream().filter(map -> "".equals(String.valueOf(map.get("type")))).collect(Collectors.toList());

            //时间段集合
            String[] timeSlotArr = new String[] {
                    "01:00", "02:00", "03:00", "04:00", "05:00", "06:00", "07:00", "08:00", "09:00", "10:00", "11:00", "12:00",
                    "13:00", "14:00", "15:00", "16:00", "17:00", "18:00", "19:00", "20:00", "21:00", "22:00", "23:00", "24:00"
            };
            //获取结果数据
            //发电成交电量集合
            List<BigDecimal> yieldEnergyList = new LinkedList<>();
            //用户成交电量集合
            List<BigDecimal> userEnergyList = new LinkedList<>();
            //成交均价集合
            List<BigDecimal> dealAvgPriceList = new LinkedList<>();
            for(int i = 1; i <= 24; i++) {
                String iStr = String.valueOf(i);
                //发电成交电量
                BigDecimal yieldEnergy = retainDigit(yieldEnergyData.stream().filter(m -> iStr.equals(String.valueOf(m.get("tradeTimeSlot")))).findFirst().orElse(new HashMap<>()).get("dealEnergy"));
                //用户成交电量
                BigDecimal userEnergy = retainDigit(userEnergyData.stream().filter(m -> iStr.equals(String.valueOf(m.get("tradeTimeSlot")))).findFirst().orElse(new HashMap<>()).get("dealEnergy"));
                //成交均价
                BigDecimal avgPrice = retainDigit(avgPriceData.stream().filter(m -> iStr.equals(String.valueOf(m.get("tradeTimeSlot")))).findFirst().orElse(new HashMap<>()).get("dealAvgPrice"));

                yieldEnergyList.add(yieldEnergy);
                userEnergyList.add(userEnergy);
                dealAvgPriceList.add(avgPrice);
            }
            //y轴数据
            Map<String, Object> yieldEnergyMap = new HashMap<>();
            yieldEnergyMap.put("name", "发电成交电量");
            yieldEnergyMap.put("data", yieldEnergyList);
            Map<String, Object> userEnergyMap = new HashMap<>();
            userEnergyMap.put("name", "用户成交电量");
            userEnergyMap.put("data", userEnergyList);
            Map<String, Object> dealAvgPriceMap = new HashMap<>();
            dealAvgPriceMap.put("name", "成交均价");
            dealAvgPriceMap.put("data", dealAvgPriceList);
            List<Map<String, Object>> seriesData = new ArrayList<Map<String, Object>>();
            seriesData.add(yieldEnergyMap);
            seriesData.add(userEnergyMap);
            seriesData.add(dealAvgPriceMap);

            Map<String, Object> result = new HashMap<>();
            result.put("xAxis", Arrays.asList(timeSlotArr));
            result.put("seriesData", seriesData);
            long end = System.currentTimeMillis();
            logger.info("-D+3页面获取各时段成交情况接口耗时: {}s", (end - start)/1000);
            return CompletableFuture.completedFuture(result);
        } catch (Exception e) {
            logger.error("D+3 - 各时段成交情况获取失败!, {}", e);
            return CompletableFuture.completedFuture(map);
        }
    }

    /**
     * 获取D+3滚动交易 -- 实时成交数据
     * @return
     * @throws Exception
     */
    @Override
    @Async
    public CompletableFuture<List<List<String>>> getDayAddThreeRealTimeDeal(){
        try {
            //获取电力交易平台地址
            long start = System.currentTimeMillis();
            String sgccUrl = sgccAddressService.getSgccAddress(ENV_KEY);
//			String sgccUrl = "http://39.96.27.4:17017";
//			String sgccUrl = "http://127.0.0.1:16016";
            //接口地址
            String mappingAddress = sgccUrl + "/dataPush/dayRolls/selectTradeDetailed";
            String realTimeDealResultString = HttpUtils.sendPost(mappingAddress, "", DataPushUtils.createToken(PUBLIC_KEY));
            logger.info("-D+3: 获取D+3滚动交易 - 实时成交数据结果: {}", realTimeDealResultString);
            if (StringUtils.isEmpty(realTimeDealResultString)) {
                logger.info("-D+3: 获取D+3滚动交易 - 实时成交数据结果为空, ip: {}, 接口地址: {}", sgccUrl, mappingAddress);
                return CompletableFuture.completedFuture(list);
            }
            Map realTimeDealResultMap = JSON.parseObject(realTimeDealResultString, Map.class);
            //data数据
            List<Map> realTimeDealData = JSON.parseArray(JSON.toJSONString(realTimeDealResultMap.get("data")), Map.class);
            //根据成交时间排序
            Collections.sort(realTimeDealData, new Comparator<Map>() {
                @Override
                public int compare(Map o1, Map o2) {
                    String o1String = o1.get("dealTime").toString();
                    String o2String = o2.get("dealTime").toString();
                    return o2String.compareTo(o1String);
                }
            });

            //数据量>300的话  限制展示300条
            List<Map> newList = realTimeDealData.size()>300 ? realTimeDealData.subList(0, 300) : realTimeDealData;
            System.out.println("newList.Size: " + newList.size());

            //封装结果
            List<List<String>> result = new ArrayList<>();
            for (Map map : newList) {
                //交易时段
                String tradeTimeSlot = map.get("tradeTimeSolt").toString();
                //成交电量
                String dealEnergy = retainDigit(map.get("dealEnergy")).toString();
                //成交均价
                String dealAvgPrice = retainDigit(map.get("dealAvgPrice")).toString();
                //成交时间
                String dealTime = map.get("dealTime").toString();

                List<String> row = new LinkedList<>();
                row.add(tradeTimeSlot);
                row.add(dealEnergy);
                row.add(dealAvgPrice);
                row.add(dealTime);
                result.add(row);
            }
            long end = System.currentTimeMillis();
            logger.info("-D+3页面获取实时成交数据接口: {}s", (end - start)/1000);
            return CompletableFuture.completedFuture(result);
        } catch (Exception e) {
            logger.error("D+3 - 实时成交数据获取失败!, {}", e);
            return CompletableFuture.completedFuture(list);
        }
    }

    /**
     * 获取D+3滚动交易 -- 各日成交情况
     * @throws Exception
     */
    @Override
    @Async
    public CompletableFuture<Map<String, Object>> getDayAddThreeEveryDayDeal() {
        try {
            //获取电力交易平台地址
            long start = System.currentTimeMillis();
            String sgccUrl = sgccAddressService.getSgccAddress(ENV_KEY);
//			String sgccUrl = "http://39.96.27.4:17017";
//			String sgccUrl = "http://127.0.0.1:16016";
            //接口地址
            String mappingAddress = sgccUrl + "/dataPush/dayRolls/selectSameMonthTradeDetailed";
            String everyDayDealResultString = HttpUtils.sendPost(mappingAddress, "", DataPushUtils.createToken(PUBLIC_KEY));
            logger.info("-D+3: 获取D+3滚动交易 - 各日成交情况数据结果： {}", everyDayDealResultString);
            if (StringUtils.isEmpty(everyDayDealResultString)) {
                logger.info("-D+3: 获取D+3滚动交易 - 各日成交情况数据结果为空, ip: {}, 接口地址: {}", sgccUrl, mappingAddress);
                return CompletableFuture.completedFuture(map);
            }
            Map everyDayDealMap = JSON.parseObject(everyDayDealResultString, Map.class);
            //data数据
            List<Map> everyDayDealData = JSON.parseArray(JSON.toJSONString(everyDayDealMap.get("data")), Map.class);
            //发电成交量数据
            List<Map> yieldEnergyData = dateSorted(everyDayDealData.stream().filter(m -> "1".equals(String.valueOf(m.get("type")))).collect(Collectors.toList()));
            //用户成交量数据
            List<Map> userEnergyData = dateSorted(everyDayDealData.stream().filter(m -> "2".equals(String.valueOf(m.get("type")))).collect(Collectors.toList()));
            //均价数据
            List<Map> avgPriceData = dateSorted(everyDayDealData.stream().filter(m -> "".equals(String.valueOf(m.get("type")))).collect(Collectors.toList()));

            //封装结果
            List<String> xAxis = new LinkedList<>();
            //发电成交电量
            List<BigDecimal> yieldDealEnergyList = new LinkedList<>();
            //用户成交电量
            List<BigDecimal> userDealEnergyList = new LinkedList<>();
            List<BigDecimal> dealAvgPriceList = new LinkedList<>();

            //发电成交量
            for (Map map : yieldEnergyData) {
                //yyyy-MM-dd 转为 MM/dd
                String dealDate = map.get("dealDate").toString();
                String dealDateFormat = LocalDate.parse(dealDate, DateTimeFormatter.ofPattern("yyyyMMdd")).format(DateTimeFormatter.ofPattern("MM/dd"));
                xAxis.add(dealDateFormat);
                yieldDealEnergyList.add(retainDigit(map.get("dealEnergy")));
            }

            //用户成交量
            for (Map map : userEnergyData) {
                userDealEnergyList.add(retainDigit(map.get("dealEnergy")));
            }
            //成交均价
            for (Map map : avgPriceData) {
                dealAvgPriceList.add(retainDigit(map.get("dealAvgPrice")));
            }

            //y轴数据
            Map<String, Object> yieldEnergyMap = new HashMap<>();
            yieldEnergyMap.put("name", "发电成交电量");
            yieldEnergyMap.put("data", yieldDealEnergyList);
            Map<String, Object> userEnergyMap = new HashMap<>();
            userEnergyMap.put("name", "用户成交电量");
            userEnergyMap.put("data", userDealEnergyList);
            Map<String, Object> dealAvgPriceMap = new HashMap<>();
            dealAvgPriceMap.put("name", "成交均价");
            dealAvgPriceMap.put("data", dealAvgPriceList);
            List<Map<String, Object>> seriesData = new ArrayList<Map<String, Object>>();
            seriesData.add(yieldEnergyMap);
            seriesData.add(userEnergyMap);
            seriesData.add(dealAvgPriceMap);

            Map<String, Object> result = new HashMap<>();
            result.put("xAxis", xAxis);
            result.put("seriesData", seriesData);

            long end = System.currentTimeMillis();
            logger.info("-D+3页面获取各日成交情况接口耗时: {}s", (end-start)/1000);
            return CompletableFuture.completedFuture(result);
        } catch (Exception e) {
            logger.error("D+3 - 各日成交情况数据获取失败!, {}", e);
            return CompletableFuture.completedFuture(map);
        }
    }

    /**
     * 获取申报、成交总笔数
     */
    @Override
    @Async
    public CompletableFuture<Map<String, Object>> getReportDealNum() {
        try {
            //获取电力交易平台地址
            long start = System.currentTimeMillis();
            String sgccUrl = sgccAddressService.getSgccAddress(ENV_KEY);
//			String sgccUrl = "http://39.96.27.4:17017";
//			String sgccUrl = "http://127.0.0.1:16016";
            //接口地址
            String mappingAddress = sgccUrl + "/dataPush/dayRolls/selectAuctoinNum";
            String everyDayDealResultString = HttpUtils.sendPost(mappingAddress, "", DataPushUtils.createToken(PUBLIC_KEY));
            logger.info("-D+3: 获取D+3滚动交易 - 申报、成交总笔数结果： {}", everyDayDealResultString);
            if (StringUtils.isEmpty(everyDayDealResultString)) {
                logger.info("-D+3: 获取D+3滚动交易 - 申报、成交总笔数结果, ip: {}, 接口地址: {}", sgccUrl, mappingAddress);
                return CompletableFuture.completedFuture(map);
            }
            Map reportDealMap = JSONObject.parseObject(everyDayDealResultString, Map.class);
            Map<String, Object> reportDealData = (Map<String, Object>)reportDealMap.get("data");
            //封装结果
            Map<String, Object> result = new HashMap<>();
            result.put("reportNum", Optional.ofNullable(reportDealData.get("reportNum")).orElse(""));
            result.put("dealNum", Optional.ofNullable(reportDealData.get("dealNum")).orElse(""));
            long end = System.currentTimeMillis();
            logger.info("-D+3页面获取申报、成交总笔数接口耗时: {} s", (end -start)/1000);
            return CompletableFuture.completedFuture(result);
        } catch (Exception e) {
            logger.error("D+3 - 各日成交情况数据获取失败!, {}", e);
            return CompletableFuture.completedFuture(map);
        }
    }

    /**
     * 交易情况-发电、用户申报电量、成交电量
     */
    @Override
    @Async
    public CompletableFuture<Map<String, Object>> getYieldUserForStatus() {
        try {
            //获取电力交易平台地址
            long start = System.currentTimeMillis();
            String sgccUrl = sgccAddressService.getSgccAddress(ENV_KEY);
//			String sgccUrl = "http://39.96.27.4:17017";
//			String sgccUrl = "http://127.0.0.1:16016";
            //发电、用户申报电量接口地址
            String reportAddress = sgccUrl + "/dataPush/dayRolls/selectTrListingEnergy";
            String reportEnergyResStr = HttpUtils.sendPost(reportAddress, "", DataPushUtils.createToken(PUBLIC_KEY));

            //发电、用户成交电量接口地址
            String dealAddress = sgccUrl + "/dataPush/dayRolls/selectDealDetailEnergy";
            String dealEnergyResStr = HttpUtils.sendPost(dealAddress, "", DataPushUtils.createToken(PUBLIC_KEY));

            logger.info("-D+3: 获取D+3滚动交易 - 交易情况:发电、用户申报电量数据结果： {}", reportEnergyResStr);
            logger.info("-D+3: 获取D+3滚动交易 - 交易情况:发电、用户成交电量数据结果： {}", dealEnergyResStr);
            if (StringUtils.isEmpty(reportEnergyResStr) || StringUtils.isEmpty(dealEnergyResStr)) {
                logger.info("-D+3: D+3滚动交易 - 交易情况: 发电、用户申报电量、成交电量结果为空!");
                return CompletableFuture.completedFuture(map);
            }
            //申报电量-发电、用户数据
            Map reportEnergyResultMap = JSON.parseObject(reportEnergyResStr, Map.class);
            Map<String, Object> reportRes = (Map<String, Object>) reportEnergyResultMap.get("data");
            //成交电量-发电、用户数据
            Map dealEnergyResultMap = JSON.parseObject(dealEnergyResStr, Map.class);
            Map<String, Object> dealRes = (Map<String, Object>) dealEnergyResultMap.get("data");

            Map<String, Object> result = new HashMap<>();
            result.put("buyYieldReport", retainDigit(reportRes.get("faVendeeEnergy")));
            result.put("buyUserReport", retainDigit(reportRes.get("userVendeeEnergy")));
            result.put("saleYieldReport", retainDigit(reportRes.get("faSellerEnergy")));
            result.put("saleUserReport", retainDigit(reportRes.get("userSellEnergy")));

            //计算买方、卖方申报电量
            BigDecimal buyReport = toBigDecimal(reportRes.get("faVendeeEnergy")).add(toBigDecimal(reportRes.get("userVendeeEnergy")));
            BigDecimal saleReport = toBigDecimal(reportRes.get("faSellerEnergy")).add(toBigDecimal(reportRes.get("userSellEnergy")));
            buyReportThreadLocal.set(buyReport.setScale(2, BigDecimal.ROUND_HALF_UP));
            saleReportThreadLocal.set(saleReport.setScale(2, BigDecimal.ROUND_HALF_UP));

            //计算买方成交电量
            BigDecimal dealEnergy = toBigDecimal(dealRes.get("faEnergy")).add(toBigDecimal(dealRes.get("userEnergy")));
            BigDecimal dealEnergyScale = dealEnergy.setScale(2, BigDecimal.ROUND_HALF_UP);
            energyThreadLocal.set(dealEnergyScale);

            result.put("buyYieldDeal", retainDigit(dealRes.get("faEnergy")));
            result.put("buyUserDeal", retainDigit(dealRes.get("userEnergy")));
            result.put("saleYieldDeal", dealEnergyScale);
            result.put("saleUserDeal", 0);
            long end = System.currentTimeMillis();
            logger.info("D+3: 交易情况-发电、用户申报电量、成交电量接口耗时: {}s", (end-start)/1000);
            return CompletableFuture.completedFuture(result);
        } catch (Exception e) {
            logger.error("D+3 - 交易情况:发电、用户申报电量、成交电量数据失败!, {}", e);
            return CompletableFuture.completedFuture(map);
        }
    }

    /**
     * 申报明细-买卖方申报电量、申报均价
     */
    @Override
    @Async
    public CompletableFuture<Map<String, Object>> getEnergyPriceForDetails() {
        try {
            //获取电力交易平台地址
            long start = System.currentTimeMillis();
            String sgccUrl = sgccAddressService.getSgccAddress(ENV_KEY);
//			String sgccUrl = "http://39.96.27.4:17017";
//			String sgccUrl = "http://127.0.0.1:16016";
            //接口地址
            String mappingAddress = sgccUrl + "/dataPush/dayRolls/selectTrListing";
            String energyPriceForDetailsResStr = HttpUtils.sendPost(mappingAddress, "", DataPushUtils.createToken(PUBLIC_KEY));
            logger.info("-D+3: 获取D+3滚动交易 - 申报明细:买卖方申报电量、申报均价数据结果： {}", energyPriceForDetailsResStr);
            if (StringUtils.isEmpty(energyPriceForDetailsResStr)) {
                logger.info("-D+3: D+3滚动交易 - 申报明细:买卖方申报电量、申报均价结果为空!");
                return CompletableFuture.completedFuture(map);
            }
            Map yieldUserForStatusResult = JSON.parseObject(energyPriceForDetailsResStr, Map.class);
            Map<String, Object> data = (Map<String, Object>)yieldUserForStatusResult.get("data");
            Map<String, Object> result = new HashMap<>();
//			result.put("buyReportElectric", retainDigit(data.get("buyEnergy")));
            result.put("buyReportElectric", buyReportThreadLocal.get());
            result.put("buyReportAvgPrice", retainDigit(data.get("buyPrice")));

//			result.put("saleReportElectric", retainDigit(data.get("sellEnergy")));
            result.put("saleReportElectric", saleReportThreadLocal.get());
            result.put("saleReportAvgPrice", retainDigit(data.get("sellPrice")));
            long end = System.currentTimeMillis();
            logger.info("D+3: 申报明细-买卖方申报电量、申报均价接口耗时: {}s", (end-start)/1000);
            return CompletableFuture.completedFuture(result);
        } catch (Exception e) {
            logger.info("获取D+3滚动交易-申报明细:买卖方申报电量、申报均价失败!, {}", e);
            return CompletableFuture.completedFuture(map);
        }
    }

    /**
     * 电量、电价保留2位小数
     * @param number
     * @return
     */
    private BigDecimal retainDigit(Object number) {
        if (number == null || "".equals(number)) {
            return BigDecimal.ZERO;
        }
        String valueOf = String.valueOf(number);
        return new BigDecimal(valueOf).setScale(2, BigDecimal.ROUND_HALF_UP);
    }

    /*
     *  电量、电价转Bigdecimal
     */
    private BigDecimal toBigDecimal(Object number) {
        if (number == null || "".equals(number)) {
            return BigDecimal.ZERO;
        }
        return new BigDecimal(number.toString());
    }

    /**
     * 电价集合排序
     * @param array
     * @param flag 1-从大到小 2-从小到大
     * @return
     */
    private  List<BigDecimal> arraySorted(BigDecimal[] array, int flag) {
        //转为list
        List<BigDecimal> arrayList = Arrays.asList(array);
        if (flag == 2) {
            Collections.sort(arrayList, (o1, o2) -> {return o1.compareTo(o2);});
        } else {
            Collections.sort(arrayList, (o1, o2) -> {return o2.compareTo(o1);});
        }
        return arrayList;
    }

    /**
     * 	日期排序
     * @return
     */
    private List<Map> dateSorted(List<Map> params){
        Collections.sort(params, new Comparator<Map>() {
            @Override
            public int compare(Map o1, Map o2) {
                Date o1Date = null;
                Date o2Date = null;
                try {
                    o1Date = new SimpleDateFormat("yyyyMMdd").parse(o1.get("dealDate").toString());
                    o2Date = new SimpleDateFormat("yyyyMMdd").parse(o1.get("dealDate").toString());
                } catch (ParseException e) {
                    e.printStackTrace();
                }
                return o1Date.compareTo(o2Date);
            }
        });
        return params;
    }
}
