package com.alonginfo.project.gansu.serviceimpl.focuslisting;

import com.alonginfo.common.utils.DateUtils;
import com.alonginfo.common.utils.StringUtils;
import com.alonginfo.project.gansu.mapper.*;
import com.alonginfo.project.gansu.service.focuslisting.FocusBiddingListingDealCommonService;
import com.alonginfo.project.gansu.service.SgccAddressService;
import com.alonginfo.utils.DataPushUtils;
import com.alonginfo.utils.FocusBiddingUtil;
import lombok.extern.slf4j.Slf4j;
import org.apache.http.client.ClientProtocolException;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

import java.io.IOException;
import java.math.BigDecimal;
import java.text.ParseException;
import java.time.LocalDateTime;
import java.time.Year;
import java.time.format.DateTimeFormatter;
import java.util.*;

/**
 * 集中竞价、挂牌交易公共接口
 */
@Service
@Slf4j
public class FocusBiddingListingDealCommonServiceImpl implements FocusBiddingListingDealCommonService {

    @Value("${env.key}")
    private String ENV_KEY;

    @Value("${sgcc.publicKey}")
    private String PUBLIC_KEY;

    @Autowired
    private SgccAddressService sgccAddressService;

    @Autowired
    private TradeSeqDao tradeSeqDao;

    @Autowired
    private TradeNoticeDao tradeNoticeDao;

    @Autowired
    private TradeStatusDao tradeStatusDao;

    @Autowired
    private PriceTrendReplayDao priceTrendReplayDao;

    /**
     * 获取集中竞价、挂牌交易页面数据
     * @return
     */
    @Override
    public Map<String, Object> getFocusBidding(String screenId, String seqId) {
        //判断当前是连接电力交易平台测试环境 or 正式环境
        int environmentId = DataPushUtils.isFormal(sgccAddressService.getSgccAddress(ENV_KEY));

        Map<String, Object> result = new HashMap<>();
        //判断测试环境、正式环境
        if (environmentId == 1) {
            //获取该屏幕下的交易序列信息 - 正式环境
            Map<String, Object> seqList = DataPushUtils.handleSeqList(tradeSeqDao.getAll(screenId));
            //获取交易公告信息 - 正式环境
            Map<String, String> tradeNotice = Optional.ofNullable(tradeNoticeDao.getNoticeBySeqId(seqId)).orElse(new HashMap<>());
            //判断当前交易序列是实时交易OR回演交易
            //默认是实时交易
            String type = "1";
            for(Map<String, String> seq : (List<Map<String, String>>)seqList.get("list")) {
                if (seqId.equals(seq.get("tradeSeqId"))) {
                    type = seq.get("type");
                }
            }
            //如果为实时交易
            if ("1".equals(type)) {
                //购售方申报信息 及 购售方数量(实时交易: 从新增接口2.1获取)
                Map<String, Object> focusAndListingBidBefore = getFocusAndListingBidBefore(screenId, seqId);
                System.out.println("focusAndListingBidBefore = " + focusAndListingBidBefore);
                //中间表格数据(挂/摘牌信息，购售方申报明细)
                Map<String, Object> buySaleDetails = (Map<String, Object>) (Optional.ofNullable(focusAndListingBidBefore.get("result")).orElse(new HashMap<>()));
                //处理集中、挂牌  实时状态 中间数据格式
                Map<String, Object> dealBuySaleDetails = dealBuySaleDetail(buySaleDetails,screenId);

                //交易情况数据(实时交易: 2.1接口获取购/售方数量)
                Map<String, String> focusTradeStatus = getFocusAndListingTradeStatus(screenId, seqId, (int)focusAndListingBidBefore.get("saleNum"), (int)focusAndListingBidBefore.get("buyNum"));
                //交易流程监控
                String dealProcess = judgeDealProcess(tradeNotice.get("beginDate"), tradeNotice.get("endDate"));
                //申报主体走势分析
                Map<String, Object> reportRejectTrend = reportSubjectTrend(tradeNotice.get("beginDate"), tradeNotice.get("endDate"), buySaleDetails);
                result.put("seqList", seqList);
                result.put("tradeNotice", tradeNotice);
                result.put("tradeStatus", focusTradeStatus);
                result.put("buySaleDetails", dealBuySaleDetails);
                result.put("dealProcess", dealProcess);
                result.put("reportRejectTrend", reportRejectTrend);
            } else {
                //交易情况数据(回演交易: 查询trade_seq_status表)
                Map<String, String> focusTradeStatus = DataPushUtils.mapIsEmpty(tradeStatusDao.getStatusBySeqId(seqId));
                //购售方申报信息(回演交易:  接口2.0中获取)
                List<LinkedList<String>> buySaleDetails = DataPushUtils.dealBuySaleDetail(FocusBiddingUtil.getReportAndHandPickReplay(seqId, sgccAddressService.getSgccAddress(ENV_KEY), DataPushUtils.createToken(PUBLIC_KEY)));
                //交易量价走势分析
                Map<String, Object> dealTrends = DataPushUtils.dealTrendReplays(priceTrendReplayDao.getTrendReplayBySeqId(seqId));
                //开标后的数据 -- 用于计算集中竞价: 申报曲线；挂牌交易: 成交量价分布
                Map<String, Object> focusAndListingTradeReport = getFocusAndListingBidAfter(screenId, seqId);
                System.out.println("focusAndListingTradeReport = " + focusAndListingTradeReport);
                //集中竞价展示申报曲线、挂牌交易展示成交量价分布
                if ("1".equals(screenId)) {
                    Map<String, Object> saleCurve = reportCurve((List<Map<String, Object>>) focusAndListingTradeReport.get("saleData"));
                    Map<String, Object> buyCurve = reportCurve((List<Map<String, Object>>) focusAndListingTradeReport.get("buyData"));
                    Map<String, Object> reportCurve = new HashMap<>();
                    reportCurve.put("saleCurve", saleCurve);
                    reportCurve.put("buyCurve", buyCurve);
                    result.put("reportCurve", reportCurve);
                } else {
                    Map<String, Object> volumePriceSpread = volumePriceSpread((List<Map<String, Object>>) focusAndListingTradeReport.get("saleData"), (List<Map<String, Object>>) focusAndListingTradeReport.get("buyData"));
                    result.put("volumePriceSpread", volumePriceSpread);
                }
                result.put("seqList", seqList);
                result.put("tradeNotice", tradeNotice);
                result.put("tradeStatus", focusTradeStatus);
                result.put("buySaleDetails", buySaleDetails);
                result.put("dealTrends", dealTrends);
            }
        } else {
            //获取该屏幕下的交易序列信息 - 测试环境
            Map<String, Object> seqList = DataPushUtils.handleSeqList(tradeSeqDao.getAllTest(screenId));
            //获取交易公告信息（测试环境）
            Map<String, String> tradeNotice = Optional.ofNullable(tradeNoticeDao.getNoticeBySeqId(seqId)).orElse(new HashMap<>());
            //判断当前交易序列是实时交易OR回演交易
            //默认是实时交易
            String type = "1";
            for(Map<String, String> seq : (List<Map<String, String>>) seqList.get("list")) {
                if (seqId.equals(seq.get("tradeSeqId"))) {
                    type = seq.get("type");
                }
            }
            //购售方申报信息(接口1.8)
            //如果为实时交易
            if ("1".equals(type)) {
                //购售方申报信息(实时交易: 从新增接口2.1获取)
                Map<String, Object> focusAndListingBidBefore = getFocusAndListingBidBefore(screenId, seqId);
                System.out.println("focusAndListingBidBefore = " + focusAndListingBidBefore);
                Map<String, Object> buySaleDetails = (Map<String, Object>) focusAndListingBidBefore.get("result");
                //处理集中、挂牌  实时状态 中间数据格式
                Map<String, Object> dealBuySaleDetails = dealBuySaleDetail(buySaleDetails, screenId);

                //交易情况数据(实时交易: 2.1接口获取购/售方数量)
                Map<String, String> focusTradeStatus = getFocusAndListingTradeStatus(screenId, seqId, (int)focusAndListingBidBefore.get("saleNum"), (int)focusAndListingBidBefore.get("buyNum"));
                //交易流程监控
                String dealProcess = judgeDealProcess(tradeNotice.get("beginDate"), tradeNotice.get("endDate"));
                //申报主体走势分析
                Map<String, Object> reportRejectTrend = reportSubjectTrend(tradeNotice.get("beginDate"), tradeNotice.get("endDate"), buySaleDetails);
                result.put("seqList", seqList);
                result.put("tradeNotice", tradeNotice);
                result.put("tradeStatus", focusTradeStatus);
                result.put("buySaleDetails", dealBuySaleDetails);
                result.put("dealProcess", dealProcess);
                result.put("reportRejectTrend", reportRejectTrend);
            } else {
                //交易情况数据(回演交易: 查询trade_seq_status表)
                Map<String, String> focusTradeStatus = DataPushUtils.mapIsEmpty(tradeStatusDao.getTestStatusBySeqId(seqId));
                //购售方申报信息(回演交易:  原有接口2.0中获取)
                List<LinkedList<String>> buySaleDetails = DataPushUtils.dealBuySaleDetail(FocusBiddingUtil.getReportAndHandPickReplay(seqId, sgccAddressService.getSgccAddress(ENV_KEY), DataPushUtils.createToken(PUBLIC_KEY)));
                //交易量价走势分析
                Map<String, Object> dealTrends = DataPushUtils.dealTrendReplays(priceTrendReplayDao.getTestTrendReplayBySeqId(seqId));
                //开标后的数据 -- 用于计算集中竞价: 申报曲线；挂牌交易: 成交量价分布
                Map<String, Object> focusAndListingTradeReport = getFocusAndListingBidAfter(screenId, seqId);
                //集中竞价展示申报曲线、挂牌交易展示成交量价分布
                if ("1".equals(screenId)) {
                    Map<String, Object> saleCurve = reportCurve((List<Map<String, Object>>) focusAndListingTradeReport.get("saleData"));
                    Map<String, Object> buyCurve = reportCurve((List<Map<String, Object>>) focusAndListingTradeReport.get("buyData"));
                    Map<String, Object> reportCurve = new HashMap<>();
                    reportCurve.put("saleCurve", saleCurve);
                    reportCurve.put("buyCurve", buyCurve);
                    result.put("reportCurve", reportCurve);
                } else {
                    Map<String, Object> volumePriceSpread = volumePriceSpread((List<Map<String, Object>>) focusAndListingTradeReport.get("saleData"), (List<Map<String, Object>>) focusAndListingTradeReport.get("buyData"));
                    result.put("volumePriceSpread", volumePriceSpread);
                }
                result.put("seqList", seqList);
                result.put("tradeNotice", tradeNotice);
                result.put("tradeStatus", focusTradeStatus);
                result.put("buySaleDetails", buySaleDetails);
                result.put("dealTrends", dealTrends);
            }
        }
        return result;
    }

    /**
     * 处理中间表格数据格式
     * @param screenId 1-集中竞价 2-挂牌交易
     */
    private Map<String, Object> dealBuySaleDetail(Map<String, Object> buySaleDetails, String screenId) {
        if (CollectionUtils.isEmpty(buySaleDetails)) {
            return new HashMap<>();
        }
        Map<String, Object> result = new HashMap<>();
        for (Map.Entry entry : buySaleDetails.entrySet()) {
            String key = entry.getKey().toString();
            List<Map<String, Object>> value = (List<Map<String, Object>>) entry.getValue();
            List<List<String>> buySaleList = new ArrayList<>();
            for (Map<String, Object> v : value) {
                List<String> itemList = new LinkedList<>();
                itemList.add(v.get("reportName").toString());
                itemList.add(v.get("dealSlot").toString());
                itemList.add(v.get("energy").toString());
                //挂牌交易, 挂牌方遍历时  添加price字段
                if ("sale".equals(key) && "2".equals(screenId)) {
                    itemList.add(v.get("price").toString());
                }
                itemList.add(v.get("confirmTime").toString());
                buySaleList.add(itemList);
            }
            result.put(key, buySaleList);
        }
        return result;
    }

    /**
     * 	获取集中竞价、挂牌交易  实时交易--- 购售方申报信息 (接口2.1  -- 开标前数据)
     * 	实时交易: /dataPush/tradeDeclareDetail/selectTradeReportMain   回演交易: 从getDeclareDetailList()中获取数据
     *
     * @param screenId 挂牌交易和集中竞价中  中间模块展示数据格式不同
     * @return
     * @throws Exception
     */
    private Map<String, Object> getFocusAndListingBidBefore(String screenId, String seqId){
        try {
            String sgccAddress = sgccAddressService.getSgccAddress(ENV_KEY);
            String token = DataPushUtils.createToken(PUBLIC_KEY);
            //获取售方数据/挂牌方
            List<Map> saleData = FocusBiddingUtil.getRportAndHangPickBidBefore(2, seqId, sgccAddress, token);
            //获取购方数据/摘牌方
            List<Map> buyData = FocusBiddingUtil.getRportAndHangPickBidBefore(1, seqId, sgccAddress, token);

            //售方/挂牌方数量
            int saleNum = censusBuySaleNum(saleData);
            //获取购方/摘牌方
            int buyNum = censusBuySaleNum(buyData);
            //处理购(摘)/售(挂)方数据，判断当前seqId属于集中竞价还是挂牌交易(返回数据格式不同)
            Map<String, Object> dealMiddleData = dealMiddleData(screenId, saleData, buyData);
            //封装结果
            Map<String, Object> resultMap = new HashMap<>();
            resultMap.put("result", dealMiddleData);
            resultMap.put("saleNum", saleNum);
            resultMap.put("buyNum", buyNum);
            return resultMap;
        } catch (Exception e) {
            e.printStackTrace();
            log.info("集中竞价/挂牌交易, 实时状态, 购售方申报明细获取失败!");
            return new HashMap<>();
        }
    }

    /**
     * 	获取集中竞价、挂牌交易  实时交易时--- 交易情况数据
     *    当回演交易时  还是从tradesStatusDao中获取
     * @return
     * @throws Exception
     * @throws IOException
     * @throws ClientProtocolException
     */
    private Map<String, String> getFocusAndListingTradeStatus(String screenId, String seqId, int saleNum, int buyNum){
        try {
            //结果封装
            Map<String, String> result = new HashMap<>();
            //售方申报家数
            result.put("saleSuoteNum", String.valueOf(saleNum));
            //售方申报电量  集中、挂牌都不展示
            result.put("saleEnergy", "待结果发布后公示");
            //购方申报家数
            result.put("vendeeConfimNum", String.valueOf(buyNum));
            //购方申报电量
            result.put("vendeeEnergy", "待结果发布后公示");
            //直接交易用户
            result.put("directResultNum", "1");
            //售电公司
            result.put("retailResultNum", "1");
            //其余字段均不展示
            //售方成交家数
            result.put("saleResultNum", "待结果发布后公示");
            //购方成交家数
            result.put("vendeeNum", "待结果发布后公示");
            //成交电量
            result.put("energy", "待结果发布后公示");
            //成交均价
            result.put("avgPrice", "待结果发布后公示");
            //最高成交价
            result.put("maxPrice", "待结果发布后公示");
            //最低成交价
            result.put("minPrice", "待结果发布后公示");
            return result;
        } catch (Exception e) {
            e.printStackTrace();
            log.info("集中竞价、挂牌交易, 实时状态, 交易情况获取失败!");
            return new HashMap<>();
        }
    }

    /**
     * 	获取集中竞价、挂牌交易  实时交易--- 购售方申报信息 (接口1.8  -- 开标后数据, 用于计算挂牌回演-成交量价分布、 集中回演-申报曲线)
     * 	实时交易: /dataPush/tradeDeclareDetail/selectTradeReportMain   回演交易: 从getDeclareDetailList()中获取数据
     *
     * @param screenId 挂牌交易和集中竞价中  中间模块展示数据格式不同
     * @param seqId
     * @return
     * @throws Exception
     */
    private Map<String, Object> getFocusAndListingBidAfter(String screenId, String seqId){
        try {
            String sgccAddress = sgccAddressService.getSgccAddress(ENV_KEY);
            String token = DataPushUtils.createToken(PUBLIC_KEY);
            //调用接口1.8 /dataPush/tradeDeclareDetail/selectTradeReport
            //获取售方数据/挂牌方
            List<Map> saleData = FocusBiddingUtil.getRportAndHangPickBidAfter(2, seqId, sgccAddress, token);
            //获取购方数据/摘牌方
            List<Map> buyData = FocusBiddingUtil.getRportAndHangPickBidAfter(1, seqId, sgccAddress, token);
            //处理购(摘)/售(挂)方数据，判断当前seqId属于集中竞价还是挂牌交易(返回数据格式不同)
            //Map<String, Object> dealMiddleData = FocusBidding.dealMiddleData(screenId, saleData, buyData);
            Map<String, Object> resultMap = new HashMap<>();
            //resultMap.put("result", dealMiddleData);
            resultMap.put("saleData", saleData);
            resultMap.put("buyData", buyData);
            return resultMap;
        } catch (Exception e) {
            e.printStackTrace();
            return new HashMap<>();
        }
    }


    /**
     * 处理封装集中竞价/挂牌交易  实时交易 -- 中间表格的数据（返回数据格式不同）
     * @param screenId 判断集中竞价 OR 挂牌交易
     * @param saleData 售方数据
     * @param buyData 购方数据
     * @return
     * @throws ParseException
     */
    public static Map<String, Object> dealMiddleData(String screenId, List<Map> saleData, List<Map> buyData) throws ParseException {
        Map<String, Object> result = new HashMap<>();
        //集中竞价
        if ("1".equals(screenId)) {
            //售方
            List<Map<String, Object>> saleResult = new ArrayList<>();
            //购方
            List<Map<String, Object>> buyResult = new ArrayList<>();
            //处理售方数据
            for(Map<String, Object> sale : saleData) {
                //处理交易时段
                String reportName = String.valueOf(sale.get("reportName"));
                String dealSlot = (reportName.split("至")[0]).substring(2) + '-' +reportName.split("至")[1];
                Map<String, Object> saleItem = new HashMap<>();
                saleItem.put("reportName", sale.get("jydyParticipantName"));
                saleItem.put("dealSlot", dealSlot);
                saleItem.put("energy", "*****");
                saleItem.put("confirmTime", DateUtils.dateTimeFormat(String.valueOf(sale.get("decDate"))));
                saleResult.add(saleItem);
            }
            //处理购方数据
            for(Map<String, Object> buy : buyData) {
                //处理交易时段
                String reportName = String.valueOf(buy.get("reportName"));
                String dealSlot = (reportName.split("至")[0]).substring(2) + '-' +reportName.split("至")[1];
                Map<String, Object> buyItem = new HashMap<>();
                buyItem.put("reportName", buy.get("jydyParticipantName"));
                buyItem.put("dealSlot", dealSlot);
                //集中竞价 实时交易  不展示电量展示为****
                buyItem.put("energy", "*****");
                buyItem.put("confirmTime",  DateUtils.dateTimeFormat(String.valueOf(buy.get("decDate"))));
                buyResult.add(buyItem);
            }
            result.put("sale", saleResult);
            result.put("buy", buyResult);
        } else {
            //挂牌方（售方）
            List<Map<String, Object>> hangResult = new ArrayList<>();
            //摘牌方 (购方)
            List<Map<String, Object>> pickResult = new ArrayList<>();
            //处理售方数据
            for(Map<String, Object> hang : saleData) {
                //处理交易时段
                String reportName = String.valueOf(hang.get("reportName"));
                String dealSlot = (reportName.split("至")[0]).substring(2) + '-' +reportName.split("至")[1];
                Map<String, Object> hangItem = new HashMap<>();
                hangItem.put("reportName", hang.get("jydyParticipantName"));
                hangItem.put("dealSlot", dealSlot);
                hangItem.put("energy", "*****");
                hangItem.put("price", "*****");
                //TODO 日期还没转换, 没排序
                hangItem.put("confirmTime",  DateUtils.dateTimeFormat(String.valueOf(hang.get("decDate"))));
                hangResult.add(hangItem);
            }
            //处理购方数据
            for(Map<String, Object> pick : buyData) {
                //处理交易时段
                String reportName = String.valueOf(pick.get("reportName"));
                String dealSlot = (reportName.split("至")[0]).substring(2) + '-' +reportName.split("至")[1];
                Map<String, Object> pickItem = new HashMap<>();
                pickItem.put("reportName", pick.get("jydyParticipantName"));
                pickItem.put("dealSlot", dealSlot);
                pickItem.put("energy", "*****");
                pickItem.put("confirmTime", DateUtils.dateTimeFormat(String.valueOf(pick.get("decDate"))));
                pickResult.add(pickItem);
            }
            result.put("sale", hangResult);
            result.put("buy", pickResult);
        }
        return result;
    }

    /**
     * 集中/挂牌交易  实时交易 -- 交易监控流程
     *
     * 交易流程监控: 1-公告发布变亮  2-交易申报变亮 3-交易开标和交易计算都变亮, 4-交易出清变亮, 5-结果发布变亮
     *
     * 交易公告的开始时间之前: 交易发布
     * 交易公告的开始跟结束时间内: 交易申报
     * 申报结束12小时内完成计算状态为：交易开标与交易计算
     * 申报结束后12小时-24小时内为交易出清
     * 申报结束后26小时- 24小时内为结果发布
     * @param beginDate
     * @param endDate
     * @return
     */
    public static String judgeDealProcess(String beginDate, String endDate) {
        try {
            if (StringUtils.isEmpty(beginDate) || StringUtils.isEmpty(endDate)) {
                log.info("交易公告开始时间beginDate, 结束时间endDate为空!");
                return "5";
            }
            //获取当前时间点
            LocalDateTime nowDateTime = LocalDateTime.now();
            //申报开始时间
            LocalDateTime beginDateTime = LocalDateTime.parse(beginDate, DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss"));
            //申报结束时间
            LocalDateTime endDateTime = LocalDateTime.parse(endDate, DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss"));
            if (nowDateTime.isBefore(beginDateTime)) {
                return "1";
            } else if (nowDateTime.isAfter(beginDateTime) && nowDateTime.isBefore(endDateTime)) {
                return "2";
            } else if (nowDateTime.isAfter(endDateTime) && nowDateTime.isBefore(endDateTime.plusHours(12))) {
                return "3";
            } else if (nowDateTime.isAfter(endDateTime.plusHours(12)) && nowDateTime.isBefore(endDateTime.plusHours(24))) {
                return "4";
            } else {
                return "5";
            }
        } catch (Exception e) {
            e.printStackTrace();
            log.info("集中竞价、挂牌交易, 实时状态, 交易监控流程获取失败!");
            return "5";
        }

    }

    /**
     *  集中/挂牌交易  实时交易 -- 申报主体走势分析
     * @param buySaleDetails
     * @throws ParseException
     */
    public static Map<String, Object> reportSubjectTrend(String beginDate, String endDate, Map<String, Object> buySaleDetails){
        try {
            //x轴时间按开始时间每隔1小时至结束时间
            LocalDateTime beginDateTime = LocalDateTime.parse(beginDate, DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss"));
            LocalDateTime endDateTime = LocalDateTime.parse(endDate, DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss"));
            //x轴时间数据
            List<String> xAxisData = new LinkedList<String>();
            //y轴数据
            List<Map<String, Object>> seriesData = new ArrayList<>();
            //售方数据
            List<Integer> saleData = new LinkedList<>();
            //购方数据
            List<Integer> buyData = new LinkedList<>();
            while (beginDateTime.isBefore(endDateTime) || beginDateTime.equals(endDateTime)) {
                String xAxisTime = beginDateTime.format(DateTimeFormatter.ofPattern("MM-dd HH:mm"));
                xAxisData.add(xAxisTime);
                //y轴 购售方数据
                List<Map<String, Object>> buyList = (List<Map<String, Object>>) buySaleDetails.get("buy");
                List<Map<String, Object>> saleList = (List<Map<String, Object>>) buySaleDetails.get("sale");
                //统计购方时间段内的家数(一个企业10个时段)
                Map<String, Integer> buyNumMap = new HashMap<String, Integer>();
                for (Map<String, Object> buyItem : buyList) {
                    //MM-dd HH:mm 变为 yyyy-MM-dd HH:mm:ss
                    String confirmTime = Year.now() + "-" + String.valueOf(buyItem.get("confirmTime")) + ":00";
                    LocalDateTime confirmDateTime = LocalDateTime.parse(confirmTime, DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss"));
                    if ((confirmDateTime.equals(beginDateTime) || confirmDateTime.isAfter(beginDateTime)) && confirmDateTime.isBefore(beginDateTime.plusHours(1))) {
                        String key = String.valueOf(buyItem.get("reportName")) + ":" + String.valueOf(buyItem.get("confirmTime"));
                        //企业名相同且时间也相同  算一个购方， 企业名相同但时间不同 算俩个
                        buyNumMap.put(key, 1);
                    }
                }
                //统计售方时间段内的家数
                Map<String, Integer> saleNumMap = new HashMap<String, Integer>();
                for (Map<String, Object> saleItem : saleList) {
                    //MM-dd HH:mm 变为 yyyy-MM-dd HH:mm:ss
                    String confirmTime = Year.now() + "-" + String.valueOf(saleItem.get("confirmTime")) + ":00";
                    LocalDateTime confirmDateTime = LocalDateTime.parse(confirmTime, DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss"));
                    if ((confirmDateTime.equals(beginDateTime) || confirmDateTime.isAfter(beginDateTime)) && confirmDateTime.isBefore(beginDateTime.plusHours(1))) {
                        String key = String.valueOf(saleItem.get("reportName")) + ":" + String.valueOf(saleItem.get("confirmTime"));
                        //企业名相同且时间也相同  算一个购方， 企业名相同但时间不同 算俩个
                        saleNumMap.put(key, 1);
                    }
                }
                saleData.add(saleNumMap.size());
                buyData.add(buyNumMap.size());

                beginDateTime = beginDateTime.plusHours(1);
            }
            //封装y轴数据
            Map<String, Object> saleMap = new HashMap<String, Object>();
            saleMap.put("name", "售方");
            saleMap.put("data", saleData);
            Map<String, Object> buyMap = new HashMap<String, Object>();
            buyMap.put("name", "购方");
            buyMap.put("data", buyData);
            seriesData.add(saleMap);
            seriesData.add(buyMap);
            Map<String, Object> result = new HashMap<>();
            result.put("xAxisData", xAxisData);
            result.put("seriesData", seriesData);
            return result;
        } catch (Exception e) {
            e.printStackTrace();
            log.info("集中竞价、挂牌交易, 实时状态, 申报主体走势分析数据获取失败!");
            return new HashMap<>();
        }
    }

    /**
     * 	申报曲线
     * @param saleData
     * @return
     * @throws ParseException
     */
    public static Map<String, Object> reportCurve(List<Map<String, Object>> saleData){
        if (saleData == null || saleData.size() == 0) {
            log.info("计算申报曲线FocusBidding.reportCurve参数为空!");
            return new HashMap<>();
        }
        try {
            //售方
            //将数据通过申报主体名称、交易时间进行分组
            Map<String, List<Map<String, Object>>> groupData = new HashMap<>();
            for (Map<String, Object> sale : saleData) {
                //存储Key 格式：主体名称:时间
                String key = String.valueOf(sale.get("jydyParticipantName")) + ":" + DateUtils.dateTimeFormat(String.valueOf(sale.get("decDate")));
                List<Map<String, Object>> groupItem = groupData.get(key);
                if (groupItem != null) {
                    groupItem.add(sale);
                } else {
                    groupData.put(key, new ArrayList<Map<String,Object>>());
                }
            }
            //遍历分组后的数据,根据时间排序
            List<Map.Entry<String, List<Map<String, Object>>>> groupDataList = new ArrayList<Map.Entry<String, List<Map<String, Object>>>>(groupData.entrySet());
            Collections.sort(groupDataList, new Comparator<Map.Entry<String, List<Map<String, Object>>>>() {
                @Override
                public int compare(Map.Entry<String, List<Map<String, Object>>> o1,
                                   Map.Entry<String, List<Map<String, Object>>> o2) {
                    return o1.getKey().split(":")[1].compareTo(o2.getKey().split(":")[1]);
                }
            });

            List<Integer> xAxis = new LinkedList<>();
            //峰
            List<String> peakValue = new LinkedList<>();
            //平
            List<String> flatValue = new LinkedList<>();
            //谷
            List<String> valleyValue = new LinkedList<>();
            //遍历排序后的集合
            int index = 0;
            for (Map.Entry<String, List<Map<String, Object>>> entry : groupDataList) {
                List<Map<String, Object>> values = entry.getValue();
                String peakPrice = "0";
                String flatPrice = "0";
                String valleyPrice = "0";
                for (Map<String, Object> value : values) {
                    String typeName = String.valueOf(String.valueOf(value.get("reportName")).charAt(0));
                    if(typeName.equals("峰")) {
                        peakPrice = String.valueOf(value.get("price"));
                    }else if (typeName.equals("平")) {
                        flatPrice = String.valueOf(value.get("price"));
                    }else {
                        valleyPrice = String.valueOf(value.get("price"));
                    }
                }
                xAxis.add(index);
                peakValue.add(peakPrice);
                flatValue.add(flatPrice);
                valleyValue.add(valleyPrice);
                index ++;
            }
            //封装seriesData
            Map<String, Object> peakMap = new HashMap<>();
            peakMap.put("name", "峰段价格");
            peakMap.put("data", peakValue);
            Map<String, Object> flatMap = new HashMap<>();
            flatMap.put("name", "平段价格");
            flatMap.put("data", flatValue);
            Map<String, Object> valleyMap = new HashMap<>();
            valleyMap.put("name", "谷段价格");
            valleyMap.put("data", valleyValue);
            List<Map<String, Object>> seriesData = new ArrayList<>();
            seriesData.add(peakMap);
            seriesData.add(flatMap);
            seriesData.add(valleyMap);

            Map<String, Object> result = new HashMap<>();
            result.put("xAxisData", xAxis);
            result.put("seriesData", seriesData);
            return result;
        }catch (Exception e) {
            e.printStackTrace();
            log.info("-获取集中竞价/挂牌交易, 申报曲线数据异常");
            return new HashMap<>();
        }
    }

    /**
     * 	成交电量量价分布
     * @param saleData
     * @param buyData
     * @return
     * @throws ParseException
     */
    public static Map<String, Object> volumePriceSpread(List<Map<String, Object>> saleData, List<Map<String, Object>> buyData){
        if (saleData == null || buyData == null) {
            log.info("处理成交电量量价分布FocusBidding.volumePriceSpread()参数为null!");
            return new HashMap<>();
        }
        try {
            //摘牌方分组
            Map<String, List<Map<String, Object>>> groupData = new HashMap<>();
            for (Map<String, Object> buy : buyData) {
                //存储Key 格式：主体名称:时间
                String key = String.valueOf(buy.get("jydyParticipantName")) + ":" + DateUtils.dateTimeFormat(String.valueOf(buy.get("decDate")));
                List<Map<String, Object>> groupItem = groupData.get(key);
                if (groupItem != null) {
                    groupItem.add(buy);
                } else {
                    ArrayList<Map<String, Object>> newList = new ArrayList<Map<String,Object>>();
                    newList.add(buy);
                    groupData.put(key, newList);
                }
            }
            //统计每组数据电量
            //遍历分组后的数据,根据时间排序
            List<Map.Entry<String, List<Map<String, Object>>>> groupDataList = new ArrayList<Map.Entry<String, List<Map<String, Object>>>>(groupData.entrySet());
            Collections.sort(groupDataList, new Comparator<Map.Entry<String, List<Map<String, Object>>>>() {
                @Override
                public int compare(Map.Entry<String, List<Map<String, Object>>> o1,
                                   Map.Entry<String, List<Map<String, Object>>> o2) {
                    return o1.getKey().split(":")[1].compareTo(o2.getKey().split(":")[1]);
                }
            });
            //量价和
            BigDecimal volumePriceCount = BigDecimal.ZERO;
            //总量
            BigDecimal energyCount = BigDecimal.ZERO;
            //获取电价
            for (Map<String, Object> sale : saleData) {
                BigDecimal energy = new BigDecimal(String.valueOf(sale.get("checkEnergy")));
                BigDecimal price = new BigDecimal(String.valueOf(sale.get("price")));
                BigDecimal sum = energy.multiply(price);
                volumePriceCount = volumePriceCount.add(sum);
                energyCount = energyCount.add(energy);
            }
            //计算加权平均价(量*价的和除以总量)
            BigDecimal weightedAvgPrice = volumePriceCount.divide(energyCount, 2, BigDecimal.ROUND_HALF_UP).setScale(2, BigDecimal.ROUND_HALF_UP);

            //y轴数据
            List<String> yAxis = new LinkedList<String>();
            //x轴数据
            List<BigDecimal> data = new LinkedList<BigDecimal>();
            int index = 01;
            //遍历排序后的数据
            System.out.println("===========" + groupDataList);
            for (Map.Entry<String, List<Map<String, Object>>> entry : groupDataList) {
                //获取每个摘牌主体电量和
                List<Map<String, Object>> values = entry.getValue();
                BigDecimal energySum = BigDecimal.ZERO;
                for (Map<String, Object> value : values) {
                    BigDecimal energy = new BigDecimal(String.valueOf(value.get("checkEnergy")));
                    energySum = energySum.add(energy);
                }
                System.out.println("-===============" + energySum);
                //组装y轴数据
                String yData = "价" + index + ":" + weightedAvgPrice;
                yAxis.add(yData);
                data.add(energySum);
                index ++;
            }
            Map<String, Object> result = new HashMap<>();
            result.put("xAxisData", yAxis);
            result.put("seriesData", data);
            return result;
        }catch (Exception e) {
            e.printStackTrace();
            log.info("-获取集中竞价/挂牌交易, 成交电量量价分布数据异常!");
            return new HashMap<>();
        }
    }

    /**
     * 统计开标前购售方个数
     * @param data
     * @throws ParseException
     */
    public static int censusBuySaleNum(List<Map> data) throws ParseException {
        Set<String> set = new HashSet<>();
        for (Map<String, Object> map : data) {
            String Key = map.get("jydyParticipantName") + ":" + DateUtils.dateTimeFormat(String.valueOf(map.get("decDate")));
            set.add(Key);
        }
        return set.size();
    }

}
