package com.alonginfo.project.gansu.serviceimpl.forward;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.TypeReference;
import com.alonginfo.common.utils.StringUtils;
import com.alonginfo.common.utils.http.HttpUtils;
import com.alonginfo.project.gansu.service.SgccAddressService;
import com.alonginfo.project.gansu.service.forward.IDeliveryService;
import com.alonginfo.utils.DataPushUtils;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.io.IOException;
import java.util.*;

/**
 * @author: HaoXs
 * @Date: 2023/7/7 17:36
 * @Description:
 */
@Service
@Slf4j
public class DeliveryServiceImpl implements IDeliveryService {

    @Value("${env.key}")
    private String ENV_KEY;

    @Value("${sgcc.publicKey}")
    public String PUBLIC_KEY;

    @Autowired
    private SgccAddressService sgccAddressService;

    @Override
    public List<Map<String, Object>> trackingPower() {
        String sgccAddress = sgccAddressService.getSgccAddress(ENV_KEY);
        String trackingPowerRes = HttpUtils.sendPost(sgccAddress + "/delivery/trackingPower", "", DataPushUtils.createToken(PUBLIC_KEY));
        log.info("-接口: /delivery/trackingPower, 调用结果: {}", trackingPowerRes);
        if (StringUtils.isEmpty(trackingPowerRes)) {
            log.error("-接口: /delivery/trackingPower, 返回结果为空!");
            return new ArrayList<>();
        }
        Map map = JSON.parseObject(trackingPowerRes, Map.class);
        Object data = map.get("data");
        if (null == data) {
            log.error("-接口: /delivery/trackingPower, data值为NULL");
            return new ArrayList<>();
        }
        return JSON.parseObject(JSON.toJSONString(data), new TypeReference<List<Map<String, Object>>>() {
        });
    }

    @Override
    public List<Map<String, Object>> getShortSendAllData() {
        String sgccAddress = sgccAddressService.getSgccAddress(ENV_KEY);
        String shortSendDataRes = HttpUtils.sendPost(sgccAddress + "/delivery/getShortSendAllData", "", DataPushUtils.createToken(PUBLIC_KEY));
        log.info("-接口: /delivery/getShortSendAllData, 调用结果: {}", shortSendDataRes);
        if (StringUtils.isEmpty(shortSendDataRes)) {
            log.error("-接口: /delivery/getShortSendAllData, 返回结果为空!");
            return new ArrayList<>();
        }
        Map map = JSON.parseObject(shortSendDataRes, Map.class);
        Object data = map.get("data");
        if (null == data) {
            log.error("-接口: /delivery/getShortSendAllData, data值为NULL");
            return new ArrayList<>();
        }
        return JSON.parseObject(JSON.toJSONString(data), new TypeReference<List<Map<String, Object>>>() {
        });
    }

    @Override
    public List<Map<String, Object>> getSendByAllChannel() {
        String sgccAddress = sgccAddressService.getSgccAddress(ENV_KEY);
        String sendByAllChannelRes = HttpUtils.sendPost(sgccAddress + "/delivery/getSendByAllChannel", "", DataPushUtils.createToken(PUBLIC_KEY));
        log.info("-接口: /delivery/getSendByAllChannel, 调用结果: {}", sendByAllChannelRes);
        if (StringUtils.isEmpty(sendByAllChannelRes)) {
            log.error("-接口: /delivery/getSendByAllChannel, 返回结果为空!");
            return new ArrayList<>();
        }
        Map map = JSON.parseObject(sendByAllChannelRes, Map.class);
        Object data = map.get("data");
        if (null == data) {
            log.error("-接口: /delivery/getSendByAllChannel, data值为NULL");
            return new ArrayList<>();
        }
        return JSON.parseObject(JSON.toJSONString(data), new TypeReference<List<Map<String, Object>>>() {
        });
    }

    @Override
    public List<Map<String, Object>> selectMachineLoadList() {
        String sgccAddress = sgccAddressService.getSgccAddress(ENV_KEY);
        String selectMachineLoadListRes = HttpUtils.sendPost(sgccAddress + "/delivery/selectMachineLoadList", "", DataPushUtils.createToken(PUBLIC_KEY));
        log.info("-接口: /delivery/selectMachineLoadList, 调用结果: {}", selectMachineLoadListRes);
        if (StringUtils.isEmpty(selectMachineLoadListRes)) {
            log.error("-接口: /delivery/selectMachineLoadList, 返回结果为空!");
            return new ArrayList<>();
        }
        Map map = JSON.parseObject(selectMachineLoadListRes, Map.class);
        Object data = map.get("data");
        if (null == data) {
            log.error("-接口: /delivery/selectMachineLoadList, data值为NULL");
            return new ArrayList<>();
        }
        return JSON.parseObject(JSON.toJSONString(data), new TypeReference<List<Map<String, Object>>>() {
        });
    }

    @Override
    public List<Map<String, Object>> selectGroupCap() {
        String sgccAddress = sgccAddressService.getSgccAddress(ENV_KEY);
        String selectGroupCapRes = HttpUtils.sendPost(sgccAddress + "/delivery/selectGroupCap", "", DataPushUtils.createToken(PUBLIC_KEY));
        log.info("-接口: /delivery/selectGroupCap, 调用结果: {}", selectGroupCapRes);
        if (StringUtils.isEmpty(selectGroupCapRes)) {
            log.error("-接口: /delivery/selectGroupCap, 返回结果为空!");
            return new ArrayList<>();
        }
        Map map = JSON.parseObject(selectGroupCapRes, Map.class);
        Object data = map.get("data");
        if (null == data) {
            log.error("-接口: /delivery/selectGroupCap, data值为NULL");
            return new ArrayList<>();
        }
        return JSON.parseObject(JSON.toJSONString(data), new TypeReference<List<Map<String, Object>>>() {
        });
    }

    @Override
    public List<Map<String, Object>> selectContractInfo() {
        String sgccAddress = sgccAddressService.getSgccAddress(ENV_KEY);
        String contractInfoRes = HttpUtils.sendPost(sgccAddress + "/delivery/selectContractInfo", "", DataPushUtils.createToken(PUBLIC_KEY));
        log.info("-接口: /delivery/selectContractInfo, 调用结果: {}", contractInfoRes);
        if (StringUtils.isEmpty(contractInfoRes)) {
            log.error("-接口: /delivery/selectContractInfo, 返回结果为空!");
            return new ArrayList<>();
        }
        JSONObject jsonObject = JSONObject.parseObject(contractInfoRes);
        Object data = jsonObject.get("data");
        if (null == data) {
            log.error("-接口: /delivery/selectContractInfo, data值为NULL");
            return new ArrayList<>();
        }
        return JSON.parseObject(JSON.toJSONString(data), new TypeReference<List<Map<String, Object>>>(){});
    }

    @Override
    public List<Map<String, Object>> selectEmossContractList() {
        String sgccAddress = sgccAddressService.getSgccAddress(ENV_KEY);
        String emossRes = HttpUtils.sendPost(sgccAddress + "/delivery/selectEmossContractList", "", DataPushUtils.createToken(PUBLIC_KEY));
        log.info("-接口: /delivery/selectEmossContractList, 调用结果: {}", emossRes);
        if(StringUtils.isEmpty(emossRes)) {
            log.error("-接口: /delivery/selectEmossContractList, 返回结果为空!");
            return new ArrayList<>();
        }
        Map map = JSON.parseObject(emossRes, Map.class);
        Object data = map.get("data");
        if (null == data) {
            log.error("-接口: /delivery/selectEmossContractList, data值为NULL");
            return new ArrayList<>();
        }
        return JSON.parseObject(JSON.toJSONString(data), new TypeReference<List<Map<String, Object>>>(){});
    }

    @Override
    public List<Map<String, Object>> selectEmossContractListByMonth() {
        String sgccAddress = sgccAddressService.getSgccAddress(ENV_KEY);
        String emossByMonthRes = HttpUtils.sendPost(sgccAddress + "/delivery/selectEmossContractListByMonth", "", DataPushUtils.createToken(PUBLIC_KEY));
        log.info("-接口: /delivery/selectEmossContractListByMonth, 调用结果: {}", emossByMonthRes);
        if(StringUtils.isEmpty(emossByMonthRes)) {
            log.error("-接口: /delivery/selectEmossContractListByMonth, 返回结果为空!");
            return new ArrayList<>();
        }
        Map map = JSON.parseObject(emossByMonthRes, Map.class);
        Object data = map.get("data");
        if (null == data) {
            log.error("-接口: /delivery/selectEmossContractListByMonth, data值为NULL");
            return new ArrayList<>();
        }
        return JSON.parseObject(JSON.toJSONString(data), new TypeReference<List<Map<String, Object>>>(){});
    }


    @Override
    public List<Map<String, Object>> selectInnerTradeByType() {
        String sgccAddress = sgccAddressService.getSgccAddress(ENV_KEY);
        String innerTradeRes = HttpUtils.sendPost(sgccAddress + "/delivery/selectInnerTradeByType", "", DataPushUtils.createToken(PUBLIC_KEY));
        log.info("-接口: /delivery/selectInnerTradeByType, 调用结果: {}", innerTradeRes);
        if(StringUtils.isEmpty(innerTradeRes)) {
            log.error("-接口: /delivery/selectInnerTradeByType, 返回结果为空!");
            return new ArrayList<>();
        }
        Map map = JSON.parseObject(innerTradeRes, Map.class);
        Object data = map.get("data");
        if (null == data) {
            log.error("-接口: /delivery/selectInnerTradeByType, data值为NULL");
            return new ArrayList<>();
        }
        return JSON.parseObject(JSON.toJSONString(data), new TypeReference<List<Map<String, Object>>>(){});
    }

    @Override
    public List<Map<String, Object>> selectDirTradeInfo() {
        String sgccAddress = sgccAddressService.getSgccAddress(ENV_KEY);
        String dirTradeInfoRes = HttpUtils.sendPost(sgccAddress + "/delivery/selectDirTradeInfo", "", DataPushUtils.createToken(PUBLIC_KEY));
        log.info("-接口: /delivery/selectDirTradeInfo, 调用结果: {}", dirTradeInfoRes);
        if(StringUtils.isEmpty(dirTradeInfoRes)) {
            log.error("-接口: /delivery/selectDirTradeInfo, 返回结果为空!");
            return new ArrayList<>();
        }
        Map map = JSON.parseObject(dirTradeInfoRes, Map.class);
        Object data = map.get("data");
        if (null == data) {
            log.error("-接口: /delivery/selectDirTradeInfo, data值为NULL");
            return new ArrayList<>();
        }
        return JSON.parseObject(JSON.toJSONString(data), new TypeReference<List<Map<String, Object>>>(){});
    }

    @Override
    public List<Map<String, Object>> selectPowerContractListByMonth() {
        String sgccAddress = sgccAddressService.getSgccAddress(ENV_KEY);
        String powerContractByMonthRes = HttpUtils.sendPost(sgccAddress + "/delivery/selectPowerContractListByMonth", "", DataPushUtils.createToken(PUBLIC_KEY));
        log.info("-接口: /delivery/selectPowerContractListByMonth, 调用结果: {}", powerContractByMonthRes);
        if(StringUtils.isEmpty(powerContractByMonthRes)) {
            log.error("-接口: /delivery/selectPowerContractListByMonth, 返回结果为空!");
            return new ArrayList<>();
        }
        Map map = JSON.parseObject(powerContractByMonthRes, Map.class);
        Object data = map.get("data");
        if (null == data) {
            log.error("-接口: /delivery/selectPowerContractListByMonth, data值为NULL");
            return new ArrayList<>();
        }
        return JSON.parseObject(JSON.toJSONString(data), new TypeReference<List<Map<String, Object>>>(){});
    }

    @Override
    public List<Map<String, Object>> newQueryProviceProviderEle() {
        String sgccAddress = sgccAddressService.getSgccAddress(ENV_KEY);
        String provinceProviderEleResStr = HttpUtils.sendPost(sgccAddress + "/delivery/newQueryProviceProviderEle", "", DataPushUtils.createToken(PUBLIC_KEY));
        log.info("-接口: /delivery/newQueryProviceProviderEle, 调用结果: {}", provinceProviderEleResStr);
        if(StringUtils.isEmpty(provinceProviderEleResStr)) {
            log.error("-接口: /delivery/newQueryProviceProviderEle, 返回结果为空!");
            return new ArrayList<>();
        }
        Map map = JSON.parseObject(provinceProviderEleResStr, Map.class);
        Object data = map.get("data");
        if (null == data) {
            log.error("-接口: /delivery/newQueryProviceProviderEle, data值为NULL");
            return new ArrayList<>();
        }
        return JSON.parseObject(JSON.toJSONString(data), new TypeReference<List<Map<String, Object>>>(){});
    }

    @Override
    public List<Map<String, Object>> selectGeneratorCount() {
        String sgccAddress = sgccAddressService.getSgccAddress(ENV_KEY);
        String generatorCountResStr = HttpUtils.sendPost(sgccAddress + "/delivery/selectGeneratorCount", "", DataPushUtils.createToken(PUBLIC_KEY));
        log.info("-接口: /delivery/selectGeneratorCount, 调用结果: {}", generatorCountResStr);
        if(StringUtils.isEmpty(generatorCountResStr)) {
            log.error("-接口: /delivery/selectGeneratorCount, 返回结果为空!");
            return new ArrayList<>();
        }
        Map map = JSON.parseObject(generatorCountResStr, Map.class);
        Object data = map.get("data");
        if (null == data) {
            log.error("-接口: /delivery/selectGeneratorCount, data值为NULL");
            return new ArrayList<>();
        }
        return JSON.parseObject(JSON.toJSONString(data), new TypeReference<List<Map<String, Object>>>(){});
    }

    @Override
    public List<Map<String, Object>> selectParticipantByMonth() {
        String sgccAddress = sgccAddressService.getSgccAddress(ENV_KEY);
        String participantByMonthResStr = HttpUtils.sendPost(sgccAddress + "/delivery/selectParticipantByMonth", "", DataPushUtils.createToken(PUBLIC_KEY));
        log.info("-接口: /delivery/selectParticipantByMonth, 调用结果: {}", participantByMonthResStr);
        if(StringUtils.isEmpty(participantByMonthResStr)) {
            log.error("-接口: /delivery/selectParticipantByMonth, 返回结果为空!");
            return new ArrayList<>();
        }
        Map map = JSON.parseObject(participantByMonthResStr, Map.class);
        Object data = map.get("data");
        if (null == data) {
            log.error("-接口: /delivery/selectParticipantByMonth, data值为NULL");
            return new ArrayList<>();
        }
        return JSON.parseObject(JSON.toJSONString(data), new TypeReference<List<Map<String, Object>>>(){});

    }

    @Override
    public List<Map<String, Object>> selectTradeCountByMonth(String year) throws IOException {
        String sgccAddress = sgccAddressService.getSgccAddress(ENV_KEY);
        Map<String, String> param = new HashMap<>();
        param.put("year", year);
        String tradeCountResStr = HttpUtils.sendPostDataByJson(sgccAddress + "/delivery/selectTradeCountByMonth", JSON.toJSONString(param), DataPushUtils.createToken(PUBLIC_KEY));
        log.info("-接口: /delivery/selectTradeCountByMonth, 调用结果: {}", tradeCountResStr);
        if(StringUtils.isEmpty(tradeCountResStr)) {
            log.error("-接口: /delivery/selectTradeCountByMonth, 返回结果为空!");
            return new ArrayList<>();
        }
        Map map = JSON.parseObject(tradeCountResStr, Map.class);
        Object data = map.get("data");
        if (null == data) {
            log.error("-接口: /delivery/selectTradeCountByMonth, data值为NULL");
            return new ArrayList<>();
        }
        return JSON.parseObject(JSON.toJSONString(data), new TypeReference<List<Map<String, Object>>>(){});
    }

    @Override
    public List<Map<String, Object>> selectGreenPower() {
        String sgccAddress = sgccAddressService.getSgccAddress(ENV_KEY);
        String greenPowerRes = HttpUtils.sendPost(sgccAddress + "/delivery/selectGreenPower", "", DataPushUtils.createToken(PUBLIC_KEY));
        log.info("-接口: /delivery/selectGreenPower, 调用结果: {}", greenPowerRes);
        if(StringUtils.isEmpty(greenPowerRes)) {
            log.error("-接口: /delivery/selectGreenPower, 返回结果为空!");
            return new ArrayList<>();
        }
        Map map = JSON.parseObject(greenPowerRes, Map.class);
        Object data = map.get("data");
        if (null == data) {
            log.error("-接口: /delivery/selectGreenPower, data值为NULL");
            return new ArrayList<>();
        }
        return JSON.parseObject(JSON.toJSONString(data), new TypeReference<List<Map<String, Object>>>(){});
    }

    @Override
    public List<Map<String, Object>> selectInnerGreenPower() {
        String sgccAddress = sgccAddressService.getSgccAddress(ENV_KEY);
        String innerGreenPowerRes = HttpUtils.sendPost(sgccAddress + "/delivery/selectInnerGreenPower", "", DataPushUtils.createToken(PUBLIC_KEY));
        log.info("-接口: /delivery/selectInnerGreenPower, 调用结果: {}", innerGreenPowerRes);
        if(StringUtils.isEmpty(innerGreenPowerRes)) {
            log.error("-接口: /delivery/selectInnerGreenPower, 返回结果为空!");
            return new ArrayList<>();
        }
        Map map = JSON.parseObject(innerGreenPowerRes, Map.class);
        Object data = map.get("data");
        if (null == data) {
            log.error("-接口: /delivery/selectInnerGreenPower, data值为NULL");
            return new ArrayList<>();
        }
        return JSON.parseObject(JSON.toJSONString(data), new TypeReference<List<Map<String, Object>>>(){});
    }

    @Override
    public List<Map<String, Object>> selectParticipantReg() {
        String sgccAddress = sgccAddressService.getSgccAddress(ENV_KEY);
        String participantRegResStr = HttpUtils.sendPost(sgccAddress + "/delivery/selectParticipantReg", "", DataPushUtils.createToken(PUBLIC_KEY));
        log.info("-接口: /delivery/selectParticipantReg, 调用结果: {}", participantRegResStr);
        if(StringUtils.isEmpty(participantRegResStr)) {
            log.error("-接口: /delivery/selectParticipantReg, 返回结果为空!");
            return new ArrayList<>();
        }
        Map map = JSON.parseObject(participantRegResStr, Map.class);
        Object data = map.get("data");
        if (Objects.isNull(data)) {
            log.error("-接口: /delivery/selectParticipantReg, data值为NULL");
            return new ArrayList<>();
        }
        return JSON.parseObject(JSON.toJSONString(data), new TypeReference<List<Map<String, Object>>>(){});
    }

    @Override
    public List<Map<String, Object>> selectParticipantTrade() {
        String sgccAddress = sgccAddressService.getSgccAddress(ENV_KEY);
        String participantTradeResStr = HttpUtils.sendPost(sgccAddress + "/delivery/selectParticipantTrade", "", DataPushUtils.createToken(PUBLIC_KEY));
        log.info("-接口: /delivery/selectParticipantTrade, 调用结果: {}", participantTradeResStr);
        if(StringUtils.isEmpty(participantTradeResStr)) {
            log.error("-接口: /delivery/selectParticipantTrade, 返回结果为空!");
            return new ArrayList<>();
        }
        Map map = JSON.parseObject(participantTradeResStr, Map.class);
        Object data = map.get("data");
        if (Objects.isNull(data)) {
            log.error("-接口: /delivery/selectParticipantTrade, data值为NULL");
            return new ArrayList<>();
        }
        return JSON.parseObject(JSON.toJSONString(data), new TypeReference<List<Map<String, Object>>>(){});
    }

    @Override
    public List<Map<String, Object>> selectParticipantTradeByYear() {
        String sgccAddress = sgccAddressService.getSgccAddress(ENV_KEY);
        String participantTradeByYearResStr = HttpUtils.sendPost(sgccAddress + "/delivery/selectParticipantTradeByYear", "", DataPushUtils.createToken(PUBLIC_KEY));
        log.info("-接口: /delivery/selectParticipantTradeByYear, 调用结果: {}", participantTradeByYearResStr);
        if(StringUtils.isEmpty(participantTradeByYearResStr)) {
            log.error("-接口: /delivery/selectParticipantTradeByYear, 返回结果为空!");
            return new ArrayList<>();
        }
        Map map = JSON.parseObject(participantTradeByYearResStr, Map.class);
        Object data = map.get("data");
        if (Objects.isNull(data)) {
            log.error("-接口: /delivery/selectParticipantTradeByYear, data值为NULL");
            return new ArrayList<>();
        }
        return JSON.parseObject(JSON.toJSONString(data), new TypeReference<List<Map<String, Object>>>(){});
    }

    @Override
    public List<Map<String, Object>> selectYearDirEnergy() {
        String sgccAddress = sgccAddressService.getSgccAddress(ENV_KEY);
        String yearDirEnergyResStr = HttpUtils.sendPost(sgccAddress + "/delivery/selectYearDirEnergy", "", DataPushUtils.createToken(PUBLIC_KEY));
        log.info("-接口: /delivery/yearDirEnergyResStr, 调用结果: {}", yearDirEnergyResStr);
        if(StringUtils.isEmpty(yearDirEnergyResStr)) {
            log.error("-接口: /delivery/yearDirEnergyResStr, 返回结果为空!");
            return new ArrayList<>();
        }
        Map map = JSON.parseObject(yearDirEnergyResStr, Map.class);
        Object data = map.get("data");
        if (Objects.isNull(data)) {
            log.error("-接口: /delivery/yearDirEnergyResStr, data值为NULL");
            return new ArrayList<>();
        }
        return JSON.parseObject(JSON.toJSONString(data), new TypeReference<List<Map<String, Object>>>(){});
    }
}
