package com.alonginfo.project.gansu.serviceimpl.forward;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.TypeReference;
import com.alonginfo.common.utils.StringUtils;
import com.alonginfo.common.utils.http.HttpUtils;
import com.alonginfo.project.gansu.service.SgccAddressService;
import com.alonginfo.project.gansu.service.forward.IGreenConsumer;
import com.alonginfo.utils.DataPushUtils;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.io.IOException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author: HaoXs
 * @Date: 2023/7/7 17:14
 * @Description:
 */
@Service
@Slf4j
public class GreenConsumerImpl implements IGreenConsumer {

    @Value("${env.key}")
    private String ENV_KEY;

    @Value("${sgcc.publicKey}")
    public String PUBLIC_KEY;

    @Autowired
    private SgccAddressService sgccAddressService;

    /**
     * 历年外送电规模
     * @return
     */
    @Override
    public List<Map<String, Object>> getYearHitorySend() throws IOException {
        String sgccAddress = sgccAddressService.getSgccAddress(ENV_KEY);
        //传空json对象
        Map<String, String> param = new HashMap<>();
        String yearHitorySendRes = HttpUtils.sendPostDataByJson(sgccAddress + "/greenConsumer/getYearHitorySend", JSON.toJSONString(param), DataPushUtils.createToken(PUBLIC_KEY));
        log.info("-接口: /greenConsumer/getYearHitorySend, 调用结果: {}", yearHitorySendRes);
        if (StringUtils.isEmpty(yearHitorySendRes)) {
            log.error("-接口: /greenConsumer/getYearHitorySend, 返回结果为空!");
            return new ArrayList<>();
        }
        Map map = JSON.parseObject(yearHitorySendRes, Map.class);
        Object data = map.get("data");
        if (null == data) {
            log.error("-接口: /greenConsumer/getYearHitorySend, data值为NULL");
            return new ArrayList<>();
        }
        return JSON.parseObject(JSON.toJSONString(data), new TypeReference<List<Map<String, Object>>>() {});
    }

    /**
     * 装机总量/新能源变化趋势
     * @return
     */
    @Override
    public List<Map<String, Object>> getMachineHistory() throws IOException {
        String sgccAddress = sgccAddressService.getSgccAddress(ENV_KEY);
        //传空json对象
        Map<String, String> param = new HashMap<>();
        String machineHistoryRes = HttpUtils.sendPostDataByJson(sgccAddress + "/greenConsumer/getMachineHistory", JSON.toJSONString(param), DataPushUtils.createToken(PUBLIC_KEY));
        log.info("-接口: /greenConsumer/getMachineHistory, 调用结果: {}", machineHistoryRes);
        if (StringUtils.isEmpty(machineHistoryRes)) {
            log.error("-接口: /greenConsumer/getMachineHistory, 返回结果为空!");
            return new ArrayList<>();
        }
        Map map = JSON.parseObject(machineHistoryRes, Map.class);
        Object data = map.get("data");
        if (null == data) {
            log.error("-接口: /greenConsumer/getMachineHistory, data值为NULL");
            return new ArrayList<>();
        }
        return JSON.parseObject(JSON.toJSONString(data), new TypeReference<List<Map<String, Object>>>() {});
    }

    /**
     * 新能源装机结构
     * @return
     */
    @Override
    public Map<String, Object> getGreenProportion() throws IOException {
        String sgccAddress = sgccAddressService.getSgccAddress(ENV_KEY);
        //传空json对象
        Map<String, String> param = new HashMap<>();
        String greenProportionResStr = HttpUtils.sendPostDataByJson(sgccAddress + "/greenConsumer/getGreenProportion", JSON.toJSONString(param), DataPushUtils.createToken(PUBLIC_KEY));
        log.info("-接口: /greenConsumer/getGreenProportion, 调用结果: {}", greenProportionResStr);
        if (StringUtils.isEmpty(greenProportionResStr)) {
            log.error("-接口: /greenConsumer/getGreenProportion, 返回结果为空!");
            return new HashMap<>();
        }
        Map map = JSON.parseObject(greenProportionResStr, Map.class);
        Object data = map.get("data");
        if (null == data) {
            log.error("-接口: /greenConsumer/getGreenProportion, data值为NULL");
            return new HashMap<>();
        }
        return JSON.parseObject(JSON.toJSONString(data), new TypeReference<Map<String, Object>>() {});
    }

    /**
     * 新能源发电趋势
     * @return
     */
    @Override
    public List<Map<String, Object>> getHistoryGreenPower() throws IOException {
        String sgccAddress = sgccAddressService.getSgccAddress(ENV_KEY);
        //传空json对象
        Map<String, String> param = new HashMap<>();
        String historyGreenPowerResStr = HttpUtils.sendPostDataByJson(sgccAddress + "/greenConsumer/getHistoryGreenPower", JSON.toJSONString(param), DataPushUtils.createToken(PUBLIC_KEY));
        log.info("-接口: /greenConsumer/getHistoryGreenPower, 调用结果: {}", historyGreenPowerResStr);
        if (StringUtils.isEmpty(historyGreenPowerResStr)) {
            log.error("-接口: /greenConsumer/getHistoryGreenPower, 返回结果为空!");
            return new ArrayList<>();
        }
        Map map = JSON.parseObject(historyGreenPowerResStr, Map.class);
        Object data = map.get("data");
        if (null == data) {
            log.error("-接口: /greenConsumer/getHistoryGreenPower, data值为NULL");
            return new ArrayList<>();
        }
        return JSON.parseObject(JSON.toJSONString(data), new TypeReference<List<Map<String, Object>>>() {});
    }

    /**
     * 新能源参与交易情况
     * @return
     */
    @Override
    public Map<String, Object> getGreenTrade() throws IOException {
        String sgccAddress = sgccAddressService.getSgccAddress(ENV_KEY);
        //传空json对象
        Map<String, String> param = new HashMap<>();
        String greenTradeResStr = HttpUtils.sendPostDataByJson(sgccAddress + "/greenConsumer/getGreenTrade", JSON.toJSONString(param), DataPushUtils.createToken(PUBLIC_KEY));
        log.info("-接口: /greenConsumer/getGreenTrade, 调用结果: {}", greenTradeResStr);
        if (StringUtils.isEmpty(greenTradeResStr)) {
            log.error("-接口: /greenConsumer/getGreenTrade, 返回结果为空!");
            return new HashMap<>();
        }
        Map map = JSON.parseObject(greenTradeResStr, Map.class);
        Object data = map.get("data");
        if (null == data) {
            log.error("-接口: /greenConsumer/getGreenTrade, data值为NULL");
            return new HashMap<>();
        }
        return JSON.parseObject(JSON.toJSONString(data), new TypeReference<Map<String, Object>>() {});
    }
}
