package com.alonginfo.project.gansu.serviceimpl.forward;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.TypeReference;
import com.alonginfo.common.utils.StringUtils;
import com.alonginfo.common.utils.http.HttpUtils;
import com.alonginfo.framework.web.domain.AjaxResult;
import com.alonginfo.project.gansu.service.forward.IInfoDisclosureService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author: HaoXs
 * @Date: 2023/7/6 14:35
 * @Description:
 */
@Service
@Slf4j
public class InfoDisclosureServiceImpl implements IInfoDisclosureService {

    @Value("${sgcc.informationAddress}")
    private String INFORMATION_ADDRESS;

    /**
     * 月度披露数据
     * @return
     */
    @Override
    public List<Object> getMonthInfpubData() {
        //调用交易公告详细信息接口
        String monthResult = HttpUtils.sendPost(INFORMATION_ADDRESS + "/menuStatist/getMonthInfpubData", "", "");
        log.error("获取信息披露-月度披露数据, 接口调用结果 : {}", monthResult);
        if (monthResult == null || "".equals(monthResult)) {
            log.error("获取信息披露-月度披露数据, 接口调用结果为空！");
            return new ArrayList<>();
        }
        Map resultMap = JSON.parseObject(monthResult, Map.class);
        Object data = resultMap.get("data");
        if (null == data) {
            log.error("获取信息披露-月度披露数据, data值为NULL!");
            return new ArrayList<>();
        }
        List<Object> result = JSON.parseObject(JSON.toJSONString(resultMap.get("data")), new TypeReference<List<Object>>() {});
        return result;
    }

    /**
     * 获取累计披露数据
     * @return
     */
    @Override
    public Map<String, Object> getTotalCount() {
        String totalCountRes = HttpUtils.sendPost(INFORMATION_ADDRESS + "/menuStatist/getTotalCount", "", "");
        log.info("获取信息披露-累计披露数据, 接口调用结果: {}", totalCountRes);
        if (StringUtils.isEmpty(totalCountRes)) {
            log.error("获取信息披露-累计披露数据, 接口调用结果为空!");
            return new HashMap<>();
        }
        Map map = JSON.parseObject(totalCountRes, Map.class);
        Object data = map.get("data");
        if (null == data) {
            log.error("获取信息披露-累计披露数据, data值为NULL");
            return new HashMap<>();
        }
        Map<String, Object> result = JSON.parseObject(JSON.toJSONString(data), new TypeReference<Map<String, Object>>() {
        });
        return result;
    }

    /**
     * 年度披露数据
     * @return
     */
    @Override
    public Map<String, Object> getYearInfpubData() {
        String yearInfpubRes = HttpUtils.sendPost(INFORMATION_ADDRESS + "/menuStatist/getYearInfpubData", "", "");
        log.info("获取信息披露-年度披露数据, 接口调用结果: {}", yearInfpubRes);
        if (StringUtils.isEmpty(yearInfpubRes)) {
            log.error("获取信息披露-年度披露数据, 接口调用结果为空!");
            return new HashMap<>();
        }
        Map map = JSON.parseObject(yearInfpubRes, Map.class);
        String data = (String) map.get("data");
        if (null == data) {
            log.error("获取信息披露-年度披露数据, data值为NULL");
            return new HashMap<>();
        }
        Map<String, Object> result = JSON.parseObject(data, new TypeReference<Map<String, Object>>() {
        });
        return result;
    }

    /**
     * 累计披露数据条数及占比
     * @return
     */
    @Override
    public List<Map<String, Object>> getToalInfpubData() {
        String totalInfpubRes = HttpUtils.sendPost(INFORMATION_ADDRESS + "/menuStatist/getToalInfpubData", "", "");
        log.info("获取信息披露-累计披露数据条数及占比, 接口调用结果:{}", totalInfpubRes);
        if (StringUtils.isEmpty(totalInfpubRes)) {
            log.error("获取信息披露-累计披露数据条数及占比, 接口调用结果为空!");
            return new ArrayList<>();
        }
        Map map = JSON.parseObject(totalInfpubRes, Map.class);
        Object data = map.get("data");
        if (null == data) {
            log.error("获取信息披露-累计披露数据条数及占比, data值为NULL");
            return new ArrayList<>();
        }
        List<Map<String, Object>> result = JSON.parseObject(JSON.toJSONString(data), new TypeReference<List<Map<String, Object>>>() {
        });
        return result;
    }
}
