package com.alonginfo.project.gansu.serviceimpl.forward;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.TypeReference;
import com.alonginfo.common.utils.StringUtils;
import com.alonginfo.common.utils.http.HttpUtils;
import com.alonginfo.project.gansu.service.SgccAddressService;
import com.alonginfo.project.gansu.service.forward.ITradeInfoService;
import com.alonginfo.utils.DataPushUtils;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.io.IOException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author: HaoXs
 * @Date: 2023/7/13 16:21
 * @Description:
 */
@Service
@Slf4j
public class TradeInfoServiceImpl implements ITradeInfoService {

    @Value("${env.key}")
    private String ENV_KEY;

    @Value("${sgcc.publicKey}")
    public String PUBLIC_KEY;

    @Autowired
    private SgccAddressService sgccAddressService;

    /**
     * 交易情况总览统计
     * @param yearCode
     * @return
     */
    @Override
    public Map<String, Object> selectTotalTradeInfoByYear(String yearCode) throws IOException {
        String sgccAddress = sgccAddressService.getSgccAddress(ENV_KEY);
        Map<String, String> param = new HashMap<>();
        param.put("yearCode", yearCode);
        String tradeInfoByYearRes = HttpUtils.sendPostDataByJson(sgccAddress + "/tradeInfo/selectTotalTradeInfoByYear", JSON.toJSONString(param), DataPushUtils.createToken(PUBLIC_KEY));
        log.info("-接口: /tradeInfo/selectTotalTradeInfoByYear, 调用结果: {}", tradeInfoByYearRes);
        if (StringUtils.isEmpty(tradeInfoByYearRes)) {
            log.error("-接口: /tradeInfo/selectTotalTradeInfoByYear, 返回结果为空!");
            return new HashMap<>();
        }
        Map map = JSON.parseObject(tradeInfoByYearRes, Map.class);
        Object data = map.get("data");
        if (null == data) {
            log.error("-接口: /tradeInfo/selectTotalTradeInfoByYear, data值为NULL!");
            return new HashMap<>();
        }
        return JSON.parseObject(JSON.toJSONString(data), new TypeReference<Map<String, Object>>(){});
    }

    /**
     * 各类型交易组织情况
     * @param yearCode
     * @return
     */
    @Override
    public List<Map<String, Object>> selectTradeDetailByType(String yearCode) throws IOException {
        String sgccAddress = sgccAddressService.getSgccAddress(ENV_KEY);
        Map<String, String> param = new HashMap<>();
        param.put("yearCode", yearCode);
        String tradeDetailRes = HttpUtils.sendPostDataByJson(sgccAddress + "/tradeInfo/selectTradeDetailByType", JSON.toJSONString(param), DataPushUtils.createToken(PUBLIC_KEY));
        log.info("-接口: /tradeInfo/selectTradeDetailByType, 调用结果: {}", tradeDetailRes);
        if (StringUtils.isEmpty(tradeDetailRes)) {
            log.error("-接口: /tradeInfo/selectTradeDetailByType, 返回结果为空!");
            return new ArrayList<>();
        }
        Map map = JSON.parseObject(tradeDetailRes, Map.class);
        Object data = map.get("data");
        if (null == data) {
            log.error("-接口: /tradeInfo/selectTradeDetailByType, data值为NULL!");
            return new ArrayList<>();
        }
        return JSON.parseObject(JSON.toJSONString(data), new TypeReference<List<Map<String, Object>>>(){});
    }

    /**
     * 各类市场主体参与市场情况
     * @param yearCode
     * @return
     */
    @Override
    public Map<String, Object> selectMarketMemberNumByType(String yearCode) throws IOException {
        String sgccAddress = sgccAddressService.getSgccAddress(ENV_KEY);
        Map<String, String> param = new HashMap<>();
        param.put("yearCode", yearCode);
        String marketMemberNumRes = HttpUtils.sendPostDataByJson(sgccAddress + "/tradeInfo/selectMarketMemberNumByType", JSON.toJSONString(param), DataPushUtils.createToken(PUBLIC_KEY));
        log.info("-接口: /tradeInfo/selectMarketMemberNumByType, 调用结果: {}", marketMemberNumRes);
        if (StringUtils.isEmpty(marketMemberNumRes)) {
            log.error("-接口: /tradeInfo/selectMarketMemberNumByType, 返回结果为空!");
            return new HashMap<>();
        }
        Map map = JSON.parseObject(marketMemberNumRes, Map.class);
        Object data = map.get("data");
        if (null == data) {
            log.error("-接口: /tradeInfo/selectMarketMemberNumByType, data值为NULL!");
            return new HashMap<>();
        }
        return JSON.parseObject(JSON.toJSONString(data), new TypeReference<Map<String, Object>>(){});
    }

    /**
     * 历年直接交易规模
     * @param
     * @return
     */
    @Override
    public List<Map<String, Object>> selectDirectTradeByType() throws IOException {
        String sgccAddress = sgccAddressService.getSgccAddress(ENV_KEY);
        String directTradeResStr = HttpUtils.sendPost(sgccAddress + "/tradeInfo/selectDirectTradeByType", "", DataPushUtils.createToken(PUBLIC_KEY));
        log.info("-接口: /tradeInfo/selectDirectTradeByType, 调用结果: {}", directTradeResStr);
        if (StringUtils.isEmpty(directTradeResStr)) {
            log.error("-接口: /tradeInfo/selectDirectTradeByType, 返回结果为空!");
            return new ArrayList<>();
        }
        Map map = JSON.parseObject(directTradeResStr, Map.class);
        Object data = map.get("data");
        if (null == data) {
            log.error("-接口: /tradeInfo/selectDirectTradeByType, data值为NULL!");
            return new ArrayList<>();
        }
        return JSON.parseObject(JSON.toJSONString(data), new TypeReference<List<Map<String, Object>>>(){});
    }

    /**
     * 各地市市场主体情况
     * @return
     */
    @Override
    public List<Map<String, Object>> selectTradeCityMemberResult(String yearCode) throws IOException {
        String sgccAddress = sgccAddressService.getSgccAddress(ENV_KEY);
        Map<String, String> param = new HashMap<>();
        param.put("yearCode", yearCode);
        String cityMemberResStr = HttpUtils.sendPostDataByJson(sgccAddress + "/tradeInfo/selectTradeCityMemberResult", JSON.toJSONString(param), DataPushUtils.createToken(PUBLIC_KEY));
        log.info("-接口: /tradeInfo/selectTradeCityMemberResult, 调用结果: {}", cityMemberResStr);
        if (StringUtils.isEmpty(cityMemberResStr)) {
            log.error("-接口: /tradeInfo/selectTradeCityMemberResult, 返回结果为空!");
            return new ArrayList<>();
        }
        Map map = JSON.parseObject(cityMemberResStr, Map.class);
        Object data = map.get("data");
        if (null == data) {
            log.error("-接口: /tradeInfo/selectTradeCityMemberResult, data值为NULL!");
            return new ArrayList<>();
        }
        return JSON.parseObject(JSON.toJSONString(data), new TypeReference<List<Map<String, Object>>>(){});
    }

    /**
     * 历年省内交易均价交易电量
     * @return
     */
    @Override
    public List<Map<String, Object>> selectAvgPriceEnergyByYearResult() throws IOException {
        String sgccAddress = sgccAddressService.getSgccAddress(ENV_KEY);
        String avgPriceEnergyByYearResStr = HttpUtils.sendPostDataByJson(sgccAddress + "/tradeInfo/selectAvgPriceEnergyByYearResult", "", DataPushUtils.createToken(PUBLIC_KEY));
        log.info("-接口: /tradeInfo/selectAvgPriceEnergyByYearResult, 调用结果: {}", avgPriceEnergyByYearResStr);
        if (StringUtils.isEmpty(avgPriceEnergyByYearResStr)) {
            log.error("-接口: /tradeInfo/selectAvgPriceEnergyByYearResult, 返回结果为空!");
            return new ArrayList<>();
        }
        Map map = JSON.parseObject(avgPriceEnergyByYearResStr, Map.class);
        Object data = map.get("data");
        if (null == data) {
            log.error("-接口: /tradeInfo/selectAvgPriceEnergyByYearResult, data值为NULL!");
            return new ArrayList<>();
        }
        return JSON.parseObject(JSON.toJSONString(data), new TypeReference<List<Map<String, Object>>>(){});
    }

    /**
     * 历年省间外送交易均价交易电量
     * @return
     */
    @Override
    public List<Map<String, Object>> selectOutSendAvgPriceEnergyByYearResult() throws IOException {
        String sgccAddress = sgccAddressService.getSgccAddress(ENV_KEY);
        String outSendAvgPriceResStr = HttpUtils.sendPostDataByJson(sgccAddress + "/tradeInfo/selectOutSendAvgPriceEnergyByYearResult", "", DataPushUtils.createToken(PUBLIC_KEY));
        log.info("-接口: /tradeInfo/selectOutSendAvgPriceEnergyByYearResult, 调用结果: {}", outSendAvgPriceResStr);
        if (StringUtils.isEmpty(outSendAvgPriceResStr)) {
            log.error("-接口: /tradeInfo/selectOutSendAvgPriceEnergyByYearResult, 返回结果为空!");
            return new ArrayList<>();
        }
        Map map = JSON.parseObject(outSendAvgPriceResStr, Map.class);
        Object data = map.get("data");
        if (null == data) {
            log.error("-接口: /tradeInfo/selectOutSendAvgPriceEnergyByYearResult, data值为NULL!");
            return new ArrayList<>();
        }
        return JSON.parseObject(JSON.toJSONString(data), new TypeReference<List<Map<String, Object>>>(){});
    }

    /**
     * 省间外送历年水火风光电量
     * @return
     */
    @Override
    public List<Map<String, Object>> selectTradeEnergyPowerTypeResult() throws IOException {
        String sgccAddress = sgccAddressService.getSgccAddress(ENV_KEY);
        String energyPowerTypeRes = HttpUtils.sendPostDataByJson(sgccAddress + "/tradeInfo/selectTradeEnergyPowerTypeResult", "", DataPushUtils.createToken(PUBLIC_KEY));
        log.info("-接口: /tradeInfo/selectTradeEnergyPowerTypeResult, 调用结果: {}", energyPowerTypeRes);
        if (StringUtils.isEmpty(energyPowerTypeRes)) {
            log.error("-接口: /tradeInfo/selectTradeEnergyPowerTypeResult, 返回结果为空!");
            return new ArrayList<>();
        }
        Map map = JSON.parseObject(energyPowerTypeRes, Map.class);
        Object data = map.get("data");
        if (null == data) {
            log.error("-接口: /tradeInfo/selectTradeEnergyPowerTypeResult, data值为NULL!");
            return new ArrayList<>();
        }
        return JSON.parseObject(JSON.toJSONString(data), new TypeReference<List<Map<String, Object>>>(){});
    }



}
