package com.alonginfo.project.gansu.serviceimpl.forward;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.TypeReference;
import com.alonginfo.common.utils.http.HttpUtils;
import com.alonginfo.project.gansu.service.SgccAddressService;
import com.alonginfo.project.gansu.service.forward.ITradeMarketInfoService;
import com.alonginfo.utils.DataPushUtils;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

import java.io.IOException;
import java.util.HashMap;
import java.util.Map;

/**
 * @author: HaoXs
 * @Date: 2023/7/7 16:52
 * @Description:
 */
@Service
@Slf4j
public class TradeMarketInfoServiceImpl implements ITradeMarketInfoService {

    @Value("${env.key}")
    private String ENV_KEY;

    @Value("${sgcc.publicKey}")
    private String publicKey;

    @Autowired
    private SgccAddressService sgccAddressService;

    /**
     * (接口调用)当年市场化电量累计执行情况
     * @return
     */
    @Override
    public Map<String, Object> selectTradeEnergyRatio(String yearCode) throws IOException {
        String sgccAddress = sgccAddressService.getSgccAddress(ENV_KEY);
        Map<String, String> param = new HashMap<>();
        param.put("yearCode", yearCode);
        String tradeEnergyRatioRes = HttpUtils.sendPostDataByJson(sgccAddress + "/tradeMarketInfo/selectTradeEnergyRatio", JSON.toJSONString(param), DataPushUtils.createToken(publicKey));
        log.info("-市场概览-当年市场化电量累计执行情况, 接口调用结果: {}", tradeEnergyRatioRes);
        if (StringUtils.isEmpty(tradeEnergyRatioRes)) {
            log.error("-市场概览-当年市场化电量累计执行情况, 接口返回为空!");
            return new HashMap<>();
        }
        Map map = JSON.parseObject(tradeEnergyRatioRes, Map.class);
        Object data = map.get("data");
        if (null == data) {
            log.error("-市场概览-当年市场化电量累计执行情况, data为NULL");
            return new HashMap<>();
        }
        return JSON.parseObject(JSON.toJSONString(data), new TypeReference<Map<String, Object>>() {});
    }

    /**
     * (接口调用)市场概览-顶部发电数据
     * @param yearCode
     * @return
     */
    @Override
    public Map<String, Object> selectGeneratePowerDataByYear(String yearCode) throws IOException {
        String sgccAddress = sgccAddressService.getSgccAddress(ENV_KEY);
        Map<String, String> param = new HashMap<>();
        param.put("caliber", "0");
        param.put("yearCode", yearCode);
        String generatePowerRes = HttpUtils.sendPostDataByJson(sgccAddress + "/tradeMarketInfo/selectGeneratePowerDataByYear", JSON.toJSONString(param), DataPushUtils.createToken(publicKey));
        log.info("-市场概览-发电数据, 接口调用结果: {}", generatePowerRes);
        if (StringUtils.isEmpty(generatePowerRes)) {
            log.error("-市场概览-发电数据, 接口返回为空!");
            return new HashMap<>();
        }
        Map map = JSON.parseObject(generatePowerRes, Map.class);
        Object data = map.get("data");
        if (null == data) {
            log.error("-市场概览-发电数据, data为NULL");
            return new HashMap<>();
        }
        return JSON.parseObject(JSON.toJSONString(data), new TypeReference<Map<String, Object>>() {});
    }

    /**
     * (接口调用)当年交易量价走势
     * @param yearCode
     * @return
     */
    @Override
    public Map<String, Object> selectTradePowerAvgPriceResult(String yearCode) throws IOException {
        String sgccAddress = sgccAddressService.getSgccAddress(ENV_KEY);
        Map<String, String> param = new HashMap<>();
        param.put("yearCode", yearCode);
        param.put("tradeType", "1");
        String powerPriceRes = HttpUtils.sendPostDataByJson(sgccAddress + "/tradeMarketInfo/selectTradePowerAvgPriceResult", JSON.toJSONString(param), DataPushUtils.createToken(publicKey));
        log.info("-市场概览-当年交易量价走势, 接口调用结果: {}", powerPriceRes);
        if (StringUtils.isEmpty(powerPriceRes)) {
            log.error("-市场概览-当年交易量价走势, 接口返回为空!");
            return new HashMap<>();
        }
        Map map = JSON.parseObject(powerPriceRes, Map.class);
        Object data = map.get("data");
        if (null == data) {
            log.error("-市场概览-当年交易量价走势, data为NULL");
            return new HashMap<>();
        }
        return JSON.parseObject(JSON.toJSONString(data), new TypeReference<Map<String, Object>>() {});
    }

    /**
     * (接口调用)发电装机情况与利用小时数
     * @return
     */
    @Override
    public Map<String, Object> selectGeneratorCapacity(String yearCode) throws IOException {
        String sgccAddress = sgccAddressService.getSgccAddress(ENV_KEY);
        Map<String, String> param = new HashMap<>();
        param.put("yearCode", yearCode);
        param.put("caliber", "1");
        String generatorCapacityRes = HttpUtils.sendPostDataByJson(sgccAddress + "/tradeMarketInfo/selectGeneratorCapacity", JSON.toJSONString(param), DataPushUtils.createToken(publicKey));
        log.info("-市场概览-发电装机情况与利用小时数, 接口调用结果: {}", generatorCapacityRes);
        if (StringUtils.isEmpty(generatorCapacityRes)) {
            log.error("-市场概览-发电装机情况与利用小时数, 接口返回为空!");
            return new HashMap<>();
        }
        Map map = JSON.parseObject(generatorCapacityRes, Map.class);
        Object data = map.get("data");
        if (null == data) {
            log.error("-市场概览-发电装机情况与利用小时数, data为NULL");
            return new HashMap<>();
        }
        return JSON.parseObject(JSON.toJSONString(data), new TypeReference<Map<String, Object>>() {});
    }

    /**
     * (接口调用)各类型资源装机容量与发电量
     * @param yearCode
     * @return
     */
    @Override
    public Map<String, Object> selectResourceCapacity(String yearCode) throws IOException {
        String sgccAddress = sgccAddressService.getSgccAddress(ENV_KEY);
        Map<String, String> param = new HashMap<>();
        param.put("yearCode", yearCode);
        String resourceCapacityRes = HttpUtils.sendPostDataByJson(sgccAddress + "/tradeMarketInfo/selectResourceCapacity", JSON.toJSONString(param), DataPushUtils.createToken(publicKey));
        log.info("-市场概览-各类型资源装机容量与发电量, 接口调用结果: {}", resourceCapacityRes);
        if (StringUtils.isEmpty(resourceCapacityRes)) {
            log.error("-市场概览-各类型资源装机容量与发电量, 接口返回为空!");
            return new HashMap<>();
        }
        Map map = JSON.parseObject(resourceCapacityRes, Map.class);
        Object data = map.get("data");
        if (null == data) {
            log.error("-市场概览-各类型资源装机容量与发电量, data为NULL");
            return new HashMap<>();
        }
        return JSON.parseObject(JSON.toJSONString(data), new TypeReference<Map<String, Object>>() {});
    }

    /**
     * (接口调用)当年发电情况统计
     * @param yearCode
     * @return
     */
    @Override
    public Map<String, Object> selectResourceDevDataList(String yearCode) throws IOException {
        String sgccAddress = sgccAddressService.getSgccAddress(ENV_KEY);
        Map<String, String> param = new HashMap<>();
        param.put("yearCode", yearCode);
        param.put("resourceType", "1");
        String resourceDevDataRes = HttpUtils.sendPostDataByJson(sgccAddress + "/tradeMarketInfo/selectResourceDevDataList", JSON.toJSONString(param), DataPushUtils.createToken(publicKey));
        log.info("-市场概览-当年发电情况统计, 接口调用结果: {}", resourceDevDataRes);
        if (StringUtils.isEmpty(resourceDevDataRes)) {
            log.error("-市场概览-当年发电情况统计, 接口返回为空!");
            return new HashMap<>();
        }
        Map map = JSON.parseObject(resourceDevDataRes, Map.class);
        Object data = map.get("data");
        if (null == data) {
            log.error("-市场概览-当年发电情况统计, data为NULL");
            return new HashMap<>();
        }
        return JSON.parseObject(JSON.toJSONString(data), new TypeReference<Map<String, Object>>() {});
    }

    /**
     * 查询当年电力用户交易量价情况
     * @return
     */
    @Override
    public Map<String, Object> selectUserSumEnergyAvgPrice() {
        String sgccAddress = sgccAddressService.getSgccAddress(ENV_KEY);
        String userSumEnergyAvgPriceResStr = HttpUtils.sendPost(sgccAddress + "/tradeMarketInfo/selectUserSumEnergyAvgPrice", "", DataPushUtils.createToken(publicKey));
        log.info("-当年电力用户交易量价情况, 接口调用结果: {}", userSumEnergyAvgPriceResStr);
        if (StringUtils.isEmpty(userSumEnergyAvgPriceResStr)) {
            log.error("-当年电力用户交易量价情况, 接口返回为空!");
            return new HashMap<>();
        }
        Map map = JSONObject.parseObject(userSumEnergyAvgPriceResStr, Map.class);
        Object data = map.get("data");
        if (null == data) {
            log.error("-当年电力用户交易量价情况, data为NULL!");
            return new HashMap<>();
        }
        return JSON.parseObject(JSON.toJSONString(data), new TypeReference<Map<String, Object>>(){});
    }

    /**
     * 当年发电企业交易量价情况数据
     * @return
     */
    @Override
    public Map<String, Object> selectEnterpriseSumEnergyAvgPrice() {
        String sgccAddress = sgccAddressService.getSgccAddress(ENV_KEY);
        String enterpriseSumResStr = HttpUtils.sendPost(sgccAddress + "/tradeMarketInfo/selectEnterpriseSumEnergyAvgPrice", "", DataPushUtils.createToken(publicKey));
        log.info("-当年发电企业交易量价情况数据, 接口调用结果: {}", enterpriseSumResStr);
        if (StringUtils.isEmpty(enterpriseSumResStr)) {
            log.error("-当年发电企业交易量价情况数据, 接口返回为空!");
            return new HashMap<>();
        }
        Map map = JSONObject.parseObject(enterpriseSumResStr, Map.class);
        Object data = map.get("data");
        if (null == data) {
            log.error("-当年发电企业交易量价情况数据, data为NULL!");
            return new HashMap<>();
        }
        return JSON.parseObject(JSON.toJSONString(data), new TypeReference<Map<String, Object>>(){});
    }
}
