package com.alonginfo.project.gansu.serviceimpl.forward;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.TypeReference;
import com.alonginfo.common.utils.StringUtils;
import com.alonginfo.common.utils.http.HttpUtils;
import com.alonginfo.project.gansu.service.SgccAddressService;
import com.alonginfo.project.gansu.service.forward.TransactionPowerService;
import com.alonginfo.utils.DataPushUtils;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.util.*;

/**
 * TransactionPowerServiceImpl
 *
 * @package_name： com.alonginfo.project.gansu.serviceimpl.forward
 * @author： 樊群靖
 * @date： 2023/8/9
 * @description:
 **/
@Service
@Slf4j

public class TransactionPowerServiceImpl implements TransactionPowerService {

    @Value("${env.key}")
    private String ENV_KEY;

    @Value("${sgcc.publicKey}")
    public String PUBLIC_KEY;

    @Autowired
    private SgccAddressService sgccAddressService;

    @Override
    public List<Map<String, Object>> selectDirectPowerList() {
        String sgccAddress = sgccAddressService.getSgccAddress(ENV_KEY);
        String directPowerListRes = HttpUtils.sendPost(sgccAddress + "/transactionPowerController/selectDirectPowerList", "", DataPushUtils.createToken(PUBLIC_KEY));
        log.info("-接口: /transactionPowerController/selectDirectPowerList, 调用结果: {}", directPowerListRes);
        if(StringUtils.isEmpty(directPowerListRes)) {
            log.error("-接口: /transactionPowerController/selectDirectPowerList, 返回结果为空!");
            return new ArrayList<>();
        }
        Map map = JSON.parseObject(directPowerListRes, Map.class);
        Object data = map.get("data");
        if (null == data) {
            log.error("-接口: /transactionPowerController/selectDirectPowerList, data值为NULL");
            return new ArrayList<>();
        }
        return JSON.parseObject(JSON.toJSONString(data), new TypeReference<List<Map<String, Object>>>(){});
    }

    @Override
    public List<Map<String, Object>> selectGenerationRightPowerList() {
        String sgccAddress = sgccAddressService.getSgccAddress(ENV_KEY);
        String generationRightPowerListRes = HttpUtils.sendPost(sgccAddress + "/transactionPowerController/selectGenerationRightPowerList", "", DataPushUtils.createToken(PUBLIC_KEY));
        log.info("-接口: /transactionPowerController/selectGenerationRightPowerList, 调用结果: {}", generationRightPowerListRes);
        if(StringUtils.isEmpty(generationRightPowerListRes)) {
            log.error("-接口: /transactionPowerController/selectGenerationRightPowerList, 返回结果为空!");
            return new ArrayList<>();
        }
        Map map = JSON.parseObject(generationRightPowerListRes, Map.class);
        Object data = map.get("data");
        if (null == data) {
            log.error("-接口: /transactionPowerController/selectGenerationRightPowerList, data值为NULL");
            return new ArrayList<>();
        }
        return JSON.parseObject(JSON.toJSONString(data), new TypeReference<List<Map<String, Object>>>(){});
    }

    @Override
    public List<Map<String, Object>> selectPowerList() {
        String sgccAddress = sgccAddressService.getSgccAddress(ENV_KEY);
        String powerListRes = HttpUtils.sendPost(sgccAddress + "/transactionPowerController/selectPowerList", "", DataPushUtils.createToken(PUBLIC_KEY));
        log.info("-接口: /transactionPowerController/selectPowerList, 调用结果: {}", powerListRes);
        if(StringUtils.isEmpty(powerListRes)) {
            log.error("-接口: /transactionPowerController/selectPowerList, 返回结果为空!");
            return new ArrayList<>();
        }
        Map map = JSON.parseObject(powerListRes, Map.class);
        Object data = map.get("data");
        if (null == data) {
            log.error("-接口: /transactionPowerController/selectPowerList, data值为NULL");
            return new ArrayList<>();
        }
        return JSON.parseObject(JSON.toJSONString(data), new TypeReference<List<Map<String, Object>>>(){});
    }

    @Override
    public Map<String, Object> transactionInTheProvince() {
        String sgccAddress = sgccAddressService.getSgccAddress(ENV_KEY);
        String transactionInTheProvinceResStr = HttpUtils.sendPost(sgccAddress + "/transactionPowerController/transactionInTheProvince", "", DataPushUtils.createToken(PUBLIC_KEY));
        log.info("-接口: /transactionPowerController/transactionInTheProvince, 调用结果: {}", transactionInTheProvinceResStr);
        if(StringUtils.isEmpty(transactionInTheProvinceResStr)) {
            log.error("-接口: /transactionPowerController/transactionInTheProvince, 返回结果为空!");
            return new HashMap<>();
        }
        Map map = JSON.parseObject(transactionInTheProvinceResStr, Map.class);
        Object data = map.get("data");
        if (Objects.isNull(data)) {
            log.error("-接口: /transactionPowerController/transactionInTheProvince, data值为NULL");
            return new HashMap<>();
        }
        return JSON.parseObject(JSON.toJSONString(data), new TypeReference<Map<String, Object>>(){});
    }

    @Override
    public Map<String, Object> abschluss() {
        String sgccAddress = sgccAddressService.getSgccAddress(ENV_KEY);
        String abschlussResStr = HttpUtils.sendPost(sgccAddress + "/transactionPowerController/abschluss", "", DataPushUtils.createToken(PUBLIC_KEY));
        log.info("-接口: /transactionPowerController/abschluss, 调用结果: {}", abschlussResStr);
        if(StringUtils.isEmpty(abschlussResStr)) {
            log.error("-接口: /transactionPowerController/abschluss, 返回结果为空!");
            return new HashMap<>();
        }
        Map map = JSON.parseObject(abschlussResStr, Map.class);
        Object data = map.get("data");
        if (Objects.isNull(data)) {
            log.error("-接口: /transactionPowerController/abschluss, data值为NULL");
            return new HashMap<>();
        }
        return JSON.parseObject(JSON.toJSONString(data), new TypeReference<Map<String, Object>>(){});
    }
}
