package com.alonginfo.project.gansu.serviceimpl.generation;

import com.alonginfo.common.utils.StringUtils;
import com.alonginfo.project.gansu.domain.*;
import com.alonginfo.project.gansu.mapper.GenerationRightMapper;
import com.alonginfo.project.gansu.service.generation.IGenerationRightService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.*;

/**
 * @author: HaoXs
 * @Date: 2023/5/17 15:13
 * @Description:  发电权交易情况 业务层实现
 */
@Service
public class GenerationRightServiceImpl implements IGenerationRightService {

    @Autowired
    private GenerationRightMapper generationRightMapper;

    /**
     * (同步数据)当年发电权交易组织情况
     * @return
     */
    @Override
    public DealOrganizeDTO getDealOrganize() {
        Map<String, String> dealOrganize = generationRightMapper.getDealOrganize();
        DealOrganizeDTO dealOrganizeDTO = new DealOrganizeDTO();
        if (StringUtils.isNotEmpty(dealOrganize)) {
            dealOrganizeDTO.setDealNum(dealOrganize.get("dealNum"));
            dealOrganizeDTO.setDealNumPer(dealOrganize.get("dealNumPer"));
            dealOrganizeDTO.setDealEnergy(dealOrganize.get("dealEnergy"));
            dealOrganizeDTO.setDealEnergyPer(dealOrganize.get("dealEnergyPer"));
            dealOrganizeDTO.setPowerCount(dealOrganize.get("powerCount"));
            dealOrganizeDTO.setPowerCountPer(dealOrganize.get("powerCountPer"));
        }
        return dealOrganizeDTO;
    }

    /**
     * (同步数据)当年发电权交易市场主体参与情况
     * @return
     */
    @Override
    public SubjectJoinDTO getSubjectJoin() {
        Map<String, String> subjectJoin = generationRightMapper.getSubjectJoin();

        SubjectJoinDTO subjectJoinDTO = new SubjectJoinDTO();
        if (StringUtils.isNotEmpty(subjectJoin)) {
            subjectJoinDTO.setParticipantCount(subjectJoin.get("participantCount"));
            subjectJoinDTO.setVendeeParticipantCount(subjectJoin.get("vendeeParticipantCount"));
            subjectJoinDTO.setSaleParticipantCount(subjectJoin.get("saleParticipantCount"));
        }
        return subjectJoinDTO;
    }

    /**
     * (同步数据)买入、卖出电量企业排名
     * @return
     */
    @Override
    public List<SaleBuyEnterpriseOrderDTO> getSaleBuyOrder(String type) {
        List<Map<String, String>> saleBuyOrder = generationRightMapper.getSaleBuyOrder(type);

        List<SaleBuyEnterpriseOrderDTO> result = new ArrayList<>();
        if (StringUtils.isNotEmpty(saleBuyOrder)) {
            saleBuyOrder.forEach(order -> {
                SaleBuyEnterpriseOrderDTO saleBuyEnterpriseOrderDTO = new SaleBuyEnterpriseOrderDTO();
                saleBuyEnterpriseOrderDTO.setEnergy(order.get("energy"));
                saleBuyEnterpriseOrderDTO.setParticipantName(order.get("participantName"));
                result.add(saleBuyEnterpriseOrderDTO);
            });
        }
        return result;
    }

    /**
     * (同步数据)历年发电权交易电量趋势
     * @return
     */
    @Override
    public PowerByYearDTO getPowerByYear() {
        List<Map<String, String>> powerByYear = generationRightMapper.getPowerByYear();

        List<String> xAxis = new LinkedList<>();
        //交易电量
        List<String> tradePower = new LinkedList<>();
        //结算电量
        //TODO 目前还没该字段  预留
        List<String> settlementPower = new LinkedList<>();
        if (StringUtils.isNotEmpty(powerByYear)) {
            for (Map<String, String> power : powerByYear) {
                xAxis.add(power.get("year"));
                tradePower.add(power.get("energy"));
                settlementPower.add(power.get("settlement"));
            }
        }

        PowerByYearDTO powerByYearDTO = new PowerByYearDTO();
        powerByYearDTO.setXAxisData(xAxis);
        powerByYearDTO.setSeriesData(new ArrayList<Map<String, Object>>(){{
            add(new HashMap<String, Object>(){{
                put("name", "交易电量");
                put("data", tradePower);
            }});
            add(new HashMap<String, Object>(){{
                put("name", "结算电量");
                put("data", settlementPower);
            }});
        }});
        return powerByYearDTO;
    }

    /**
     * (同步数据)当年分月 发电权交易电量趋势
     * @return
     */
    @Override
    public PowerByYearMonthDTO getPowerByYearMonth() {
        List<Map<String, String>> powerByYearMonth = generationRightMapper.getPowerByYearMonth();

        List<String> xAxis = new LinkedList<>();
        //交易电量
        List<String> tradePower = new LinkedList<>();
        //结算电量
        //TODO 目前还没该字段  预留
        List<String> settlementPower = new LinkedList<>();
        if (StringUtils.isNotEmpty(powerByYearMonth)) {
            for (Map<String, String> power : powerByYearMonth) {
                //01 -> 1月
                xAxis.add(Integer.parseInt(power.get("yearMonth")) < 10 ? power.get("yearMonth").charAt(1)+"月" : power.get("yearMonth")+"月");
                tradePower.add(power.get("energy"));
                settlementPower.add(power.get("settlement"));
            }
        }

        PowerByYearMonthDTO powerByYearMonthDTO = new PowerByYearMonthDTO();
        powerByYearMonthDTO.setXAxisData(xAxis);
        powerByYearMonthDTO.setSeriesData(new ArrayList<Map<String, Object>>(){{
            add(new HashMap<String, Object>(){{
                put("name", "交易电量");
                put("data", tradePower);
            }});
            add(new HashMap<String, Object>(){{
                put("name", "结算电量");
                put("data", settlementPower);
            }});
        }});
        return powerByYearMonthDTO;
    }
}
