package com.alonginfo.project.gansu.serviceimpl.green;

import com.alonginfo.common.utils.StringUtils;
import com.alonginfo.project.gansu.domain.GreenSyndromeTradeByYearDTO;
import com.alonginfo.project.gansu.domain.GreenTradeInfoDTO;
import com.alonginfo.project.gansu.mapper.GreenTradeMapper;
import com.alonginfo.project.gansu.service.green.IGreenTradeService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

import java.util.*;

/**
 * @author: HaoXs
 * @Date: 2023/6/19 16:48
 * @Description: 绿证绿电交易情况
 */
@Service
public class GreenTradeServiceImpl implements IGreenTradeService {

    @Autowired
    private GreenTradeMapper greenTradeMapper;

    /**
     * 绿证绿电交易电量、均价
     * @return
     */
    @Override
    public GreenTradeInfoDTO getGreenTradeInfo() {
        Map<String, String> tradeInfo = greenTradeMapper.queryGreenTradeInfo();
        if (StringUtils.isEmpty(tradeInfo)) {
            return new GreenTradeInfoDTO();
        }
        return GreenTradeInfoDTO.builder()
                .snlddl(tradeInfo.get("innerTradeValue"))
                .snldjj(tradeInfo.get("innerTradePrice"))
                .kqlvdl(tradeInfo.get("spannedTradeValue"))
                .kqlvjj(tradeInfo.get("spannedTradePrice"))
                .lzjydl(tradeInfo.get("syndromeTrdaeValueTop"))
                .lzjyjj(tradeInfo.get("syndromeTradePriceTop"))
                .lzjydl1(tradeInfo.get("syndromeTradeValueDown"))
                .lzjyjj1(tradeInfo.get("syndromeTradePriceDown")).build();
    }

    /**
     * 历年绿证市场交易情况
     * @return
     */
    @Override
    public GreenSyndromeTradeByYearDTO greenSyndromeTradeByYear() {
        List<Map<String, String>> greenSyndromeTrades = greenTradeMapper.queryGreenSyndromeTradeByYear();
        if (CollectionUtils.isEmpty(greenSyndromeTrades)){
            return new GreenSyndromeTradeByYearDTO();
        }
        List<String> xAxis = new LinkedList<>();
        List<String> tradeNumList = new LinkedList<>();
        List<String> tradePriceList = new LinkedList<>();
        for (Map<String, String> greenSyndromeTrade : greenSyndromeTrades) {
            String dataYear = Optional.ofNullable(greenSyndromeTrade.get("dataYear")).orElse("");
            String tradeNum = Optional.ofNullable(greenSyndromeTrade.get("tradeNum")).orElse("0");
            String tradePrice = Optional.ofNullable(greenSyndromeTrade.get("tradePrice")).orElse("0");
            xAxis.add(dataYear);
            tradeNumList.add(tradeNum);
            tradePriceList.add(tradePrice);
        }
        GreenSyndromeTradeByYearDTO greenSyndrome = new GreenSyndromeTradeByYearDTO();
        greenSyndrome.setXAxis(xAxis);
        greenSyndrome.setGreenTradeNum(tradeNumList);
        greenSyndrome.setGreenTradePrice(tradePriceList);
        return greenSyndrome;
    }
}
