package com.alonginfo.project.gansu.serviceimpl.grid;

import com.alonginfo.common.utils.StringUtils;
import com.alonginfo.project.gansu.domain.LineCapacityDTO;
import com.alonginfo.project.gansu.domain.LineTransportDTO;
import com.alonginfo.project.gansu.domain.TextBoxVO;
import com.alonginfo.project.gansu.domain.TransformerInfoVO;
import com.alonginfo.project.gansu.mapper.GridMapper;
import com.alonginfo.project.gansu.service.grid.IGridService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * @author: HaoXs
 * @Date: 2023/6/13 10:19
 * @Description: 甘肃网架图
 */
@Service
public class GridServiceImpl implements IGridService {

    @Autowired
    private GridMapper gridMapper;

    /**
     * 左下角文本框数据
     * @return
     */
    @Override
    public TextBoxVO getTextBoxData() {
        return gridMapper.getTextBoxData();
    }

    /**
     * 变电站信息
     * @return
     */
    @Override
    public List<TransformerInfoVO> getTransformerInfo() {
        List<TransformerInfoVO> transformerInfoList = gridMapper.queryTransformerInfo();
        if(StringUtils.isEmpty(transformerInfoList)) {
            return new ArrayList<>();
        }
        return transformerInfoList;
    }

    /**
     * 各线路输送电量分析
     * @return
     */
    @Override
    public LineTransportDTO getLineTransport() {
        List<Map<String, String>> lineTransportList = gridMapper.queryLineTransport();
        if (StringUtils.isEmpty(lineTransportList)) {
            return new LineTransportDTO();
        }
        List<String> lines = new ArrayList<>();
        List<String> clearEnergyList = new ArrayList<>();
        List<String> fireEnergyList = new ArrayList<>();
        for (Map<String, String> line : lineTransportList) {
            lines.add(line.get("lineName"));
            clearEnergyList.add(line.get("clearEnergy"));
            fireEnergyList.add(line.get("fireEnergy"));
        }

        LineTransportDTO result = new LineTransportDTO();
        result.setXData(lines);
        result.setQjny(clearEnergyList);
        result.setHd(fireEnergyList);
        return result;
    }

    /**
     * 各线路整体容量情况
     * @return
     */
    @Override
    public LineCapacityDTO getLineCapacity() {
        List<Map<String, String>> lineCapacityList = gridMapper.queryLineCapacity();
        if (StringUtils.isEmpty(lineCapacityList)) {
            return new LineCapacityDTO();
        }
        List<String> lines = new ArrayList<>();
        List<String> capacityList = new ArrayList<>();
        for (Map<String, String> line : lineCapacityList) {
            lines.add(line.get("lineName"));
            capacityList.add(line.get("capacity"));
        }

        LineCapacityDTO result = new LineCapacityDTO();
        result.setXAxisData(lines);
        result.setSeriesData(capacityList);
        return result;
    }
}
