package com.alonginfo.project.gansu.serviceimpl.mltermcontract;

import com.alonginfo.common.utils.StringUtils;
import com.alonginfo.project.gansu.domain.common.EchartsCommonDTO;
import com.alonginfo.project.gansu.domain.SupplyTypeDTO;
import com.alonginfo.project.gansu.domain.TypePowerDTO;
import com.alonginfo.project.gansu.domain.TypePowerVo;
import com.alonginfo.project.gansu.domain.OutsideDeliverDTO;
import com.alonginfo.project.gansu.mapper.MediumLongTermContractMapper;
import com.alonginfo.project.gansu.service.mltermcontract.IMediumLongTermContractService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;

/**
 * @author: HaoXs
 * @Date: 2023/5/19 11:50
 * @Description: 中长期合同签订情况 业务层实现
 */
@Service
public class MediumLongTermContractServiceImpl implements IMediumLongTermContractService {

    @Autowired
    private MediumLongTermContractMapper mediumLongTermContractMapper;

    /**
     * (同步数据)中长期省内交易品种及电量
     * @return
     */
    @Override
    public TypePowerDTO getTypePower() {
        List<TypePowerVo> typePowerList = mediumLongTermContractMapper.getTypePower();
        String directElectric = null;
        String proxyElectric = null;
        String greenElectric = null;
        String countElectric = null;
        if (StringUtils.isNotEmpty(typePowerList)) {
            directElectric = typePowerList.stream().filter(item -> "省内直购电".equals(item.getEnergyType())).findAny().map(TypePowerVo::getSumEnergy).orElse("0");
            proxyElectric = typePowerList.stream().filter(item -> "电网代理购电".equals(item.getEnergyType())).findAny().map(TypePowerVo::getSumEnergy).orElse("0");
            greenElectric = typePowerList.stream().filter(item -> "省内绿电".equals(item.getEnergyType())).findAny().map(TypePowerVo::getSumEnergy).orElse("0");
            //总成交量: 省内直购量+电网代理购电+省内绿电
            countElectric = new BigDecimal(directElectric).add(new BigDecimal(proxyElectric)).add(new BigDecimal(greenElectric)).toPlainString();
        }
        TypePowerDTO typePowerDTO = new TypePowerDTO();
        typePowerDTO.setDirectElectric(directElectric);
        typePowerDTO.setProxyElectric(proxyElectric);
        typePowerDTO.setGreenElectric(greenElectric);
        typePowerDTO.setCountElectric(countElectric);
        return typePowerDTO;
    }

    /**
     * (同步数据)电源类型及成交电量
     * @return
     */
    @Override
    public SupplyTypeDTO getSupplyType() {
        Map<String, Object> supplyType = mediumLongTermContractMapper.getSupplyType();

        SupplyTypeDTO supplyTypeDTO = new SupplyTypeDTO();
        if (StringUtils.isNotEmpty(supplyType)) {
            supplyTypeDTO.setCountEnergy(String.valueOf(supplyType.get("countEnergy")));
            supplyTypeDTO.setFireEnergy(String.valueOf(supplyType.get("fireEnergy")));
            supplyTypeDTO.setFireRatio(new BigDecimal(String.valueOf(supplyType.get("fireRatio"))).multiply(new BigDecimal("100")).stripTrailingZeros().toPlainString() + "%");
            supplyTypeDTO.setWaterEnergy(String.valueOf(supplyType.get("waterEnergy")));
            supplyTypeDTO.setWaterRatio(new BigDecimal(String.valueOf(supplyType.get("waterRatio"))).multiply(new BigDecimal("100")).stripTrailingZeros().toPlainString() + "%");
            supplyTypeDTO.setNewEnergy(String.valueOf(supplyType.get("newEnergy")));
            supplyTypeDTO.setNewRatio(new BigDecimal(String.valueOf(supplyType.get("newRatio"))).multiply(new BigDecimal("100")).stripTrailingZeros().toPlainString() + "%");
        }
        return supplyTypeDTO;
    }

    /**
     * 外送交易
     * @return
     */
    @Override
    public OutsideDeliverDTO getOutsideDeliver() {
        List<Map<String, String>> outsideDeliverList = mediumLongTermContractMapper.queryOutsideDeliver();
        if (StringUtils.isEmpty(outsideDeliverList)) {
            return new OutsideDeliverDTO();
        }
        List<String> xData = new LinkedList<>();
        List<String> green = new LinkedList<>();
        List<String> outside = new LinkedList<>();
        for (Map<String, String> outsideDeliver : outsideDeliverList) {
            xData.add(outsideDeliver.get("outsideProvince"));
            green.add(outsideDeliver.get("greenElectric"));
            outside.add(outsideDeliver.get("outsideElectric"));
        }

        OutsideDeliverDTO result = new OutsideDeliverDTO();
        result.setXData(xData);
        result.setGreenElectric(green);
        result.setOutside(outside);
        return result;
    }

    /**
     * 外购交易
     * @return
     */
    @Override
    public EchartsCommonDTO<String> getOutsideBuy() {
        List<Map<String, String>> outsideBuys = mediumLongTermContractMapper.queryOutsideBuy();
        if (StringUtils.isEmpty(outsideBuys)) {
            return new EchartsCommonDTO<>();
        }
        List<String> xData = new LinkedList<>();
        List<String> seriesData = new LinkedList<>();
        for (Map<String, String> outsideBuy : outsideBuys) {
            xData.add(outsideBuy.get("buyProvince"));
            seriesData.add(outsideBuy.get("tradeElectric"));
        }

        EchartsCommonDTO<String> result = new EchartsCommonDTO<>();
        result.setXAxisData(xData);
        result.setSeriesData(seriesData);
        return result;
    }
}
