package com.alonginfo.project.gansu.serviceimpl.newenergy;

import com.alonginfo.common.utils.StringUtils;
import com.alonginfo.project.gansu.domain.*;
import com.alonginfo.project.gansu.domain.JoinEnergyTrendDTO;
import com.alonginfo.project.gansu.mapper.NewEnergySurveyMapper;
import com.alonginfo.project.gansu.service.newEnergy.INewEnergySurveyService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.*;
import java.util.stream.Collectors;

/**
 * @author: HaoXs
 * @Date: 2023/5/17 14:37
 * @Description: 新能源概览 业务层实现
 */
@Service
public class NewEnergySurveyServiceImpl implements INewEnergySurveyService {

    @Autowired
    private NewEnergySurveyMapper newEnergySurveyMapper;

    /**
     * (同步数据)新能源参与交易电量趋势
     * @return
     */
    @Override
    public JoinEnergyTrendDTO getJoinEnergyTrend() {
        List<Map<String, String>> joinEnergyTrend = newEnergySurveyMapper.getJoinEnergyTrend();

        List<String> xAxis = new LinkedList<>();
        List<String> seriesData = new LinkedList<>();
        joinEnergyTrend.forEach(map -> {
            xAxis.add(map.get("tradeYear"));
            seriesData.add(map.get("vendeeEnergy"));
        });

        JoinEnergyTrendDTO joinEnergyTrendDTO = new JoinEnergyTrendDTO();
        joinEnergyTrendDTO.setXAxisData(xAxis);
        joinEnergyTrendDTO.setSeriesData(seriesData);
        return joinEnergyTrendDTO;
    }

    /**
     * (导入数据)新能源装机结构
     *
     * @return
     */
    @Override
    public InstallStructureDTO getInstallStructure() {
        List<Map<String, String>> installStructureInfo = newEnergySurveyMapper.getInstallStructureInfo();
        if (StringUtils.isEmpty(installStructureInfo)) {
            return new InstallStructureDTO();
        }
        //新能源装机总容量
        Map<String, String> newEnergyInstallCount = installStructureInfo.stream().filter(item -> "新能源总装机容量".contains(item.get("structureName"))).findFirst().orElse(new HashMap<>());
        //表格数据
        List<Map<String, String>> tableList = installStructureInfo.stream().filter(item -> !"新能源总装机容量".contains(item.get("structureName"))).collect(Collectors.toList());

        //处理新能源装机总容量数据
        InstallStructureCount installStructureCount
                = new InstallStructureCount(newEnergyInstallCount.get("structureValue"), newEnergyInstallCount.get("yoyValue"), newEnergyInstallCount.get("flag"));
        //处理表格数据
        List<InstallStructureTable> installStructureTableList = new ArrayList<>();
        for (Map<String, String> map : tableList) {
            InstallStructureTable installStructureTable = new InstallStructureTable();
            installStructureTable.setName(map.get("structureName"));
            installStructureTable.setPrice(map.get("structureValue"));
            installStructureTable.setUnits(map.get("yoyValue"));
            installStructureTable.setFlag(map.get("flag"));
            installStructureTableList.add(installStructureTable);
        }

        //返回结果
        InstallStructureDTO installStructureDTO = new InstallStructureDTO();
        installStructureDTO.setCount(installStructureCount);
        installStructureDTO.setTable(installStructureTableList);
        return installStructureDTO;
    }

    /**
     * (导入数据)新能源装机情况
     *
     * @return
     */
    @Override
    public InstallSituationDTO getInstallSituation() {
        List<Map<String, String>> installSituationList = newEnergySurveyMapper.queryInstallSituation();
        if (StringUtils.isEmpty(installSituationList)) {
            return new InstallSituationDTO();
        }
        List<String> xData = new LinkedList<>();
        List<String> windElectricList = new LinkedList<>();
        List<String> lightElectricList = new LinkedList<>();
        for (Map<String, String> map : installSituationList) {
            xData.add(map.get("dataYear"));
            windElectricList.add(map.get("windElectric"));
            lightElectricList.add(map.get("lightElectric"));
        }

        InstallSituationDTO installSituationDTO = new InstallSituationDTO();
        installSituationDTO.setXData(xData);
        installSituationDTO.setWindElectric(windElectricList);
        installSituationDTO.setLightElectric(lightElectricList);
        return installSituationDTO;
    }

    /**
     * (导入数据)新能源发电趋势
     *
     * @return
     */
    @Override
    public ElectricTrendDTO getElectricTrend() {
        List<Map<String, String>> trends = newEnergySurveyMapper.queryElectricTrend();
        if (StringUtils.isEmpty(trends)) {
            return new ElectricTrendDTO();
        }
        List<String> xData = new LinkedList<>();
        List<String> seriesData = new LinkedList<>();
        for (Map<String, String> trend : trends) {
            xData.add(trend.get("dataYear"));
            seriesData.add(trend.get("electricValue"));
        }

        ElectricTrendDTO electricTrendDTO = new ElectricTrendDTO();
        electricTrendDTO.setXAxisData(xData);
        electricTrendDTO.setSeriesData(seriesData);
        return electricTrendDTO;
    }

    /**
     * (导入数据)新能源发电与消纳情况
     *
     * @return
     */
    @Override
    public ElectricAbsorptionDTO getElectricAbsorption() {
        List<Map<String, String>> absorptionList = newEnergySurveyMapper.queryElectricAbsorption();
        if (StringUtils.isEmpty(absorptionList)) {
            return new ElectricAbsorptionDTO();
        }
        //发电量 各类型名称和值
        Map<String, String> fdMap = new HashMap<>();
        //消纳量 各类型名称和值
        Map<String, String> xnMap = new HashMap<>();
        List<Map<String, String>> table = new ArrayList<>();
        for (Map<String, String> absorptionMap : absorptionList) {
            String energyName = absorptionMap.get("energyName");
            String electric = absorptionMap.get("electric");
            String absorption = absorptionMap.get("absorption");
            String absorptionRatio = absorptionMap.get("absorptionRatio");

            Map<String, String> tableItem = new HashMap<>();
            tableItem.put("name", energyName);
            tableItem.put("fd", electric);
            tableItem.put("xn", absorption);
            tableItem.put("units", absorptionRatio);
            table.add(tableItem);

            fdMap.put(energyName, electric);
            xnMap.put(energyName, absorption);
        }

        //处理发电量、消纳量雷达图数据
        List<List<String>> fdList = new ArrayList<List<String>>() {{
            add(
                    Arrays.asList(
                            Optional.ofNullable(fdMap.get("风电")).orElse("0"),
                            Optional.ofNullable(fdMap.get("其他")).orElse("0"),
                            Optional.ofNullable(fdMap.get("生物质")).orElse("0"),
                            Optional.ofNullable(fdMap.get("光伏")).orElse("0"))
            );
        }};
        List<List<String>> xnList = new ArrayList<List<String>>() {{
            add(
                    Arrays.asList(
                            Optional.ofNullable(xnMap.get("风电")).orElse("0"),
                            Optional.ofNullable(xnMap.get("其他")).orElse("0"),
                            Optional.ofNullable(xnMap.get("生物质")).orElse("0"),
                            Optional.ofNullable(xnMap.get("光伏")).orElse("0"))
            );
        }};

        ElectricAbsorptionDTO result = new ElectricAbsorptionDTO();
        result.setEchartXN(xnList);
        result.setEchartFD(fdList);
        result.setTable(table);
        return result;
    }

    /**
     * (导入数据)新能源参与交易情况
     * @return
     */
    @Override
    public JoinTradeDTO getJoinTrade() {
        List<Map<String, String>> joinTrades = newEnergySurveyMapper.queryJoinTrade();
        if (StringUtils.isEmpty(joinTrades)) {
            return new JoinTradeDTO();
        }
        //交易电量总量
        Map<String, String> tradeCount = joinTrades.stream()
                .filter(item -> "交易电量总量".contains(item.get("structureName"))).findFirst()
                .map(map -> {
                    Map<String, String> resultMap = new HashMap<>();
                    resultMap.put("jydlzl", map.get("tradeValue"));
                    resultMap.put("tb", map.get("yoyValue"));
                    resultMap.put("flag", map.get("flag"));
                    return resultMap;
                }).orElse(new HashMap<>());

        //过滤除交易电量总量以外其他数据
        List<Map<String, String>> joinTradesFilter = joinTrades.stream().filter(item -> !"交易电量总量".contains(item.get("structureName"))).collect(Collectors.toList());
        //环形图及表格数据
        List<Map<String, String>> echartData = new ArrayList<>();
        List<Map<String, String>> table = new ArrayList<>();
        for (Map<String, String> joinTrade : joinTradesFilter) {
            String structureName = joinTrade.get("structureName");
            String tradeValue = joinTrade.get("tradeValue");
            String flag = joinTrade.get("flag");
            String yoyValue = joinTrade.get("yoyValue");
            //环形图
            Map<String, String> echartDataItem = new HashMap<>();
            echartDataItem.put("name", structureName);
            echartDataItem.put("value", tradeValue);
            //表格
            Map<String, String> tableItem = new HashMap<>();
            tableItem.put("name", structureName);
            tableItem.put("price", tradeValue);
            tableItem.put("units", yoyValue);
            tableItem.put("flag", flag);
            echartData.add(echartDataItem);
            table.add(tableItem);
        }

        JoinTradeDTO result = new JoinTradeDTO();
        result.setEchartData(echartData);
        result.setTitle(tradeCount);
        result.setTable(table);
        return result;
    }

    /**
     * (导入数据)地图上方概览
     * @return
     */
    @Override
    public MapTopOverviewDTO getMapTopOverview() {
        Map<String, String> overview = newEnergySurveyMapper.queryMapTopOverview();
        if (StringUtils.isEmpty(overview)) {
            return new MapTopOverviewDTO();
        }
        MapTopOverviewDTO result = new MapTopOverviewDTO();
        result.setXnyzfdy(overview.get("electricCount"));
        result.setXnyxn(overview.get("absorption"));
        result.setXnl(overview.get("absorptionRatio"));
        return result;
    }
}
