package com.alonginfo.project.gansu.serviceimpl.provincemiddle;

import com.alonginfo.common.utils.StringUtils;
import com.alonginfo.project.gansu.domain.*;
import com.alonginfo.project.gansu.mapper.ProvinceMiddleMapper;
import com.alonginfo.project.gansu.service.provincemiddle.IProvinceMiddleService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.*;

/**
 * @author: HaoXs
 * @Date: 2023/6/14 16:27
 * @Description: 省间交易情况(导入数据)
 */
@Service
public class ProvinceMiddleServiceImpl implements IProvinceMiddleService {

    @Autowired
    private ProvinceMiddleMapper provinceMiddleMapper;

    /**
     * 交易组织情况
     * @return
     */
    @Override
    public List<OrganizeAndTypeVO> getOrganize() {
        List<OrganizeAndTypeVO> organizeList = provinceMiddleMapper.queryOrganizeData();
        if (StringUtils.isEmpty(organizeList)) {
            return new ArrayList<>();
        }
        return organizeList;
    }

    /**
     * 各类型电量交易情况
     * @return
     */
    @Override
    public TradeElectricTypeDTO getTradeElectricType() {
        Map<String, String> tradeElectricTypeList = provinceMiddleMapper.queryTradeElectricType();
        if (StringUtils.isEmpty(tradeElectricTypeList)) {
            return new TradeElectricTypeDTO();
        }
        List<String> xData = new LinkedList<>();
        List<String> yData = new LinkedList<>();
        xData = Arrays.asList("火电","水电","风电", "光伏");
        yData = Arrays.asList(tradeElectricTypeList.get("fire"),
                              tradeElectricTypeList.get("water"),
                              tradeElectricTypeList.get("wind"),
                              tradeElectricTypeList.get("light"));

        TradeElectricTypeDTO tradeElectricTypeDTO = new TradeElectricTypeDTO();
        tradeElectricTypeDTO.setXData(xData);
        tradeElectricTypeDTO.setYData(yData);
        return tradeElectricTypeDTO;
    }

    /**
     * 本年省间交易电量情况
     * @return
     */
    @Override
    public TradeElectricCurrentYearDTO getTradeElectricCurrentYear() {
        List<Map<String, String>> currentYearList = provinceMiddleMapper.queryTradeElectricCurrentYear();
        if (StringUtils.isEmpty(currentYearList)) {
            return new TradeElectricCurrentYearDTO();
        }
        List<String> xData = new LinkedList<>();
        List<String> electric = new LinkedList<>();
        List<String> outerPrice = new LinkedList<>();
        for (Map<String, String> map : currentYearList) {
            xData.add(map.get("dataMonth"));
            electric.add(map.get("electric"));
            outerPrice.add(map.get("outerPrice"));
        }

        TradeElectricCurrentYearDTO tradeElectricCurrentYear = new TradeElectricCurrentYearDTO();
        tradeElectricCurrentYear.setXData(xData);
        tradeElectricCurrentYear.setElectric(electric);
        tradeElectricCurrentYear.setOuterPrice(outerPrice);
        return tradeElectricCurrentYear;
    }

    /**
     * 历年省间交易电量情况
     * @return
     */
    @Override
    public TradeELectricCalendarYearDTO getTradeElectricCalendarYear() {
        List<Map<String, String>> calendarYearList = provinceMiddleMapper.queryTradeElectricCalendarYear();
        if (StringUtils.isEmpty(calendarYearList)) {
            return new TradeELectricCalendarYearDTO();
        }
        List<String> xData = new LinkedList<>();
        List<String> electric = new LinkedList<>();
        List<String> outerPrice = new LinkedList<>();
        for (Map<String, String> map : calendarYearList) {
            xData.add(map.get("dataYear"));
            electric.add(map.get("electric"));
            outerPrice.add(map.get("outerPrice"));
        }

        TradeELectricCalendarYearDTO tradeELectricCalendarYearDTO = new TradeELectricCalendarYearDTO();
        tradeELectricCalendarYearDTO.setXData(xData);
        tradeELectricCalendarYearDTO.setElectric(electric);
        tradeELectricCalendarYearDTO.setOuterPrice(outerPrice);
        return tradeELectricCalendarYearDTO;
    }

    /**
     * 概览数据
     * @return
     */
    @Override
    public OverviewDTO getOverview() {
        Map<String, String> overview = provinceMiddleMapper.queryOverview();
        if (StringUtils.isEmpty(overview)) {
            return new OverviewDTO();
        }
        OverviewDTO overviewDTO = new OverviewDTO();
        overviewDTO.setOrganizationElectric(overview.get("organizationElectric"));
        overviewDTO.setOuterElectric(overview.get("outerElectric"));
        overviewDTO.setQSDcElectric(overview.get("QSDcElectric"));
        overviewDTO.setPowerElectric(overview.get("powerElectric"));
        overviewDTO.setMarkerElectric(overview.get("markerElectric"));
        overviewDTO.setOuterGreenElectric(overview.get("outerGreenElectric"));
        return overviewDTO;
    }

    /**
     * 外送省份及外送电量
     * @return
     */
    @Override
    public List<OutProvinceDTO> getOutProvince() {

        return provinceMiddleMapper.getOutProvince();
    }
}
