package com.alonginfo.project.gansu.serviceimpl.resources;

import com.alonginfo.project.gansu.domain.*;
import com.alonginfo.project.gansu.mapper.ResourcesMapper;
import com.alonginfo.project.gansu.service.resources.IResourcesService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.ObjectUtils;
import org.springframework.util.StringUtils;

import java.util.HashMap;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;

/**
 * @author: HaoXs
 * @Date: 2023/6/12 10:28
 * @Description: 资源概览 业务层实现
 */
@Service
public class ResourcesServiceImpl implements IResourcesService {

    @Autowired
    private ResourcesMapper resourcesMapper;

    /**
     * 地图分布数据
     * @return
     */
    @Override
    public MapInfoDTO getMapInfo() {
        List<MapInfoVO> mapInfoData = resourcesMapper.getMapInfoData();
        MapInfoVO gf = mapInfoData.stream().filter(map -> "光伏".equals(map.getResourcesType())).findFirst().orElse(null);
        MapInfoVO sd = mapInfoData.stream().filter(map -> "水电".equals(map.getResourcesType())).findFirst().orElse(null);
        MapInfoVO fd = mapInfoData.stream().filter(map -> "风电".equals(map.getResourcesType())).findFirst().orElse(null);
        MapInfoVO cn = mapInfoData.stream().filter(map -> "储能".equals(map.getResourcesType())).findFirst().orElse(null);
        MapInfoVO hd = mapInfoData.stream().filter(map -> "火电".equals(map.getResourcesType())).findFirst().orElse(null);

        Map<String, Object> gfResult = dealMapInfo(gf, "1");
        Map<String, Object> sdResult = dealMapInfo(sd, "2");
        Map<String, Object> fdResult = dealMapInfo(fd, "3");
        Map<String, Object> cnResult = dealMapInfo(cn, "4");
        Map<String, Object> hdResult = dealMapInfo(hd, "5");

        MapInfoDTO mapInfoDTO = new MapInfoDTO();
        mapInfoDTO.setGf(gfResult);
        mapInfoDTO.setSd(sdResult);
        mapInfoDTO.setFd(fdResult);
        mapInfoDTO.setCn(cnResult);
        mapInfoDTO.setHd(hdResult);
        return mapInfoDTO;
    }

    /**
     * 处理地图分布数据
     * @param mapInfoVO 各资源数据
     * @param flag 1-光伏 2-水电 3-风电 4-储能 5-火电
     * @return
     */
    private Map<String, Object> dealMapInfo(MapInfoVO mapInfoVO, String flag) {
        if (ObjectUtils.isEmpty(mapInfoVO)) {
            return new HashMap<>();
        }
        Map<String, Object> result = new HashMap<>();
        //地图下方图例数据
        String[] modelText;
        //地图上图标数据
        Map<String, String[]> mapText;
        switch (flag) {
            //光伏
            case "1":
                modelText = new String[]{mapInfoVO.getPowerStation(), mapInfoVO.getInstallCapacity()};
                String[] gfOne = new String[]{mapInfoVO.getStationOneNum(), mapInfoVO.getStationOnePower()};
                String[] gfTwo = new String[]{mapInfoVO.getStationTwoNum(), mapInfoVO.getStationTwoPower()};
                String[] gfThree = new String[]{mapInfoVO.getStationThreeNum(), mapInfoVO.getStationThreePower()};
                String[] gfFour = new String[]{mapInfoVO.getStationFourNum(), mapInfoVO.getStationFourPower()};
                mapText = new HashMap<String, String[]>(){{
                    put("one", gfOne);
                    put("two", gfTwo);
                    put("three", gfThree);
                    put("four", gfFour);
                }};
                result.put("modelText", modelText);
                result.put("mapText", mapText);
                return result;
            //水电
            case "2":
                modelText = new String[]{mapInfoVO.getPowerStation(), mapInfoVO.getInstallCapacity()};
                result.put("modelText", modelText);
                return result;
            //风电
            case "3":
                modelText = new String[]{mapInfoVO.getPowerStation(), mapInfoVO.getInstallCapacity()};
                String[] fdOne = new String[]{mapInfoVO.getStationOneNum()};
                String[] fdTwo = new String[]{mapInfoVO.getStationTwoNum()};
                String[] fdThree = new String[]{mapInfoVO.getStationThreeNum()};
                String[] fdFour = new String[]{mapInfoVO.getStationFourNum()};
                mapText = new HashMap<String, String[]>(){{
                    put("one", fdOne);
                    put("two", fdTwo);
                    put("three", fdThree);
                    put("four", fdFour);
                }};
                result.put("modelText", modelText);
                result.put("mapText", mapText);
                return result;
            //储能
            case "4":
                modelText = new String[]{mapInfoVO.getPowerStation(), mapInfoVO.getInstallCapacity()};
                String[] cnOne = new String[]{mapInfoVO.getStationOnePower()};
                String[] cnTwo = new String[]{mapInfoVO.getStationTwoPower()};
                String[] cnThree = new String[]{mapInfoVO.getStationThreePower()};
                String[] cnFour = new String[]{mapInfoVO.getStationFourPower()};
                mapText = new HashMap<String, String[]>(){{
                    put("one", cnOne);
                    put("two", cnTwo);
                    put("three", cnThree);
                    put("four", cnFour);
                }};
                result.put("modelText", modelText);
                result.put("mapText", mapText);
                return result;
            //火电
            case "5":
                modelText = new String[]{mapInfoVO.getPowerStation(), mapInfoVO.getInstallCapacity()};
                String[] hdOne = new String[]{mapInfoVO.getStationOneNum()};
                String[] hdTwo = new String[]{mapInfoVO.getStationTwoNum()};
                String[] hdThree = new String[]{mapInfoVO.getStationThreeNum()};
                String[] hdFour = new String[]{mapInfoVO.getStationFourNum()};
                mapText = new HashMap<String, String[]>(){{
                    put("one", hdOne);
                    put("two", hdTwo);
                    put("three", hdThree);
                    put("four", hdFour);
                }};
                result.put("modelText", modelText);
                result.put("mapText", mapText);
                return result;
            default:
                return result;
        }
    }

    /**
     * 地图右上角数据
     * @return
     */
    @Override
    public MapTopCanvasDTO getMapTopCanvas() {
        List<Map<String, String>> mapTopCanvas = resourcesMapper.getMapTopCanvas();
        if (StringUtils.isEmpty(mapTopCanvas)) {
            return new MapTopCanvasDTO();
        }
        List<String> yData = new LinkedList<>();
        List<String> seriesData = new LinkedList<>();
        for (Map<String, String> canvasData : mapTopCanvas) {
            yData.add(canvasData.get("cityName"));
            seriesData.add(canvasData.get("cityRatio"));
        }

        MapTopCanvasDTO mapTopCanvasDTO = new MapTopCanvasDTO();
        mapTopCanvasDTO.setYData(yData);
        mapTopCanvasDTO.setSeriesData(seriesData);
        return mapTopCanvasDTO;
    }

    /**
     * 各类资源装机容量发电量对比
     * @return
     */
    @Override
    public InstallCapicatyPowerDTO getInstallAndPower() {
        List<Map<String, String>> installAndPowerList = resourcesMapper.getInstallAndPower();
        if (StringUtils.isEmpty(installAndPowerList)) {
            return new InstallCapicatyPowerDTO();
        }
        List<String> xData = new LinkedList<>();
        List<String> installCapacity = new LinkedList<>();
        List<String> power = new LinkedList<>();
        for (Map<String, String> map : installAndPowerList) {
            xData.add(map.get("resourcesName"));
            installCapacity.add(map.get("installCapacity"));
            power.add(map.get("power"));
        }

        InstallCapicatyPowerDTO installCapicatyPowerDTO = new InstallCapicatyPowerDTO();
        installCapicatyPowerDTO.setXData(xData);
        installCapicatyPowerDTO.setZjry(installCapacity);
        installCapicatyPowerDTO.setFdy(power);
        return installCapicatyPowerDTO;
    }

    /**
     * 资源开发情况
     * @return
     */
    @Override
    public ResourcesDevelopDTO getResourcesDevelop() {
        List<Map<String, String>> resourcesDevelop = resourcesMapper.getResourcesDevelop();
        if (StringUtils.isEmpty(resourcesDevelop)) {
            return new ResourcesDevelopDTO();
        }
        List<String> xData = new LinkedList<>();
        List<String> developList = new LinkedList<>();
        List<String> noDevelopList = new LinkedList<>();
        for (Map<String, String> map : resourcesDevelop) {
            xData.add(map.get("resourcesName"));
            developList.add(map.get("develop"));
            noDevelopList.add(map.get("noDevelop"));
        }

        ResourcesDevelopDTO resourcesDevelopDTO = new ResourcesDevelopDTO();
        resourcesDevelopDTO.setXData(xData);
        resourcesDevelopDTO.setYkf(developList);
        resourcesDevelopDTO.setWkf(noDevelopList);
        return resourcesDevelopDTO;
    }

    @Override
    public List<PrefectureInstallDTO> getPrefectureInstall() {
        List<PrefectureInstallDTO> prefectureInstallDTOList = resourcesMapper.getPrefectureInstall();
        return prefectureInstallDTOList;
    }
}
