package com.alonginfo.project.gansu.serviceimpl.tradeSettle;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.TypeReference;
import com.alonginfo.common.utils.StringUtils;
import com.alonginfo.common.utils.http.HttpUtils;
import com.alonginfo.project.gansu.domain.*;
import com.alonginfo.project.gansu.mapper.TradeSettleDao;
import com.alonginfo.project.gansu.service.SgccAddressService;
import com.alonginfo.project.gansu.service.tradeSettle.TradeSettleService;
import com.alonginfo.utils.DataPushUtils;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.util.*;

/**
 * TradeSettleServiceImpl
 *
 * @package_name： com.alonginfo.project.gansu.serviceimpl.tradeSettle
 * @author： 樊群靖
 * @date： 2023/8/18
 * @description:
 **/
@Service
@Slf4j
public class TradeSettleServiceImpl implements TradeSettleService {

    @Autowired
    private TradeSettleDao tradeSettleDao;

    @Autowired
    private SgccAddressService sgccAddressService;

    @Value("${env.key}")
    private String ENV_KEY;

    @Value("${sgcc.publicKey}")
    private String PUBLIC_KEY;

    @Override
    public TradeSettleDTO getProvinceTradeSettle() {
        List<Map<String, String>> currentYearList = tradeSettleDao.getProvinceTradeSettle();
        if (StringUtils.isEmpty(currentYearList)) {
            return new TradeSettleDTO();
        }
        List<String> xData = new LinkedList<>();
        List<String> zcqTradeElectric = new LinkedList<>();
        List<String> dqTradeElectric = new LinkedList<>();
        for (Map<String, String> map : currentYearList) {
            xData.add(map.get("dataMonth"));
            zcqTradeElectric.add(map.get("zcqElectric"));
            dqTradeElectric.add(map.get("dqElectric"));
        }

        TradeSettleDTO tradeSettleDTO = new TradeSettleDTO();
        tradeSettleDTO.setXData(xData);
        tradeSettleDTO.setZcqTradeElectric(zcqTradeElectric);
        tradeSettleDTO.setDqTradeElectric(dqTradeElectric);
        return tradeSettleDTO;
    }

    /**
     * 中间顶部-年度结算电量、年度结算笔数、年度结算均价
     * @return
     */
    @Override
    public Map<String, Object> getEmossInfo() {
        String sgccAddress = sgccAddressService.getSgccAddress(ENV_KEY);
        String emossInfoResStr = HttpUtils.sendPost(sgccAddress + "/emossData/emossInfo", "", DataPushUtils.createToken(PUBLIC_KEY));
        log.info("年度结算电量、年度结算笔数、年度结算均价, 接口返回结果: {}", emossInfoResStr);
        if (StringUtils.isEmpty(emossInfoResStr)) {
            log.error("年度结算电量、年度结算笔数、年度结算均价, 接口返回结果为空!");
            return new HashMap<>();
        }
        Map map = JSON.parseObject(emossInfoResStr, Map.class);
        Object data = map.get("data");
        if (null == data) {
            log.error("年度结算电量、年度结算笔数、年度结算均价, data值为null");
            return new HashMap<>();
        }
        Map<String, Object> result = JSON.parseObject(JSON.toJSONString(data), new TypeReference<Map<String, Object>>() {
        });
        return result;
    }

    /**
     * (导入数据)中间地图数据
     * @return
     */
    @Override
    public MapTextDTO getMapInfo() {
        List<TradeSettleMapInfoVo> tradeSettleMapInfoVoList = tradeSettleDao.queryMapInfo();
        if (StringUtils.isEmpty(tradeSettleMapInfoVoList)) {
            return new MapTextDTO();
        }
        MapTextDTO mapTextDTO = new MapTextDTO();
        for (TradeSettleMapInfoVo tradeSettleMap : tradeSettleMapInfoVoList) {
            String cityName = tradeSettleMap.getCityName();
            List<String> data = Arrays.asList(tradeSettleMap.getPowerSupply(), tradeSettleMap.getPowerSupplyYoy());
            if ("酒泉市".contains(cityName)) {
                mapTextDTO.setJqs(data);
            } else if ("嘉峪关市".contains(cityName)) {
                mapTextDTO.setJygs(data);
            } else if ("张掖市".contains(cityName)) {
                mapTextDTO.setZys(data);
            } else if ("金昌市".contains(cityName)) {
                mapTextDTO.setJcs(data);
            } else if ("武威市".contains(cityName)) {
                mapTextDTO.setWws(data);
            } else if ("兰州市".contains(cityName)) {
                mapTextDTO.setLzs(data);
            } else if ("临夏回族自治州".contains(cityName)) {
                mapTextDTO.setLxhzzzq(data);
            } else if ("白银市".contains(cityName)) {
                mapTextDTO.setBys(data);
            } else if ("甘南藏族自治州".contains(cityName)) {
                mapTextDTO.setGnzzzzq(data);
            } else if ("定西市".contains(cityName)) {
                mapTextDTO.setDxs(data);
            } else if ("陇南市".contains(cityName)) {
                mapTextDTO.setLns(data);
            } else if ("天水市".contains(cityName)) {
                mapTextDTO.setTss(data);
            } else if ("平凉市".contains(cityName)) {
                mapTextDTO.setPls(data);
            } else if ("庆阳市".contains(cityName)) {
                mapTextDTO.setQys(data);
            } else {

            }
        }
        return mapTextDTO;
    }
}
