package com.alonginfo.project.gansu.serviceimpl.uploadnotice;

import com.alonginfo.common.constant.Constants;
import com.alonginfo.common.utils.IdUtils;
import com.alonginfo.common.utils.StringUtils;
import com.alonginfo.common.utils.file.MimeTypeUtils;
import com.alonginfo.project.gansu.domain.MarketBuildUploadVo;
import com.alonginfo.project.gansu.domain.UploadNoticeVo;
import com.alonginfo.project.gansu.mapper.UploadNoticeMapper;
import com.alonginfo.project.gansu.service.uploadnotice.IUploadNoticeService;
import com.github.pagehelper.PageHelper;
import org.apache.commons.io.FilenameUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import java.io.File;
import java.util.*;

/**
 * 交易公告上传
 *
 * @author Administrator
 */
@Service
public class UploadNoticeServiceImpl implements IUploadNoticeService {

    @Autowired
    private UploadNoticeMapper uploadNoticeMapper;

    @Value("${notice.filePath}")
    private String NOTICE_FILE_PATH;

    @Value("${market.filePath}")
    private String MARKET_FILE_PATH;

    /**
     * 查询交易序列列表
     *
     * @param searchParam
     * @return
     */
    @Override
    public Map<String, Object> getSeqList(Map<String, String> searchParam) {
        int pageNum = Integer.parseInt(searchParam.get("pageNum"));
        int pageSize = Integer.parseInt(searchParam.get("pageSize"));

        int pageStart = (pageNum - 1) * pageSize;
        PageHelper.startPage(pageStart, pageSize);
        List<Map<String, String>> seqList = uploadNoticeMapper.getSeqList(searchParam);

        Map<String, Object> res = new HashMap<>();
        res.put("rows", seqList);
        res.put("total", seqList.size());
        return res;
    }

    /**
     * 上传交易公告
     *
     * @param uploadNoticeVo
     */
    @Override
    public void uploadNotice(UploadNoticeVo uploadNoticeVo) throws Exception {
        //判断该交易序列下是否已经上传过文件
        Map<String, Object> map = uploadNoticeMapper.checkUpload(uploadNoticeVo.getSeqId());
        if (StringUtils.isNotEmpty(map)) {
            throw new Exception("该交易序列下已上传交易公告!");
        }

        MultipartFile noticeFile = uploadNoticeVo.getNoticeFile();
        if (noticeFile == null) {
            throw new Exception("上传文件为空!");
        }
        String originalFilename = noticeFile.getOriginalFilename();
        //文件上传实际路径
        String visitPath = "";
        long size = noticeFile.getSize();
        String extension = FilenameUtils.getExtension(originalFilename);
        if (extension == null) {
            extension = MimeTypeUtils.getExtension(noticeFile.getContentType());
        }
        //判断文件大小
        checkFileSize(size);
        //判断文件后缀
        checkFileType(extension);

        //文件上传
        //文件名+uuid 避免重复
        String encodeName = IdUtils.fastSimpleUUID().toString() + "." + extension;
        // 实际上传路径
        String absolutPath = NOTICE_FILE_PATH + encodeName;
        File desc = new File(absolutPath);
        if (!desc.getParentFile().exists()) {
            desc.getParentFile().mkdirs();
        }
        noticeFile.transferTo(desc);
        //访问路径
        visitPath = Constants.NOTICE_RESOURCE_PREFIX + "/" + encodeName;

        //存储到数据库
        String uuid = UUID.randomUUID().toString().replace("-", "");
        String seqId = uploadNoticeVo.getSeqId();
        String seqName = uploadNoticeVo.getSeqName();
        uploadNoticeMapper.upload(uuid, seqId, seqName, originalFilename, encodeName, visitPath);
    }

    /**
     * 删除交易公告
     *
     * @param seqId
     */
    @Override
    public void delNotice(String seqId, String filePath) {
        //删除交易公告
        int row = uploadNoticeMapper.delNoticeNotes(seqId);
        if (row > 0) {
            //删除文件
            String realPath = filePath.replace("/notice/", NOTICE_FILE_PATH);
            File file = new File(realPath);
            if (file.exists()) {
                file.delete();
            }
        }
    }

    /**
     * 市场建设情况-上传封面图片、公告
     *
     * @param marketBuildUpload
     */
    @Override
    public void marketBuildUpload(MarketBuildUploadVo marketBuildUpload) throws Exception {
        Map<String, Object> map = uploadNoticeMapper.checkMarketBuildHave(marketBuildUpload.getFileTitle());
        if (StringUtils.isNotEmpty(map)) {
            throw new Exception("改公告标题：封面图片、文件已上传!");
        }
        MultipartFile coverImage = marketBuildUpload.getCoverImage();
        if (coverImage == null) {
            throw new Exception("封面图片文件为空!");
        }
        MultipartFile noticeFile = marketBuildUpload.getNoticeFile();
        if (noticeFile == null) {
            throw new Exception("上传文件为空!");
        }
        String imageName = coverImage.getOriginalFilename();
        String noticeFileName = noticeFile.getOriginalFilename();

        //文件校验
        long fileSize = noticeFile.getSize();
        String fileExtension = FilenameUtils.getExtension(noticeFileName);
        if (fileExtension == null) {
            fileExtension = MimeTypeUtils.getExtension(noticeFile.getContentType());
        }
        //判断文件大小
        checkFileSize(fileSize);
        //判断文件后缀
        checkFileType(fileExtension);

        long imageSize = coverImage.getSize();
        String imageExtension = FilenameUtils.getExtension(imageName);
        if (imageExtension == null) {
            imageExtension = MimeTypeUtils.getExtension(noticeFile.getContentType());
        }
        //判断图片大小
        checkImageSize(imageSize);
        //判断图片后缀
        checkImageType(imageExtension);

        //文件上传实际路径
        String visitPath = "";

        //图片上传
        //文件名+uuid 避免重复
        String imageEncodeName = imageName.substring(0, imageName.lastIndexOf(".")) + IdUtils.fastSimpleUUID().toString() + "." + imageExtension;
        //实际上传路径
        String imageAbsolutPath = MARKET_FILE_PATH + imageEncodeName;
        File imageDesc = new File(imageAbsolutPath);
        if (!imageDesc.getParentFile().exists()) {
            imageDesc.getParentFile().mkdirs();
        }
        coverImage.transferTo(imageDesc);

        //文件上传
        String fileEncodeName = noticeFileName.substring(0, noticeFileName.lastIndexOf(".")) + IdUtils.fastSimpleUUID().toString() + "." + fileExtension;
        String fileAbsolutPath = MARKET_FILE_PATH + fileEncodeName;
        File fileDesc = new File(fileAbsolutPath);
        if (!fileDesc.getParentFile().exists()) {
            fileDesc.getParentFile().mkdirs();
        }
        noticeFile.transferTo(fileDesc);

        //访问路径
        String imageVisitPath = Constants.MARKET_RESOURCE_PREFIX + "/" + imageEncodeName;
        String fileVisitPath = Constants.MARKET_RESOURCE_PREFIX + "/" + fileEncodeName;

        String uuid = UUID.randomUUID().toString().replaceAll("-", "");
        String fileTitle = marketBuildUpload.getFileTitle();
        uploadNoticeMapper.uploadMarketBuild(uuid, fileTitle, imageName, imageEncodeName, imageVisitPath,
                noticeFileName, fileEncodeName, fileVisitPath);
    }

    /**
     * 获取市场建设情况公告列表
     *
     * @param searchParam
     * @return
     */
    @Override
    public Map<String, Object> getMarketList(Map<String, String> searchParam) {
        int pageNum = Integer.parseInt(searchParam.get("pageNum"));
        int pageSize = Integer.parseInt(searchParam.get("pageSize"));

        int pageStart = (pageNum - 1) * pageSize;
        PageHelper.startPage(pageStart, pageSize);
        List<Map<String, String>> seqList = uploadNoticeMapper.getMarketList(searchParam);

        Map<String, Object> res = new HashMap<>();
        res.put("rows", seqList);
        res.put("total", seqList.size());
        return res;
    }

    /**
     * 市场建设情况-删除交易公告
     *
     * @return
     */
    @Override
    public void delMarketImageAndFile(String fileTitle, String fileUploadPath, String imageUploadPath) {
        //删除交易公告
        int row = uploadNoticeMapper.delMarketImageAndFile(fileTitle);
        if (row > 0) {
            //删除文件
            String fileRealPath = fileUploadPath.replace("/marketUpload/", MARKET_FILE_PATH);
            File file = new File(fileRealPath);
            if (file.exists()) {
                file.delete();
            }
            String imageRealPath = imageUploadPath.replace("/marketUpload/", MARKET_FILE_PATH);
            File image = new File(imageRealPath);
            if (image.exists()) {
                image.delete();
            }
        }
    }

    /**
     * 检查文件大小
     */
    public void checkFileSize(long size) throws Exception {
        //默认上传大小
        long defaultSize = 2 * 1024 * 1024;
        if (size > defaultSize) {
            throw new Exception("文件超出最大上传大小: 2M");
        }
    }

    /**
     * 检查文件类型
     *
     * @param extension
     * @throws Exception
     */
    public void checkFileType(String extension) throws Exception {
        //默认上传文件.pdf
        String defaultExtension = "pdf";
        if (!extension.equals(defaultExtension)) {
            throw new Exception("文件类型不符合! 需上传pdf文件");
        }
    }

    /**
     * 检测图片大小
     */
    private void checkImageSize(long size) throws Exception {
        //默认上传大小
        long defaultSize = 1024 * 1024;
        if (size > defaultSize) {
            throw new Exception("图片超出最大上传大小: 1M");
        }
    }

    /**
     * 检测图片类型
     *
     * @param imageExtension
     */
    private void checkImageType(String imageExtension) throws Exception {
        //默认上传文件.pdf
        String[] defaultExtensions = {"img", "jpg", "png"};
        if (!Arrays.asList(defaultExtensions).contains(imageExtension)) {
            throw new Exception("文件类型不符合! 请上传jpg、png、img格式文件!");
        }
    }
}
