package com.alonginfo.project.gansu.sync.impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.TypeReference;
import com.alonginfo.common.utils.DateUtils;
import com.alonginfo.common.utils.StringUtils;
import com.alonginfo.common.utils.http.HttpUtils;
import com.alonginfo.project.gansu.mapper.GenerationRightDataSyncMapper;
import com.alonginfo.project.gansu.service.SgccAddressService;
import com.alonginfo.project.gansu.sync.GenerationRightDataSync;
import com.alonginfo.utils.DataPushUtils;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.CollectionUtils;

import java.io.IOException;
import java.util.*;

/**
 * @author: HaoXs
 * @Date: 2023/5/17 15:12
 * @Description: 发电权交易情况 数据同步
 */
@Service
@Slf4j
public class GenerationRightDataSyncImpl implements GenerationRightDataSync {

    /**
     * 发电权交易组织情况
     */
    private static String dealOrganizeUrl = "/clearingDate/selectPowerGeneration";

    /**
     * 发电权交易市场主体参与情况
     */
    private static String subjectJoinUrl = "/clearingDate/selectParticipant";

    /**
     * 当年买入卖出企业电量排名
     */
    private static String buySaleEnterpriseOrderUrl = "/clearingDate/selectParticipantnameEnergy";

    /**
     * 发电权交易与结算电量  历年数据
     */
    private static String tradeSettlementByYearUrl = "/clearingDate/selectPowerGenerationByYaer";

    /**
     * 发电权交易与结算电量  当年各月数据
     */
    private static String tradeSettlementByCurrentYearMonthUrl = "/clearingDate/selectPowerGenerationByYaerMonth";

    @Value("${env.key}")
    private String ENV_KEY;

    @Value("${sgcc.publicKey}")
    private String publicKey;

    @Autowired
    private SgccAddressService sgccAddressService;

    @Autowired
    private GenerationRightDataSyncMapper generationRightDataSyncMapper;

    /**
     * 发电权交易组织情况
     */
    @Override
    public void dealOrganize() {
        String sgccAddress = sgccAddressService.getSgccAddress(ENV_KEY);
        String dealOrganizeResStr = HttpUtils.sendPost(sgccAddress + dealOrganizeUrl, "", DataPushUtils.createToken(publicKey));
        log.info("-发电权交易情况-发电权交易组织情况调用结果: {}", dealOrganizeResStr);
        if (StringUtils.isEmpty(dealOrganizeResStr)) {
            log.error("-发电权交易情况-发电权交易组织情况调用结果为空! url: {}, param: {}, result: {}", dealOrganizeUrl, "", dealOrganizeResStr);
            return;
        }
        Map map = JSON.parseObject(dealOrganizeResStr, Map.class);
        Object data = map.get("data");
        if (null == data) {
            log.error("-发电权交易情况-发电权交易组织情况, data为NULL!");
            return;
        }
        Map<String, Object> dealOrganizeResMap = JSON.parseObject(JSON.toJSONString(data), new TypeReference<Map<String, Object>>() {});
        generationRightDataSyncMapper.insertDealOrganize(dealOrganizeResMap);
    }

    /**
     * 发电权交易市场主体参与情况
     */
    @Override
    public void subjectJoin() {
        String sgccAddress = sgccAddressService.getSgccAddress(ENV_KEY);
        String subjectJoinResStr = HttpUtils.sendPost(sgccAddress + subjectJoinUrl, "", DataPushUtils.createToken(publicKey));
        log.info("-发电权交易情况-发电权交易市场主体参与情况调用结果: {}", subjectJoinResStr);
        if (StringUtils.isEmpty(subjectJoinResStr)) {
            log.error("-发电权交易情况-发电权交易市场主体参与情况调用结果为空! url: {}, param: {}, result: {}", subjectJoinUrl, "", subjectJoinResStr);
            return;
        }
        Map map = JSON.parseObject(subjectJoinResStr, Map.class);
        Object data = map.get("data");
        if (null == data) {
            log.error("-发电权交易情况-发电权交易市场主体参与情况, data为NULL!");
            return;
        }
        Map<String, String> subjectJoinResMap = JSON.parseObject(JSON.toJSONString(data), new TypeReference<Map<String, String>>() {});
        generationRightDataSyncMapper.insertSubjectJoin(subjectJoinResMap);
    }

    /**
     * 当年买入卖出企业电量排名
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public void buySaleEnterpriseOrder() {
        String sgccAddress = sgccAddressService.getSgccAddress(ENV_KEY);
        String buySaleResStr = HttpUtils.sendPost(sgccAddress + buySaleEnterpriseOrderUrl, "", DataPushUtils.createToken(publicKey));
        log.info("-发电权交易情况-当年买入卖出企业电量排名调用结果: {}", buySaleResStr);
        if (StringUtils.isEmpty(buySaleResStr)) {
            log.error("-发电权交易情况-当年买入卖出企业电量排名调用接口为空! url: {}, param: {}, result: {}", buySaleEnterpriseOrderUrl, "", buySaleResStr);
            return;
        }
        Map map = JSON.parseObject(buySaleResStr, Map.class);
        Object data = map.get("data");
        if (null == data) {
            log.error("-发电权交易情况-当年买入卖出企业电量排名, data为NULL!");
            return;
        }
        List<Map<String, String>> insertList = new ArrayList<>();
        Map<String, Object> dataMap = (Map<String, Object>) data;
        List<Map<String, String>> sale = JSON.parseObject(JSON.toJSONString(dataMap.get("sale")), new TypeReference<List<Map<String, String>>>() {});
        List<Map<String, String>> vendee = JSON.parseObject(JSON.toJSONString(dataMap.get("vendee")), new TypeReference<List<Map<String, String>>>() {});
        //卖出方 type=0
        sale.forEach(item -> {
            item.put("type", "0");
            insertList.add(item);
        });
        vendee.forEach(item -> {
            item.put("type", "1");
            insertList.add(item);
        });
        if (CollectionUtils.isEmpty(insertList)) {
            return;
        }
        generationRightDataSyncMapper.delBuySaleOrder();
        generationRightDataSyncMapper.insertBuySaleOrder(insertList);
    }

    /**
     * 发电权交易与结算电量  历年数据
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public void tradeSettlementByYear() throws IOException {
        String sgccAddress = sgccAddressService.getSgccAddress(ENV_KEY);

        List<Map<String, String>> insertParamList = new ArrayList<>();
        List<String> calendarYear = DateUtils.getLastYear(6);
        for (String year : calendarYear) {
            Map<String, String> requestParam = new HashMap<>();
            requestParam.put("tradeYear", year);
            String tradeSettlementByYearResStr = HttpUtils.sendPostDataByJson(sgccAddress + tradeSettlementByYearUrl, JSON.toJSONString(requestParam), DataPushUtils.createToken(publicKey));
            log.info("-发电权交易与结算电量-历年数据调用结果: {}", tradeSettlementByYearResStr);
            if (StringUtils.isEmpty(tradeSettlementByYearResStr)) {
                log.error("-发电权交易与结算电量-历年数据调用结果为空! url: {}, param: {}, result: {}", tradeSettlementByYearUrl, JSON.toJSONString(requestParam), tradeSettlementByYearResStr);
                continue;
            }
            Map map = JSON.parseObject(tradeSettlementByYearResStr, Map.class);
            Object data = map.get("data");
            if (null == data) {
                log.error("-发电权交易与结算电量-历年数据, data为NULL!");
                continue;
            }
            Map<String, String> yearMap = JSON.parseObject(JSON.toJSONString(data), new TypeReference<Map<String, String>>() {});
            insertParamList.add(yearMap);
        }
        if (CollectionUtils.isEmpty(insertParamList)) {
            return;
        }
        generationRightDataSyncMapper.delTradeSettlementYear();
        //TODO 结算电量字段暂无  暂时给settlement
        generationRightDataSyncMapper.insertTradeSettlementYear(insertParamList);
    }

    /**
     * 发电权交易与结算电量  当年各月数据
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public void tradeSettlementByCurrentYearMonth() {
        String sgccAddress = sgccAddressService.getSgccAddress(ENV_KEY);
        String tradeSettlementYearMonthResStr = HttpUtils.sendPost(sgccAddress + tradeSettlementByCurrentYearMonthUrl, "", DataPushUtils.createToken(publicKey));
        log.info("-发电权交易与结算电量-当年各月数据调用结果: {}", tradeSettlementYearMonthResStr);
        if (StringUtils.isEmpty(tradeSettlementYearMonthResStr)) {
            log.error("-发电权交易与结算电量-当年各月数据调用结果为空! url: {}, param: {}, result: {}", tradeSettlementByCurrentYearMonthUrl, "", tradeSettlementYearMonthResStr);
            return;
        }
        Map map = JSON.parseObject(tradeSettlementYearMonthResStr, Map.class);
        Object data = map.get("data");
        if (null == data) {
            log.error("-发电权交易与结算电量-当年各月数据, data为NULL!");
            return;
        }
        List<Map<String, String>> tradeSettlementResList = JSON.parseObject(JSON.toJSONString(data), new TypeReference<List<Map<String, String>>>() {});

        List<Map<String, String>> insertList = new ArrayList<>();
        tradeSettlementResList.forEach(item -> {
            Map<String, String> insertItemMap = new HashMap<>();
            insertItemMap.put("yearMonth", item.get("yearMonth"));
            insertItemMap.put("energy", item.get("energy"));
            insertList.add(insertItemMap);
        });
        if (CollectionUtils.isEmpty(insertList)) {
            return;
        }
        generationRightDataSyncMapper.delTradeSettlementYearMonth();
        //TODO 结算电量暂无  暂时给settlement
        generationRightDataSyncMapper.insertTradeSettlementYearMonth(insertList);
    }
}

