package com.alonginfo.project.gansu.sync.impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.TypeReference;
import com.alonginfo.common.utils.StringUtils;
import com.alonginfo.common.utils.http.HttpUtils;
import com.alonginfo.project.gansu.mapper.MediumLongTermContractDataSyncMapper;
import com.alonginfo.project.gansu.service.SgccAddressService;
import com.alonginfo.project.gansu.sync.MediumLongTermContractDataSync;
import com.alonginfo.utils.DataPushUtils;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.io.IOException;
import java.time.Year;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author: HaoXs
 * @Date: 2023/5/15 11:32
 * @Description: 中长期合同签订情况  数据同步
 */
@Service
@Slf4j
public class MediumLongTermContractDataSyncImpl implements MediumLongTermContractDataSync {

    private static String tradeTypeAndPowerUrl = "/tradeEnergyPriceTrend/selectTradeEnergyPriceDataByEnergyType";

    private static String powerSupplyUrl = "/tradeEnergyPriceTrend/selectTradeEnergyByGenerationType";

    @Value("${env.key}")
    private String ENV_KEY;

    @Value("${sgcc.publicKey}")
    private String publicKey;

    @Autowired
    private SgccAddressService sgccAddressService;

    @Autowired
    private MediumLongTermContractDataSyncMapper mediumLongTermContractDataSyncMapper;

    /**
     * 省内交易品种及交易电量
     * @throws Exception
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public void tradeTypeAndPowerByProvinceInner() throws Exception {
        String sgccAddress = sgccAddressService.getSgccAddress(ENV_KEY);
        Map<String, String> requestParam = new HashMap<>();
        requestParam.put("tradeYear", String.valueOf(Year.now().getValue()));
        String tradeTypeAndPowerResStr = HttpUtils.sendPostDataByJson(sgccAddress + tradeTypeAndPowerUrl, JSON.toJSONString(requestParam), DataPushUtils.createToken(publicKey));
        log.info("-中长期合同签订情况-省内交易品种及交易电量调用结果: {}", tradeTypeAndPowerResStr);
        if (StringUtils.isEmpty(tradeTypeAndPowerResStr)) {
            log.error("-中长期合同签订情况-省内交易品种及交易电量返回结果为空! url:{}, param:{}, result:{}", tradeTypeAndPowerUrl, JSON.toJSONString(requestParam), tradeTypeAndPowerResStr);
            return;
        }
        Map map = JSON.parseObject(tradeTypeAndPowerResStr, Map.class);
        Object data = map.get("data");
        if (null == data) {
            log.error("-中长期合同签订情况-省内交易品种及交易电量, data值为NULL!");
            return;
        }
        List<Map<String, String>> tradeTypeAndPowerResList = JSON.parseObject(JSON.toJSONString(data), new TypeReference<List<Map<String, String>>>(){});
        if (CollectionUtils.isEmpty(tradeTypeAndPowerResList)) {
            return;
        }
        mediumLongTermContractDataSyncMapper.delTradeTypeAndPower();
        mediumLongTermContractDataSyncMapper.insertTradeTypeAndPower(tradeTypeAndPowerResList);
    }

    /**
     * 省内电源类型及交易电量
     * @throws Exception
     */
    @Override
    public void powerSupplyByProvinceInner() throws IOException {
        String sgccAddress = sgccAddressService.getSgccAddress(ENV_KEY);
        Map<String, String> requestParam = new HashMap<>();
        requestParam.put("tradeYear", String.valueOf(Year.now().getValue()));
        String powerSupplyResStr = HttpUtils.sendPostDataByJson(sgccAddress + powerSupplyUrl, JSON.toJSONString(requestParam), DataPushUtils.createToken(publicKey));
        log.info("-中长期合同签订情况-省内电源类型及交易电量调用结果: {}", powerSupplyResStr);
        if (StringUtils.isEmpty(powerSupplyResStr)) {
            log.error("-中长期合同签订情况-省内电源类型及交易电量返回结果为空! url:{}, param:{}, result:{}", powerSupplyUrl, JSON.toJSONString(requestParam), powerSupplyResStr);
            return;
        }
        Map map = JSON.parseObject(powerSupplyResStr, Map.class);
        Object data = map.get("data");
        if (null == data) {
            log.error("-中长期合同签订情况-省内电源类型及交易电量, data值为NULL!");
            return;
        }
        List<Map<String, String>> powerSupplyResList = JSON.parseObject(JSON.toJSONString(data), new TypeReference<List<Map<String, String>>>() {});
        if (CollectionUtils.isEmpty(powerSupplyResList)) {
            return;
        }
        mediumLongTermContractDataSyncMapper.delPowerSupply();
        mediumLongTermContractDataSyncMapper.insertPowerSupply(powerSupplyResList);
    }
}
