package com.alonginfo.project.gansu.sync.impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.TypeReference;
import com.alonginfo.common.utils.StringUtils;
import com.alonginfo.common.utils.http.HttpUtils;
import com.alonginfo.project.gansu.mapper.NewEnergySurveyDataSyncMapper;
import com.alonginfo.project.gansu.service.SgccAddressService;
import com.alonginfo.project.gansu.sync.NewEnergySurveyDataSync;
import com.alonginfo.utils.DataPushUtils;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author: HaoXs
 * @Date: 2023/5/17 14:37
 * @Description:  新能源概览 数据同步
 */
@Service
@Slf4j
public class NewEnergySurveyDataSyncImpl implements NewEnergySurveyDataSync {

    private static String joinDealElectricTrendUrl = "/tradeSituation/selectCleanEnergyListByYear";

    @Value("${env.key}")
    private String ENV_KEY;

    @Value("${sgcc.publicKey}")
    private String publicKey;

    @Autowired
    private SgccAddressService sgccAddressService;

    @Autowired
    private NewEnergySurveyDataSyncMapper newEnergySurveyDataSyncMapper;

    /**
     * 新能源参与交易电量趋势
     */
    @Override
    public void joinDealElectricTrend() {
        String sgccAddress = sgccAddressService.getSgccAddress(ENV_KEY);
        String joinDealElectricResStr = HttpUtils.sendPost(sgccAddress+joinDealElectricTrendUrl, "", DataPushUtils.createToken(publicKey));
        log.info("-新能源概览-新能源参与交易电量趋势调用结果: {}", joinDealElectricResStr);
        if (StringUtils.isEmpty(joinDealElectricResStr)) {
            log.error("-新能源概览-新能源参与交易电量趋势接口返回为空! url: {}, param: {}, result: {}", joinDealElectricResStr, "", joinDealElectricTrendUrl);
            return;
        }
        Map map = JSON.parseObject(joinDealElectricResStr, Map.class);
        Object data = map.get("data");
        if (null == data) {
            log.error("-新能源概览-新能源参与交易电量趋势, data值为NULL!");
            return;
        }
        List<Map<String, Object>> joinDealElectricResList = JSON.parseObject(JSON.toJSONString(data), new TypeReference<List<Map<String, Object>>>() {});
        List<Map<String, Object>> insertParamList = new ArrayList<>();
        joinDealElectricResList.forEach(item -> {
            Map<String, Object> insertMap = new HashMap<>();
            insertMap.put("tradeYear", item.get("tradeYear"));
            insertMap.put("sumVendeeEnergy", item.get("sumVendeeEnergy"));
            insertMap.put("sumSaleEnergy", item.get("sumSaleEnergy"));
            insertMap.put("energyType", item.get("energyType"));
            insertParamList.add(insertMap);
        });

        if (CollectionUtils.isEmpty(insertParamList)) {
            return;
        }
        newEnergySurveyDataSyncMapper.delJoinElectricTrend();
        newEnergySurveyDataSyncMapper.insertJoinElectricTrend(insertParamList);
    }
}
