package com.alonginfo.project.gansu.task;

import com.alonginfo.project.gansu.sync.BilateralConsultDataSync;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

/**
 *  甘肃二期-双边协商交易过程监视及回演  动态数据获取  定时任务
 * @author HaoXs
 *
 */
@Slf4j
@Component
public class DynamicDataPushTask {

    @Autowired
    private BilateralConsultDataSync bilateralConsultDataSync;

    /**
     * 获取最新交易序列信息
     */
    public void getTradeSeqInfoList() {
        try {
            log.info("taskJob: ====获取双边协商-最新交易序列信息开始！=====");
            bilateralConsultDataSync.getTradeSeqInfoList();
            log.info("taskJob: ====获取双边协商-最新交易序列信息结束！=====");
        } catch (Exception e) {
            log.info("获取双边协商-最新交易序列信息失败!", e.getMessage());
            e.printStackTrace();
        }
    }

    /**
     * 	具体的交易公告详细信息
     */
    public void getTradeNotice() {
        try {
            log.info("taskJob: ====获取双边协商-交易公告详细信息开始! ======");
            bilateralConsultDataSync.getTradeNotice();
            log.info("taskJob: ====获取双边协商-交易公告详细信息结束! ======");
        } catch (Exception e) {
            log.info("获取双边协商-交易公告详细信息失败!", e.getMessage());
            e.printStackTrace();
        }
    }

    /**
     *	获取售方申报信息和购方确认信息 - 交易情况数据
     */
    public void getTradeDetailList() {
        try {
            log.info("taskJob: ====获取双边协商-售方申报信息和购方确认信息开始! ====");
            bilateralConsultDataSync.getTradeDetailList();
            log.info("taskJob: ====获取双边协商-售方申报信息和购方确认信息结束! ====");
        } catch (Exception e) {
            log.info("获取双边协商-售方申报信息和购方确认信息失败! ", e.getMessage());
            e.printStackTrace();
        }
    }

    /**
     *	获取售方申报的电量信息统计 - 发电类型统计
     */
    public void getTradeSaleEnergyList() {
        try {
            log.info("taskJob: ====获取双边协商-售方申报的电量信息统计开始! ====");
            bilateralConsultDataSync.getTradeSaleEnergyList();
            log.info("taskJob: ====获取双边协商-售方申报的电量信息统计结束! ====");
        } catch (Exception e) {
            log.info("获取双边协商-售方申报的电量信息统计失败! ", e.getMessage());
            e.printStackTrace();
        }
    }

    /**
     * 获取交易量价走势数据
     */
    public void getPriceTrendList() {
        try {
            log.info("taskJob: ==== 获取双边协商-交易量价走势数据开始! ====");
            bilateralConsultDataSync.getPriceTrend();
            log.info("taskJob: ==== 获取双边协商-交易量价走势数据结束! ====");
        } catch (Exception e) {
            log.info(" 获取双边协商-交易量价走势数据失败! ", e.getMessage());
            e.printStackTrace();
        }
    }

    /**
     * 获取交易量价走势 - 回演数据
     */
    public void getPriceTrendReplayList() {
        try {
            log.info("taskJob: ==== 获取双边协商-交易量价走势 - 回演数据开始! ====");
            bilateralConsultDataSync.getPriceTrendReplay();
            log.info("taskJob: ==== 获取双边协商-交易量价走势 - 回演数据结束! ====");
        } catch (Exception e) {
            log.info(" 获取双边协商-交易量价走势- 回演数据失败! ",e.getMessage());
            e.printStackTrace();
        }
    }

    /**
     * 多日交易-实时状态：交易量价走势
     */
    public void getManyDayRealTime() {
        try {
            log.info("taskJob: ==== 获取双边协商-多日交易-实时状态：交易量价走势开始! ====");
            bilateralConsultDataSync.getRealTimeManyDay();
            log.info("taskJob: ==== 获取双边协商-多日交易-实时状态：交易量价走势结束! ====");
        } catch (Exception e) {
            e.printStackTrace();
            log.info(" 获取双边协商-多日交易-实时状态：交易量价走势失败!");
        }
    }
}
