package com.alonginfo.project.gansu.task;

import com.alibaba.fastjson.JSON;
import com.alonginfo.common.utils.StringUtils;
import com.alonginfo.project.gansu.service.bilateralconsult.BilateralConsultService;
import com.alonginfo.project.gansu.service.dayaddthree.DayAddThreeSyncGet;
import com.alonginfo.project.gansu.service.focuslisting.FocusBiddingListingDealCommonService;
import com.alonginfo.websocket.server.WebSocketServer;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Map;

/**
 * 双边协商、挂牌交易、集中竞价、D+3页面实时数据推送
 */
@Component
@Slf4j
public class PageDataPush {

    @Autowired
    private WebSocketServer webSocketServer;

    @Autowired
    private BilateralConsultService bilateralConsultService;

    @Autowired
    private FocusBiddingListingDealCommonService focusBiddingListingDealCommonService;

    @Autowired
    private DayAddThreeSyncGet dayAddThreeSyncGet;

    //双边协商pageId
    private static final String sbPageId = "sb";

    //集中竞价
    private static final String jzPageId = "jz";

    //挂牌交易
    private static final String gpPageId = "gp";

    //d+3页面实时数据推送
    private static final String d3PageId = "d3";

    /**
     * 双边协商页面数据推送
     */
    public void bilateralConsultDataPush() {
        //判断是否在线
        if (webSocketServer.isOnlineForRealTimePage(sbPageId)) {
            //获取tradeId
            String tradeIdByPageId = webSocketServer.getTradeIdByPageId(sbPageId);
            if (StringUtils.isEmpty(tradeIdByPageId)) {
                log.error("-双边协商页面, 交易序列ID为空!, 数据推送失败!");
                return;
            }
            Map<String, Object> bilateralConsult = bilateralConsultService.getBilateralConsult(tradeIdByPageId);
            webSocketServer.pushDataToRealTimePage(sbPageId, JSON.toJSONString(bilateralConsult));
            log.info("-双边协商页面, 实时数据推送成功!");
        }
    }

    /**
     * 集中竞价页面数据推送
     */
    public void focusBiddingDataPush() {
        //判断是否在线
        if (webSocketServer.isOnlineForRealTimePage(jzPageId)) {
            //获取tradeId
            String tradeId = webSocketServer.getTradeIdByPageId(jzPageId);
            if (StringUtils.isEmpty(tradeId)) {
                log.error("-集中竞价页面, 交易序列ID为空!, 数据推送失败!");
                return;
            }
            Map<String, Object> focusBidding = focusBiddingListingDealCommonService.getFocusBidding("1", tradeId);
            webSocketServer.pushDataToRealTimePage(sbPageId, JSON.toJSONString(focusBidding));
            log.info("-集中竞价页面, 实时数据推送成功!");
        }
    }

    /**
     * 挂牌交易页面数据推送
     */
    public void listingDealDataPush() {
        //判断是否在线
        if (webSocketServer.isOnlineForRealTimePage(gpPageId)) {
            //获取tradeId
            String tradeId = webSocketServer.getTradeIdByPageId(gpPageId);
            if (StringUtils.isEmpty(tradeId)) {
                log.error("-挂牌交易页面, 交易序列ID为空!, 数据推送失败!");
                return;
            }
            Map<String, Object> listingDeal = focusBiddingListingDealCommonService.getFocusBidding("2", tradeId);
            webSocketServer.pushDataToRealTimePage(sbPageId, JSON.toJSONString(listingDeal));
            log.info("-挂牌交易页面, 实时数据推送成功!");
        }
    }

    /**
     * d+3页面数据推送
     */
    public void dayAddThreeDataPush() {
        //判断是否在线
        if (webSocketServer.isOnlineForRealTimePage(d3PageId)) {
            //获取tradeId
            String tradeId = webSocketServer.getTradeIdByPageId(d3PageId);
            if (StringUtils.isEmpty(tradeId)) {
                log.error("-D+3页面, 交易序列ID为空!, 数据推送失败!");
                return;
            }
            Map<String, Object> dayAddThreeResult = dayAddThreeSyncGet.dayAddThreeDataReturn(tradeId);
            webSocketServer.pushDataToRealTimePage(sbPageId, JSON.toJSONString(dayAddThreeResult));
            log.info("-D+3页面, 实时数据推送成功!");
        }
    }
}
