package com.alonginfo.project.tool;

import java.io.FileInputStream;
import java.io.IOException;
import java.util.HashMap;
import java.util.Map;

public class MagicNumberFileTypeChecker {
    // 定义魔术字节常量，以十六进制格式表示
    private static final String JPEG_MAGIC = "FFD8FF";
    private static final String PNG_MAGIC = "89504E47";
    private static final String GIF_MAGIC = "47494638";
    private static final String PDF_MAGIC = "25504446";
    private static final String ZIP_MAGIC = "504B0304";

    // 文件类型映射
    private static final Map<String, String> MAGIC_MAP = new HashMap<>();

    static {
        MAGIC_MAP.put("JPEG Image", JPEG_MAGIC);
        MAGIC_MAP.put("PNG Image", PNG_MAGIC);
        MAGIC_MAP.put("GIF Image", GIF_MAGIC);
        MAGIC_MAP.put("PDF Document", PDF_MAGIC);
        MAGIC_MAP.put("ZIP Archive", ZIP_MAGIC);
    }

    // 获取文件的前几个字节
    public static byte[] getFileMagicNumber(String filePath, int length) throws IOException {
        try (FileInputStream fis = new FileInputStream(filePath)) {
            byte[] magicNumber = new byte[length];
            if (fis.read(magicNumber) != length) {
                throw new IOException("Unable to read enough bytes from file");
            }
            return magicNumber;
        }
    }

    // 将字节数组转换为十六进制字符串
    private static String toHexString(byte[] bytes) {
        StringBuilder sb = new StringBuilder();
        for (byte b : bytes) {
            sb.append(String.format("%02X", b));
        }
        return sb.toString();
    }

    // 识别文件类型
    public static String identifyFileType(byte[] magicNumber) {
        String magicHex = toHexString(magicNumber);
        for (Map.Entry<String, String> entry : MAGIC_MAP.entrySet()) {
            if (magicHex.startsWith(entry.getValue())) {
                return entry.getKey();
            }
        }
        return "Unknown File Type";

    }
}
