package com.alonginfo.project.tool;

import org.bouncycastle.crypto.CipherParameters;
import org.bouncycastle.crypto.engines.SM4Engine;
import org.bouncycastle.crypto.modes.CBCBlockCipher;
import org.bouncycastle.crypto.modes.CBCModeCipher;
import org.bouncycastle.crypto.paddings.PaddedBufferedBlockCipher;
import org.bouncycastle.crypto.params.KeyParameter;
import org.bouncycastle.crypto.params.ParametersWithIV;
import org.bouncycastle.jce.provider.BouncyCastleProvider;

import java.nio.charset.Charset;
import java.nio.charset.StandardCharsets;
import java.security.Security;
import java.util.Arrays;
import java.util.Base64;


public class Sm4Utils {
    static {
        Security.addProvider(new BouncyCastleProvider());
    }

    public static String encrypt(byte[] key, byte[] iv, byte[] data) throws Exception {
      byte[] out=new byte[0];
      String encryptedData=null;
       try{
           SM4Engine engine = new SM4Engine();
           CBCModeCipher cbcBlockCipher = CBCBlockCipher.newInstance(engine);
           PaddedBufferedBlockCipher cipher = new PaddedBufferedBlockCipher(cbcBlockCipher);
           CipherParameters params = new ParametersWithIV(new KeyParameter(key), iv);
           cipher.init(true, params);
           out = new byte[cipher.getOutputSize(data.length)];
           int len = cipher.processBytes(data, 0, data.length, out, 0);
           len += cipher.doFinal(out, len);
           encryptedData = Base64.getEncoder().encodeToString(out);
           return encryptedData;
       } catch (Exception e) {
           // 处理异常
           throw e;
       } finally {
           Arrays.fill(out, (byte) 0);
           encryptedData = null;
       }
    }
    public static byte[] decrypt(byte[] key, byte[] iv, byte[] data) throws Exception {
        byte[] out = new byte[0];
        byte[] temp = new byte[0];
        try {
            byte[] encryptedBytes = Base64.getDecoder().decode(data);
            SM4Engine engine = new SM4Engine();
            CBCModeCipher cbcBlockCipher = CBCBlockCipher.newInstance(engine);
            PaddedBufferedBlockCipher cipher = new PaddedBufferedBlockCipher(cbcBlockCipher);
            CipherParameters params = new ParametersWithIV(new KeyParameter(key), iv);
            cipher.init(false, params);
            temp = new byte[cipher.getOutputSize(encryptedBytes.length)];
            int len = cipher.processBytes(encryptedBytes, 0, encryptedBytes.length, temp, 0);
            len += cipher.doFinal(temp, len);
            out = new byte[len];
            System.arraycopy(temp, 0, out, 0, len);
            return out;
        } catch (Exception e) {
            // 处理异常
            throw e;
        } finally {
//            Arrays.fill(out, (byte) 0);
//			Arrays.fill(temp, (byte) 0);
        }
    }

    public static void main(String[] args) throws Exception {
        String sm4key = "edcssm4key071520";
        String iv = "abcdef1234567890";
        String test = "Hxs1909.";
        String encrypt = Sm4Utils.encrypt(sm4key.getBytes(), iv.getBytes(), test.getBytes());
        System.out.println(encrypt);
        byte[] decrypt = Sm4Utils.decrypt(sm4key.getBytes(), iv.getBytes(), encrypt.getBytes());
        Charset charset = Charset.forName("UTF-8");
        String str = new String(decrypt, charset);
        System.out.println(str);
    }
}

