package com.alonginfo.utils;

import com.alibaba.fastjson.JSON;
import com.alonginfo.common.utils.DateUtils;
import com.alonginfo.common.utils.StringUtils;
import com.alonginfo.common.utils.http.HttpUtils;
import org.apache.http.client.ClientProtocolException;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.IOException;
import java.math.BigDecimal;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.time.LocalDateTime;
import java.time.Year;
import java.time.format.DateTimeFormatter;
import java.util.*;
import java.util.Map.Entry;

/**
 * 集中竞价、挂牌交易 远程接口调用方法
 * @author Administrator
 *
 */
public class FocusBiddingUtil {
	
	private static final Logger log = LoggerFactory.getLogger(FocusBiddingUtil.class);

	/**
	 * 	开标后的结果
	 * 	远程接口获取集中交易-购售方申报数据(中间表格的数据；接口1.8)  || 挂牌交易 - 挂/摘牌信息   ===== 实时交易
	 * @param role 购方/售方
	 * @param seqId 交易序列id
	 * @param sgccAddress 交易平台地址
	 * @return
	 * @throws IOException 
	 * @throws ClientProtocolException 
	 */
	public static List<Map> getRportAndHangPickBidAfter(int role, String seqId, String sgccAddress, String token) throws ClientProtocolException, IOException {
		List<Map> resiltList = new ArrayList<>();
		int pageNum = 1;
		while (true) {
//			if (pageNum>1) {
//				return resiltList;
//			}
			//封装查询参数
			Map<String, Object> pageInfo = new HashMap<>();
			pageInfo.put("pageNum", pageNum);
			pageInfo.put("pageSize", 30);
			Map<String, Object> map = new HashMap<>();
			map.put("tradeRole", role);
			map.put("tradeseqId", seqId);
			Map<String, Object> paramsMap = new HashMap<String, Object>();
			paramsMap.put("data", map);
			paramsMap.put("pageInfo", pageInfo);
			//获取集中竞价/挂牌交易  实时交易时  中间模块数据 
			String focusAndListingTradeReport = HttpUtils.sendPostDataByJson(sgccAddress + "/dataPush/tradeDeclareDetail/selectTradeReport", JSON.toJSONString(paramsMap), token);
			log.info("reportAndHangPickBidAfter = " + focusAndListingTradeReport);
			Map<String, Object> tradeReportResMap = JSON.parseObject(focusAndListingTradeReport, Map.class);
			Map<String, Object> data = (Map<String, Object>) tradeReportResMap.get("data");
			if (data == null || data.size() == 0) {
				log.info("接口: /dataPush/tradeDeclareDetail/selectTradeReport, data值为空!");
				return resiltList;
			}
			//获取结果只  接口返回数据结构: data: {"total": xx, "list": [{}]}
			List<Map> listResult = JSON.parseArray(JSON.toJSONString(data.get("list")), Map.class);
			if (listResult == null || listResult.size() == 0) {
				log.info("接口: /dataPush/tradeDeclareDetail/selectTradeReport, 当前页数据为空, 循环跳出; 已获取{}页", pageNum);
				return resiltList;
			}
			resiltList.addAll(listResult);
			pageNum++;
		}
	}
	
	/**
	 * 	获取集中竞价、挂牌交易  实时交易--- 购售方申报信息 (接口2.1  -- 开标前数据)
	 * @param role
	 * @param seqId
	 * @param sgccAddress
	 * @param token
	 * @return
	 * @throws IOException 
	 * @throws ClientProtocolException 
	 */
	public static List<Map> getRportAndHangPickBidBefore(int role, String seqId, String sgccAddress, String token) throws Exception {
		List<Map> result = new ArrayList<>();
		Map<String, Object> params = new HashMap<>();
		params.put("tradeseqId", seqId);
		params.put("tradeRole", role);
		String focusAndListingTradeReport = HttpUtils.sendPostDataByJson(sgccAddress + "/dataPush/tradeDeclareDetail/selectBeforeOpen", JSON.toJSONString(params), token);
		if (focusAndListingTradeReport == null || "".equals(focusAndListingTradeReport)) {
			log.info("接口:/dataPush/tradeDeclareDetail/selectBeforeOpen, 返回结果为NULL");
			return new ArrayList<>();
		}
		log.info("接口url:{}, 调用结果：{}", "/tradeDeclareDetail/selectBeforeOpen", focusAndListingTradeReport);
		Map<String, Object> resMap = JSON.parseObject(focusAndListingTradeReport, Map.class);
		Map<String, Object> data = (Map<String, Object>) resMap.get("data");
		if (data == null || data.size() == 0) {
			log.info("接口:/dataPush/tradeDeclareDetail/selectBeforeOpen, 返回结果中data为NULL");
			return result;
		}
		//结果数据  data: {total: xx, list: [{}]}
		List<Map> list = JSON.parseArray(JSON.toJSONString(data.get("list")), Map.class);
		result.addAll(list);
		return result;
	}
	
	/**
	  *  远程接口获取集中交易-购售方申报数据(中间表格的数据；接口2.0)  || 挂牌交易 - 挂/摘牌信息   ===== 回演交易
	 * @param seqId
	 * @return
	 * @throws IOException 
	 * @throws ClientProtocolException 
	 */
	public static List<Map<String, Object>> getReportAndHandPickReplay(String seqId, String sgccAddress, String token){
		try {
			List<Map<String, Object>> resultList = new ArrayList<>();
			//封装查询参数
			Map<String, Object> map = new HashMap<>();
			map.put("tradeseqId", seqId);
			//获取集中竞价/挂牌交易  实时交易时  中间模块数据 
			String focusAndListingTradeReport = HttpUtils.sendPostDataByJson(sgccAddress + "/dataPush/tradeDeclareDetail/query", JSON.toJSONString(map), token);
			Map<String, Object> tradeReportResMap = JSON.parseObject(focusAndListingTradeReport, Map.class);
			List<Map<String, Object>> data = (List<Map<String, Object>>) tradeReportResMap.get("data");
			if (data == null || data.size() == 0) {
				log.info("获取回演 挂/摘牌信息接口2.0, data数据为NULL或空! ");
				return new ArrayList<>();
			}
			//获取数据
			for (Map<String, Object> dataItem : data) {
				Map<String, Object> resultMap = new HashMap<String, Object>();
				resultMap.put("saleParticipantName", dataItem.get("saleParticipantname"));
				resultMap.put("vendeeParticipantName", dataItem.get("vendeeParticipantname"));
				resultMap.put("tradeTimeRange", dataItem.get("timeDivisionRange"));
				resultMap.put("confirmEnergy", dataItem.get("clearingEnergy"));
				resultMap.put("confirmTime", DateUtils.dateTimeFormat(String.valueOf(dataItem.get("createTime"))));
				resultList.add(resultMap);
			}
			return resultList;
		} catch (Exception e) {
			e.printStackTrace();
			log.info("集中竞价、挂牌交易, 回演状态, 购售方申报数据获取失败！");
			return new ArrayList<>();
		}	

	}

}
