package com.alonginfo.utils;

import cn.hutool.core.collection.CollUtil;
import com.alibaba.fastjson2.JSONObject;
import com.alonginfo.common.utils.StringUtils;
import lombok.extern.slf4j.Slf4j;
import org.springframework.util.DigestUtils;

import java.util.Map;

@Slf4j
public class SignUtil {

    /**
     * 验证签名
     *
     * @param params
     * @param sign
     * @return
     */
    public static boolean verifySign(Map<String, String> params, String sign, Long timestamp) {
        String paramsJsonStr = "Timestamp" + timestamp + (CollUtil.isEmpty(params)?"":JSONObject.toJSONString(params));
        return verifySign(paramsJsonStr, sign);
    }

    public static boolean verifySign(String body, String sign, Long timestamp) {
        String paramsJsonStr = "Timestamp" + timestamp + body;
        return verifySign(paramsJsonStr, sign);
    }

    /**
     * 验证签名
     *
     * @param params
     * @param sign
     * @return
     */
    public static boolean verifySign(String params, String sign) {
        log.info("Header Sign : {}", sign);
        if (StringUtils.isEmpty(params)) {
            return false;
        }
        log.info("Param : {}", params);
        String paramsSign = getParamsSign(params);
        log.info("Param Sign : {}", paramsSign);
        return sign.equals(paramsSign);
    }

    /**
     * @return 得到签名
     */
    public static String getParamsSign(String params) {
        return DigestUtils.md5DigestAsHex(params.getBytes()).toLowerCase();
    }
}
